""" Cisco_IOS_XR_pmengine_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR pmengine package operational data.

This module contains definitions
for the following management objects\:
  performance\-management\: performace data
  performance\-management\-history\: performance management history

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError



class PmPrbsPatternEtEnum(Enum):
    """
    PmPrbsPatternEtEnum

    PM PRBS Pattern Mode Enum

    .. data:: prbs_none = 0

    	pn none

    .. data:: pn31 = 1

    	pn31

    .. data:: pn23 = 2

    	pn23

    .. data:: pn11 = 4

    	pn11

    .. data:: inv_pn31 = 8

    	inv pn31

    .. data:: inv_pn11 = 16

    	inv pn11

    """

    prbs_none = 0

    pn31 = 1

    pn23 = 2

    pn11 = 4

    inv_pn31 = 8

    inv_pn11 = 16


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
        return meta._meta_table['PmPrbsPatternEtEnum']


class PmSonetPathWidthEnumEnum(Enum):
    """
    PmSonetPathWidthEnumEnum

    Sonet Path Width Enum

    .. data:: none = 0

    	Sonet Path Width NONE 

    .. data:: sts1 = 1

    	Sonet Path Width STS1 

    .. data:: sts3c_stm1 = 2

    	Sonet Path Width sts3cSTM1 

    .. data:: sts12c_stm4 = 3

    	Sonet Path Width sts12cSTM4 

    .. data:: sts24c = 4

    	Sonet Path Width sts24 

    .. data:: sts48c_stm16 = 5

    	Sonet Path Width sts48cSTM16 

    .. data:: sts192c_stm64 = 6

    	Sonet Path Width sts192cSTM64 

    .. data:: sts768c_stm256 = 7

    	Sonet Path Width sts768cSTM256 

    """

    none = 0

    sts1 = 1

    sts3c_stm1 = 2

    sts12c_stm4 = 3

    sts24c = 4

    sts48c_stm16 = 5

    sts192c_stm64 = 6

    sts768c_stm256 = 7


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
        return meta._meta_table['PmSonetPathWidthEnumEnum']



class PerformanceManagement(object):
    """
    performace data
    
    .. attribute:: dwdm
    
    	DWDM controller performance data
    	**type**\:   :py:class:`Dwdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm>`
    
    .. attribute:: ethernet
    
    	EHERNET controller performance data
    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet>`
    
    .. attribute:: ho_vc
    
    	HO\_VC controller performance data
    	**type**\:   :py:class:`HoVc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc>`
    
    .. attribute:: oc
    
    	OC controller performance data
    	**type**\:   :py:class:`Oc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc>`
    
    .. attribute:: odu
    
    	ODU controller performance data
    	**type**\:   :py:class:`Odu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu>`
    
    .. attribute:: optics
    
    	OPTICS controller performance data
    	**type**\:   :py:class:`Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics>`
    
    .. attribute:: otu
    
    	OTU controller performance data
    	**type**\:   :py:class:`Otu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu>`
    
    .. attribute:: sonet
    
    	SONET controller performance data
    	**type**\:   :py:class:`Sonet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet>`
    
    .. attribute:: stm
    
    	STM controller performance data
    	**type**\:   :py:class:`Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm>`
    
    .. attribute:: sts
    
    	STS controller performance data
    	**type**\:   :py:class:`Sts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts>`
    
    

    """

    _prefix = 'pmengine-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.dwdm = PerformanceManagement.Dwdm()
        self.dwdm.parent = self
        self.ethernet = PerformanceManagement.Ethernet()
        self.ethernet.parent = self
        self.ho_vc = PerformanceManagement.HoVc()
        self.ho_vc.parent = self
        self.oc = PerformanceManagement.Oc()
        self.oc.parent = self
        self.odu = PerformanceManagement.Odu()
        self.odu.parent = self
        self.optics = PerformanceManagement.Optics()
        self.optics.parent = self
        self.otu = PerformanceManagement.Otu()
        self.otu.parent = self
        self.sonet = PerformanceManagement.Sonet()
        self.sonet.parent = self
        self.stm = PerformanceManagement.Stm()
        self.stm.parent = self
        self.sts = PerformanceManagement.Sts()
        self.sts.parent = self


    class HoVc(object):
        """
        HO\_VC controller performance data
        
        .. attribute:: ho_vc_ports
        
        	Port performance data
        	**type**\:   :py:class:`HoVcPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.ho_vc_ports = PerformanceManagement.HoVc.HoVcPorts()
            self.ho_vc_ports.parent = self


        class HoVcPorts(object):
            """
            Port performance data
            
            .. attribute:: ho_vc_port
            
            	Port performance data
            	**type**\: list of    :py:class:`HoVcPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.ho_vc_port = YList()
                self.ho_vc_port.parent = self
                self.ho_vc_port.name = 'ho_vc_port'


            class HoVcPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ho_vc_current
                
                	port current performance data
                	**type**\:   :py:class:`HoVcCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.ho_vc_current = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent()
                    self.ho_vc_current.parent = self


                class HoVcCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: ho_vc_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`HoVcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24>`
                    
                    .. attribute:: ho_vc_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`HoVcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ho_vc_hour24 = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24()
                        self.ho_vc_hour24.parent = self
                        self.ho_vc_minute15 = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15()
                        self.ho_vc_minute15.parent = self


                    class HoVcHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: ho_vc_hour24_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`HoVcHour24Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ho_vc_hour24_paths = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths()
                            self.ho_vc_hour24_paths.parent = self


                        class HoVcHour24Paths(object):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_hour24_path
                            
                            	port 24 hour Path performance data
                            	**type**\: list of    :py:class:`HoVcHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ho_vc_hour24_path = YList()
                                self.ho_vc_hour24_path.parent = self
                                self.ho_vc_hour24_path.name = 'ho_vc_hour24_path'


                            class HoVcHour24Path(object):
                                """
                                port 24 hour Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath()
                                    self.fe_path.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path()
                                    self.path.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Path(object):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_bb_es
                                    
                                    	The number of background block errors
                                    	**type**\:   :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs>`
                                    
                                    .. attribute:: path_bbe_rs
                                    
                                    	The number of background block errors
                                    	**type**\:   :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs>`
                                    
                                    .. attribute:: path_e_bs
                                    
                                    	The number of Errored blocks
                                    	**type**\:   :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs>`
                                    
                                    .. attribute:: path_es_rs
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_ses_rs
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.path_bb_es = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs()
                                        self.path_bb_es.parent = self
                                        self.path_bbe_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs()
                                        self.path_bbe_rs.parent = self
                                        self.path_e_bs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs()
                                        self.path_e_bs.parent = self
                                        self.path_e_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self.path_es_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs()
                                        self.path_es_rs.parent = self
                                        self.path_se_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self.path_ses_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs()
                                        self.path_ses_rs.parent = self
                                        self.path_status = None
                                        self.path_ua_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self


                                    class PathESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs']['meta_info']


                                    class PathEsRs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-es-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs']['meta_info']


                                    class PathSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs']['meta_info']


                                    class PathSesRs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ses-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs']['meta_info']


                                    class PathEBs(object):
                                        """
                                        The number of Errored blocks
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-bs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs']['meta_info']


                                    class PathUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs']['meta_info']


                                    class PathBbEs(object):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-bb-es'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs']['meta_info']


                                    class PathBbeRs(object):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-bbe-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path_bb_es is not None and self.path_bb_es._has_data():
                                            return True

                                        if self.path_bbe_rs is not None and self.path_bbe_rs._has_data():
                                            return True

                                        if self.path_e_bs is not None and self.path_e_bs._has_data():
                                            return True

                                        if self.path_e_ss is not None and self.path_e_ss._has_data():
                                            return True

                                        if self.path_es_rs is not None and self.path_es_rs._has_data():
                                            return True

                                        if self.path_se_ss is not None and self.path_se_ss._has_data():
                                            return True

                                        if self.path_ses_rs is not None and self.path_ses_rs._has_data():
                                            return True

                                        if self.path_status is not None:
                                            return True

                                        if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path']['meta_info']


                                class FePath(object):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_ua_ss = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_path_c_vs is not None:
                                            return True

                                        if self.far_end_path_e_ss is not None:
                                            return True

                                        if self.far_end_path_se_ss is not None:
                                            return True

                                        if self.far_end_path_ua_ss is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-hour24-path[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_path is not None and self.fe_path._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.path is not None and self.path._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-hour24-paths'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ho_vc_hour24_path is not None:
                                    for child_ref in self.ho_vc_hour24_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ho_vc_hour24_paths is not None and self.ho_vc_hour24_paths._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24']['meta_info']


                    class HoVcMinute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: ho_vc_minute15_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`HoVcMinute15Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ho_vc_minute15_paths = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths()
                            self.ho_vc_minute15_paths.parent = self


                        class HoVcMinute15Paths(object):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_minute15_path
                            
                            	port 15\-minute Path performance data
                            	**type**\: list of    :py:class:`HoVcMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ho_vc_minute15_path = YList()
                                self.ho_vc_minute15_path.parent = self
                                self.ho_vc_minute15_path.name = 'ho_vc_minute15_path'


                            class HoVcMinute15Path(object):
                                """
                                port 15\-minute Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath()
                                    self.fe_path.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path()
                                    self.path.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Path(object):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_bb_es
                                    
                                    	The number of background block errors
                                    	**type**\:   :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs>`
                                    
                                    .. attribute:: path_bbe_rs
                                    
                                    	The number of background block errors
                                    	**type**\:   :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs>`
                                    
                                    .. attribute:: path_e_bs
                                    
                                    	The number of Errored blocks
                                    	**type**\:   :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs>`
                                    
                                    .. attribute:: path_es_rs
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_ses_rs
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.path_bb_es = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs()
                                        self.path_bb_es.parent = self
                                        self.path_bbe_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs()
                                        self.path_bbe_rs.parent = self
                                        self.path_e_bs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs()
                                        self.path_e_bs.parent = self
                                        self.path_e_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self.path_es_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs()
                                        self.path_es_rs.parent = self
                                        self.path_se_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self.path_ses_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs()
                                        self.path_ses_rs.parent = self
                                        self.path_status = None
                                        self.path_ua_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self


                                    class PathESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs']['meta_info']


                                    class PathEsRs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-es-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs']['meta_info']


                                    class PathSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs']['meta_info']


                                    class PathSesRs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ses-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs']['meta_info']


                                    class PathEBs(object):
                                        """
                                        The number of Errored blocks
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-bs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs']['meta_info']


                                    class PathUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs']['meta_info']


                                    class PathBbEs(object):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-bb-es'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs']['meta_info']


                                    class PathBbeRs(object):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-bbe-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path_bb_es is not None and self.path_bb_es._has_data():
                                            return True

                                        if self.path_bbe_rs is not None and self.path_bbe_rs._has_data():
                                            return True

                                        if self.path_e_bs is not None and self.path_e_bs._has_data():
                                            return True

                                        if self.path_e_ss is not None and self.path_e_ss._has_data():
                                            return True

                                        if self.path_es_rs is not None and self.path_es_rs._has_data():
                                            return True

                                        if self.path_se_ss is not None and self.path_se_ss._has_data():
                                            return True

                                        if self.path_ses_rs is not None and self.path_ses_rs._has_data():
                                            return True

                                        if self.path_status is not None:
                                            return True

                                        if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path']['meta_info']


                                class FePath(object):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_ua_ss = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_path_c_vs is not None:
                                            return True

                                        if self.far_end_path_e_ss is not None:
                                            return True

                                        if self.far_end_path_se_ss is not None:
                                            return True

                                        if self.far_end_path_ua_ss is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-minute15-path[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_path is not None and self.fe_path._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.path is not None and self.path._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-minute15-paths'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ho_vc_minute15_path is not None:
                                    for child_ref in self.ho_vc_minute15_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ho_vc_minute15_paths is not None and self.ho_vc_minute15_paths._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ho_vc_hour24 is not None and self.ho_vc_hour24._has_data():
                            return True

                        if self.ho_vc_minute15 is not None and self.ho_vc_minute15._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:ho-vc/Cisco-IOS-XR-pmengine-oper:ho-vc-ports/Cisco-IOS-XR-pmengine-oper:ho-vc-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.ho_vc_current is not None and self.ho_vc_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts.HoVcPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:ho-vc/Cisco-IOS-XR-pmengine-oper:ho-vc-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.ho_vc_port is not None:
                    for child_ref in self.ho_vc_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.HoVc.HoVcPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:ho-vc'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.ho_vc_ports is not None and self.ho_vc_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.HoVc']['meta_info']


    class Odu(object):
        """
        ODU controller performance data
        
        .. attribute:: odu_ports
        
        	Port performance data
        	**type**\:   :py:class:`OduPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.odu_ports = PerformanceManagement.Odu.OduPorts()
            self.odu_ports.parent = self


        class OduPorts(object):
            """
            Port performance data
            
            .. attribute:: odu_port
            
            	Port performance data
            	**type**\: list of    :py:class:`OduPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.odu_port = YList()
                self.odu_port.parent = self
                self.odu_port.name = 'odu_port'


            class OduPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: odu_current
                
                	port current performance data
                	**type**\:   :py:class:`OduCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.odu_current = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent()
                    self.odu_current.parent = self


                class OduCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: odu_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`OduHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24>`
                    
                    .. attribute:: odu_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`OduMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.odu_hour24 = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24()
                        self.odu_hour24.parent = self
                        self.odu_minute15 = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15()
                        self.odu_minute15.parent = self


                    class OduMinute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: odu_minute15gfps
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduMinute15Gfps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps>`
                        
                        .. attribute:: odu_minute15otns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduMinute15Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns>`
                        
                        .. attribute:: odu_minute15prbses
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduMinute15Prbses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.odu_minute15gfps = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps()
                            self.odu_minute15gfps.parent = self
                            self.odu_minute15otns = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns()
                            self.odu_minute15otns.parent = self
                            self.odu_minute15prbses = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses()
                            self.odu_minute15prbses.parent = self


                        class OduMinute15Gfps(object):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15gfp
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of    :py:class:`OduMinute15Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.odu_minute15gfp = YList()
                                self.odu_minute15gfp.parent = self
                                self.odu_minute15gfp.name = 'odu_minute15gfp'


                            class OduMinute15Gfp(object):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: rx_bit_err
                                
                                	RX BIT ERR
                                	**type**\:   :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxBitErr>`
                                
                                .. attribute:: rx_crc
                                
                                	RX CRC
                                	**type**\:   :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCrc>`
                                
                                .. attribute:: rx_csf
                                
                                	RX CSF
                                	**type**\:   :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCsf>`
                                
                                .. attribute:: rx_inv_typ
                                
                                	RX INV TYP
                                	**type**\:   :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxInvTyp>`
                                
                                .. attribute:: rx_lfd
                                
                                	RX LFD
                                	**type**\:   :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxLfd>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.rx_bit_err = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxBitErr()
                                    self.rx_bit_err.parent = self
                                    self.rx_crc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCrc()
                                    self.rx_crc.parent = self
                                    self.rx_csf = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCsf()
                                    self.rx_csf.parent = self
                                    self.rx_inv_typ = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxInvTyp()
                                    self.rx_inv_typ.parent = self
                                    self.rx_lfd = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxLfd()
                                    self.rx_lfd.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.valid = None


                                class RxBitErr(object):
                                    """
                                    RX BIT ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-bit-err'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxBitErr']['meta_info']


                                class RxInvTyp(object):
                                    """
                                    RX INV TYP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-inv-typ'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxInvTyp']['meta_info']


                                class RxCrc(object):
                                    """
                                    RX CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-crc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCrc']['meta_info']


                                class RxLfd(object):
                                    """
                                    RX LFD
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-lfd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxLfd']['meta_info']


                                class RxCsf(object):
                                    """
                                    RX CSF
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-csf'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCsf']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15gfp[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.rx_bit_err is not None and self.rx_bit_err._has_data():
                                        return True

                                    if self.rx_crc is not None and self.rx_crc._has_data():
                                        return True

                                    if self.rx_csf is not None and self.rx_csf._has_data():
                                        return True

                                    if self.rx_inv_typ is not None and self.rx_inv_typ._has_data():
                                        return True

                                    if self.rx_lfd is not None and self.rx_lfd._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15gfps'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.odu_minute15gfp is not None:
                                    for child_ref in self.odu_minute15gfp:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps']['meta_info']


                        class OduMinute15Prbses(object):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15prbs
                            
                            	port 15\-minute prbs performance data
                            	**type**\: list of    :py:class:`OduMinute15Prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.odu_minute15prbs = YList()
                                self.odu_minute15prbs.parent = self
                                self.odu_minute15prbs.name = 'odu_minute15prbs'


                            class OduMinute15Prbs(object):
                                """
                                port 15\-minute prbs performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: conf_patt
                                
                                	CONFIG PTRN
                                	**type**\:   :py:class:`PmPrbsPatternEtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEtEnum>`
                                
                                .. attribute:: ebc
                                
                                	EBC
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: found_at_time
                                
                                	FOUND AT TS
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: found_count
                                
                                	FOUND COUNT
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: lost_at_time
                                
                                	LOST AT TS
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: lost_count
                                
                                	LOST COUNT
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rcv_patt
                                
                                	RCVD PTRN
                                	**type**\:   :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs.RcvPatt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.conf_patt = None
                                    self.ebc = None
                                    self.found_at_time = None
                                    self.found_count = None
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.lost_at_time = None
                                    self.lost_count = None
                                    self.rcv_patt = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs.RcvPatt()
                                    self.rcv_patt.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class RcvPatt(object):
                                    """
                                    RCVD PTRN
                                    
                                    .. attribute:: rcv_patt
                                    
                                    	RCVD PTRN
                                    	**type**\:   :py:class:`PmPrbsPatternEtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEtEnum>`
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.rcv_patt = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rcv-patt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rcv_patt is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs.RcvPatt']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15prbs[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.conf_patt is not None:
                                        return True

                                    if self.ebc is not None:
                                        return True

                                    if self.found_at_time is not None:
                                        return True

                                    if self.found_count is not None:
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lost_at_time is not None:
                                        return True

                                    if self.lost_count is not None:
                                        return True

                                    if self.rcv_patt is not None and self.rcv_patt._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15prbses'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.odu_minute15prbs is not None:
                                    for child_ref in self.odu_minute15prbs:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses']['meta_info']


                        class OduMinute15Otns(object):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15otn
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of    :py:class:`OduMinute15Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.odu_minute15otn = YList()
                                self.odu_minute15otn.parent = self
                                self.odu_minute15otn.name = 'odu_minute15otn'


                            class OduMinute15Otn(object):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.bbe_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self.bbe_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self.bber_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self.bber_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self.es_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsFe()
                                    self.es_fe.parent = self
                                    self.es_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsNe()
                                    self.es_ne.parent = self
                                    self.esr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self.esr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self.fc_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self.fc_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.Lbc()
                                    self.lbc.parent = self
                                    self.sec30_support = None
                                    self.ses_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self.ses_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self.sesr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self.sesr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self.timestamp = None
                                    self.uas_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self.uas_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.Lbc']['meta_info']


                                class EsNe(object):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsNe']['meta_info']


                                class EsrNe(object):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrNe']['meta_info']


                                class SesNe(object):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesNe']['meta_info']


                                class SesrNe(object):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrNe']['meta_info']


                                class UasNe(object):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasNe']['meta_info']


                                class BbeNe(object):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeNe']['meta_info']


                                class BberNe(object):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberNe']['meta_info']


                                class FcNe(object):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcNe']['meta_info']


                                class EsFe(object):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsFe']['meta_info']


                                class EsrFe(object):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrFe']['meta_info']


                                class SesFe(object):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesFe']['meta_info']


                                class SesrFe(object):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrFe']['meta_info']


                                class UasFe(object):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasFe']['meta_info']


                                class BbeFe(object):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeFe']['meta_info']


                                class BberFe(object):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberFe']['meta_info']


                                class FcFe(object):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcFe']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15otn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.bbe_fe is not None and self.bbe_fe._has_data():
                                        return True

                                    if self.bbe_ne is not None and self.bbe_ne._has_data():
                                        return True

                                    if self.bber_fe is not None and self.bber_fe._has_data():
                                        return True

                                    if self.bber_ne is not None and self.bber_ne._has_data():
                                        return True

                                    if self.es_fe is not None and self.es_fe._has_data():
                                        return True

                                    if self.es_ne is not None and self.es_ne._has_data():
                                        return True

                                    if self.esr_fe is not None and self.esr_fe._has_data():
                                        return True

                                    if self.esr_ne is not None and self.esr_ne._has_data():
                                        return True

                                    if self.fc_fe is not None and self.fc_fe._has_data():
                                        return True

                                    if self.fc_ne is not None and self.fc_ne._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.ses_fe is not None and self.ses_fe._has_data():
                                        return True

                                    if self.ses_ne is not None and self.ses_ne._has_data():
                                        return True

                                    if self.sesr_fe is not None and self.sesr_fe._has_data():
                                        return True

                                    if self.sesr_ne is not None and self.sesr_ne._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uas_fe is not None and self.uas_fe._has_data():
                                        return True

                                    if self.uas_ne is not None and self.uas_ne._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15otns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.odu_minute15otn is not None:
                                    for child_ref in self.odu_minute15otn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.odu_minute15gfps is not None and self.odu_minute15gfps._has_data():
                                return True

                            if self.odu_minute15otns is not None and self.odu_minute15otns._has_data():
                                return True

                            if self.odu_minute15prbses is not None and self.odu_minute15prbses._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15']['meta_info']


                    class OduHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: odu_hour24gfps
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OduHour24Gfps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps>`
                        
                        .. attribute:: odu_hour24otns
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OduHour24Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns>`
                        
                        .. attribute:: odu_hour24prbses
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OduHour24Prbses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.odu_hour24gfps = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps()
                            self.odu_hour24gfps.parent = self
                            self.odu_hour24otns = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns()
                            self.odu_hour24otns.parent = self
                            self.odu_hour24prbses = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses()
                            self.odu_hour24prbses.parent = self


                        class OduHour24Prbses(object):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: odu_hour24prbs
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`OduHour24Prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.odu_hour24prbs = YList()
                                self.odu_hour24prbs.parent = self
                                self.odu_hour24prbs.name = 'odu_hour24prbs'


                            class OduHour24Prbs(object):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: conf_patt
                                
                                	CONFIG PTRN
                                	**type**\:   :py:class:`PmPrbsPatternEtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEtEnum>`
                                
                                .. attribute:: ebc
                                
                                	EBC
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: found_at_time
                                
                                	FOUND AT TS
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: found_count
                                
                                	FOUND COUNT
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: lost_at_time
                                
                                	LOST AT TS
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: lost_count
                                
                                	LOST COUNT
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rcv_patt
                                
                                	RCVD PTRN
                                	**type**\:   :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs.RcvPatt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.conf_patt = None
                                    self.ebc = None
                                    self.found_at_time = None
                                    self.found_count = None
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.lost_at_time = None
                                    self.lost_count = None
                                    self.rcv_patt = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs.RcvPatt()
                                    self.rcv_patt.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class RcvPatt(object):
                                    """
                                    RCVD PTRN
                                    
                                    .. attribute:: rcv_patt
                                    
                                    	RCVD PTRN
                                    	**type**\:   :py:class:`PmPrbsPatternEtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEtEnum>`
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.rcv_patt = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rcv-patt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rcv_patt is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs.RcvPatt']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24prbs[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.conf_patt is not None:
                                        return True

                                    if self.ebc is not None:
                                        return True

                                    if self.found_at_time is not None:
                                        return True

                                    if self.found_count is not None:
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lost_at_time is not None:
                                        return True

                                    if self.lost_count is not None:
                                        return True

                                    if self.rcv_patt is not None and self.rcv_patt._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24prbses'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.odu_hour24prbs is not None:
                                    for child_ref in self.odu_hour24prbs:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses']['meta_info']


                        class OduHour24Gfps(object):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: odu_hour24gfp
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`OduHour24Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.odu_hour24gfp = YList()
                                self.odu_hour24gfp.parent = self
                                self.odu_hour24gfp.name = 'odu_hour24gfp'


                            class OduHour24Gfp(object):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: rx_bit_err
                                
                                	RX BIT ERR
                                	**type**\:   :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxBitErr>`
                                
                                .. attribute:: rx_crc
                                
                                	RX CRC
                                	**type**\:   :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCrc>`
                                
                                .. attribute:: rx_csf
                                
                                	RX CSF
                                	**type**\:   :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCsf>`
                                
                                .. attribute:: rx_inv_typ
                                
                                	RX INV TYP
                                	**type**\:   :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxInvTyp>`
                                
                                .. attribute:: rx_lfd
                                
                                	RX LFD
                                	**type**\:   :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxLfd>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.rx_bit_err = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxBitErr()
                                    self.rx_bit_err.parent = self
                                    self.rx_crc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCrc()
                                    self.rx_crc.parent = self
                                    self.rx_csf = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCsf()
                                    self.rx_csf.parent = self
                                    self.rx_inv_typ = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxInvTyp()
                                    self.rx_inv_typ.parent = self
                                    self.rx_lfd = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxLfd()
                                    self.rx_lfd.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.valid = None


                                class RxBitErr(object):
                                    """
                                    RX BIT ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-bit-err'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxBitErr']['meta_info']


                                class RxInvTyp(object):
                                    """
                                    RX INV TYP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-inv-typ'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxInvTyp']['meta_info']


                                class RxCrc(object):
                                    """
                                    RX CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-crc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCrc']['meta_info']


                                class RxLfd(object):
                                    """
                                    RX LFD
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-lfd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxLfd']['meta_info']


                                class RxCsf(object):
                                    """
                                    RX CSF
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-csf'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCsf']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24gfp[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.rx_bit_err is not None and self.rx_bit_err._has_data():
                                        return True

                                    if self.rx_crc is not None and self.rx_crc._has_data():
                                        return True

                                    if self.rx_csf is not None and self.rx_csf._has_data():
                                        return True

                                    if self.rx_inv_typ is not None and self.rx_inv_typ._has_data():
                                        return True

                                    if self.rx_lfd is not None and self.rx_lfd._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24gfps'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.odu_hour24gfp is not None:
                                    for child_ref in self.odu_hour24gfp:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps']['meta_info']


                        class OduHour24Otns(object):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: odu_hour24otn
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`OduHour24Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.odu_hour24otn = YList()
                                self.odu_hour24otn.parent = self
                                self.odu_hour24otn.name = 'odu_hour24otn'


                            class OduHour24Otn(object):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.bbe_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self.bbe_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self.bber_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self.bber_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self.es_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsFe()
                                    self.es_fe.parent = self
                                    self.es_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsNe()
                                    self.es_ne.parent = self
                                    self.esr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self.esr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self.fc_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self.fc_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.Lbc()
                                    self.lbc.parent = self
                                    self.sec30_support = None
                                    self.ses_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self.ses_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self.sesr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self.sesr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self.timestamp = None
                                    self.uas_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self.uas_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.Lbc']['meta_info']


                                class EsNe(object):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsNe']['meta_info']


                                class EsrNe(object):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrNe']['meta_info']


                                class SesNe(object):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesNe']['meta_info']


                                class SesrNe(object):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrNe']['meta_info']


                                class UasNe(object):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasNe']['meta_info']


                                class BbeNe(object):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeNe']['meta_info']


                                class BberNe(object):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberNe']['meta_info']


                                class FcNe(object):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcNe']['meta_info']


                                class EsFe(object):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsFe']['meta_info']


                                class EsrFe(object):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrFe']['meta_info']


                                class SesFe(object):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesFe']['meta_info']


                                class SesrFe(object):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrFe']['meta_info']


                                class UasFe(object):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasFe']['meta_info']


                                class BbeFe(object):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeFe']['meta_info']


                                class BberFe(object):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberFe']['meta_info']


                                class FcFe(object):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcFe']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24otn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.bbe_fe is not None and self.bbe_fe._has_data():
                                        return True

                                    if self.bbe_ne is not None and self.bbe_ne._has_data():
                                        return True

                                    if self.bber_fe is not None and self.bber_fe._has_data():
                                        return True

                                    if self.bber_ne is not None and self.bber_ne._has_data():
                                        return True

                                    if self.es_fe is not None and self.es_fe._has_data():
                                        return True

                                    if self.es_ne is not None and self.es_ne._has_data():
                                        return True

                                    if self.esr_fe is not None and self.esr_fe._has_data():
                                        return True

                                    if self.esr_ne is not None and self.esr_ne._has_data():
                                        return True

                                    if self.fc_fe is not None and self.fc_fe._has_data():
                                        return True

                                    if self.fc_ne is not None and self.fc_ne._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.ses_fe is not None and self.ses_fe._has_data():
                                        return True

                                    if self.ses_ne is not None and self.ses_ne._has_data():
                                        return True

                                    if self.sesr_fe is not None and self.sesr_fe._has_data():
                                        return True

                                    if self.sesr_ne is not None and self.sesr_ne._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uas_fe is not None and self.uas_fe._has_data():
                                        return True

                                    if self.uas_ne is not None and self.uas_ne._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24otns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.odu_hour24otn is not None:
                                    for child_ref in self.odu_hour24otn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.odu_hour24gfps is not None and self.odu_hour24gfps._has_data():
                                return True

                            if self.odu_hour24otns is not None and self.odu_hour24otns._has_data():
                                return True

                            if self.odu_hour24prbses is not None and self.odu_hour24prbses._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.odu_hour24 is not None and self.odu_hour24._has_data():
                            return True

                        if self.odu_minute15 is not None and self.odu_minute15._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:odu/Cisco-IOS-XR-pmengine-oper:odu-ports/Cisco-IOS-XR-pmengine-oper:odu-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.odu_current is not None and self.odu_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.Odu.OduPorts.OduPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:odu/Cisco-IOS-XR-pmengine-oper:odu-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.odu_port is not None:
                    for child_ref in self.odu_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.Odu.OduPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:odu'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.odu_ports is not None and self.odu_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.Odu']['meta_info']


    class Otu(object):
        """
        OTU controller performance data
        
        .. attribute:: otu_ports
        
        	Port performance data
        	**type**\:   :py:class:`OtuPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.otu_ports = PerformanceManagement.Otu.OtuPorts()
            self.otu_ports.parent = self


        class OtuPorts(object):
            """
            Port performance data
            
            .. attribute:: otu_port
            
            	Port performance data
            	**type**\: list of    :py:class:`OtuPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.otu_port = YList()
                self.otu_port.parent = self
                self.otu_port.name = 'otu_port'


            class OtuPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: otu_current
                
                	port current performance data
                	**type**\:   :py:class:`OtuCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.otu_current = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent()
                    self.otu_current.parent = self


                class OtuCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: otu_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`OtuHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24>`
                    
                    .. attribute:: otu_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`OtuMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15>`
                    
                    .. attribute:: otu_second30
                    
                    	port current performance data
                    	**type**\:   :py:class:`OtuSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.otu_hour24 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24()
                        self.otu_hour24.parent = self
                        self.otu_minute15 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15()
                        self.otu_minute15.parent = self
                        self.otu_second30 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30()
                        self.otu_second30.parent = self


                    class OtuMinute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: otu_minute15fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuMinute15Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs>`
                        
                        .. attribute:: otu_minute15otns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuMinute15Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.otu_minute15fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs()
                            self.otu_minute15fecs.parent = self
                            self.otu_minute15otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns()
                            self.otu_minute15otns.parent = self


                        class OtuMinute15Fecs(object):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15fec
                            
                            	port 15\-minute fec performance data
                            	**type**\: list of    :py:class:`OtuMinute15Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.otu_minute15fec = YList()
                                self.otu_minute15fec.parent = self
                                self.otu_minute15fec.name = 'otu_minute15fec'


                            class OtuMinute15Fec(object):
                                """
                                port 15\-minute fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Q()
                                    self.q.parent = self
                                    self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.UcWords()
                                    self.uc_words.parent = self
                                    self.valid = None


                                class EcBits(object):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.EcBits']['meta_info']


                                class UcWords(object):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.UcWords']['meta_info']


                                class PreFecBer(object):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PreFecBer']['meta_info']


                                class PostFecBer(object):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PostFecBer']['meta_info']


                                class Q(object):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Q']['meta_info']


                                class Qmargin(object):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Qmargin']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15fec[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.ec_bits is not None and self.ec_bits._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                        return True

                                    if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                        return True

                                    if self.q is not None and self.q._has_data():
                                        return True

                                    if self.qmargin is not None and self.qmargin._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uc_words is not None and self.uc_words._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15fecs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.otu_minute15fec is not None:
                                    for child_ref in self.otu_minute15fec:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs']['meta_info']


                        class OtuMinute15Otns(object):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15otn
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of    :py:class:`OtuMinute15Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.otu_minute15otn = YList()
                                self.otu_minute15otn.parent = self
                                self.otu_minute15otn.name = 'otu_minute15otn'


                            class OtuMinute15Otn(object):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsFe()
                                    self.es_fe.parent = self
                                    self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsNe()
                                    self.es_ne.parent = self
                                    self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.Lbc()
                                    self.lbc.parent = self
                                    self.sec30_support = None
                                    self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self.timestamp = None
                                    self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.Lbc']['meta_info']


                                class EsNe(object):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsNe']['meta_info']


                                class EsrNe(object):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrNe']['meta_info']


                                class SesNe(object):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesNe']['meta_info']


                                class SesrNe(object):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrNe']['meta_info']


                                class UasNe(object):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasNe']['meta_info']


                                class BbeNe(object):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeNe']['meta_info']


                                class BberNe(object):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberNe']['meta_info']


                                class FcNe(object):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcNe']['meta_info']


                                class EsFe(object):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsFe']['meta_info']


                                class EsrFe(object):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrFe']['meta_info']


                                class SesFe(object):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesFe']['meta_info']


                                class SesrFe(object):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrFe']['meta_info']


                                class UasFe(object):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasFe']['meta_info']


                                class BbeFe(object):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeFe']['meta_info']


                                class BberFe(object):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberFe']['meta_info']


                                class FcFe(object):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcFe']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15otn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.bbe_fe is not None and self.bbe_fe._has_data():
                                        return True

                                    if self.bbe_ne is not None and self.bbe_ne._has_data():
                                        return True

                                    if self.bber_fe is not None and self.bber_fe._has_data():
                                        return True

                                    if self.bber_ne is not None and self.bber_ne._has_data():
                                        return True

                                    if self.es_fe is not None and self.es_fe._has_data():
                                        return True

                                    if self.es_ne is not None and self.es_ne._has_data():
                                        return True

                                    if self.esr_fe is not None and self.esr_fe._has_data():
                                        return True

                                    if self.esr_ne is not None and self.esr_ne._has_data():
                                        return True

                                    if self.fc_fe is not None and self.fc_fe._has_data():
                                        return True

                                    if self.fc_ne is not None and self.fc_ne._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.ses_fe is not None and self.ses_fe._has_data():
                                        return True

                                    if self.ses_ne is not None and self.ses_ne._has_data():
                                        return True

                                    if self.sesr_fe is not None and self.sesr_fe._has_data():
                                        return True

                                    if self.sesr_ne is not None and self.sesr_ne._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uas_fe is not None and self.uas_fe._has_data():
                                        return True

                                    if self.uas_ne is not None and self.uas_ne._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15otns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.otu_minute15otn is not None:
                                    for child_ref in self.otu_minute15otn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.otu_minute15fecs is not None and self.otu_minute15fecs._has_data():
                                return True

                            if self.otu_minute15otns is not None and self.otu_minute15otns._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15']['meta_info']


                    class OtuSecond30(object):
                        """
                        port current performance data
                        
                        .. attribute:: otu_second30fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuSecond30Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs>`
                        
                        .. attribute:: otu_second30otns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuSecond30Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.otu_second30fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs()
                            self.otu_second30fecs.parent = self
                            self.otu_second30otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns()
                            self.otu_second30otns.parent = self


                        class OtuSecond30Fecs(object):
                            """
                            port current performance data
                            
                            .. attribute:: otu_second30fec
                            
                            	port 30\-sec fec performance data
                            	**type**\: list of    :py:class:`OtuSecond30Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.otu_second30fec = YList()
                                self.otu_second30fec.parent = self
                                self.otu_second30fec.name = 'otu_second30fec'


                            class OtuSecond30Fec(object):
                                """
                                port 30\-sec fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Q()
                                    self.q.parent = self
                                    self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.UcWords()
                                    self.uc_words.parent = self
                                    self.valid = None


                                class EcBits(object):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.EcBits']['meta_info']


                                class UcWords(object):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.UcWords']['meta_info']


                                class PreFecBer(object):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PreFecBer']['meta_info']


                                class PostFecBer(object):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PostFecBer']['meta_info']


                                class Q(object):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Q']['meta_info']


                                class Qmargin(object):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Qmargin']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30fec[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.ec_bits is not None and self.ec_bits._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                        return True

                                    if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                        return True

                                    if self.q is not None and self.q._has_data():
                                        return True

                                    if self.qmargin is not None and self.qmargin._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uc_words is not None and self.uc_words._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30fecs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.otu_second30fec is not None:
                                    for child_ref in self.otu_second30fec:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs']['meta_info']


                        class OtuSecond30Otns(object):
                            """
                            port current performance data
                            
                            .. attribute:: otu_second30otn
                            
                            	port 30\-sec otn performance data
                            	**type**\: list of    :py:class:`OtuSecond30Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.otu_second30otn = YList()
                                self.otu_second30otn.parent = self
                                self.otu_second30otn.name = 'otu_second30otn'


                            class OtuSecond30Otn(object):
                                """
                                port 30\-sec otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsFe()
                                    self.es_fe.parent = self
                                    self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsNe()
                                    self.es_ne.parent = self
                                    self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.Lbc()
                                    self.lbc.parent = self
                                    self.sec30_support = None
                                    self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self.timestamp = None
                                    self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.Lbc']['meta_info']


                                class EsNe(object):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsNe']['meta_info']


                                class EsrNe(object):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrNe']['meta_info']


                                class SesNe(object):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesNe']['meta_info']


                                class SesrNe(object):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrNe']['meta_info']


                                class UasNe(object):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasNe']['meta_info']


                                class BbeNe(object):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeNe']['meta_info']


                                class BberNe(object):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberNe']['meta_info']


                                class FcNe(object):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcNe']['meta_info']


                                class EsFe(object):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsFe']['meta_info']


                                class EsrFe(object):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrFe']['meta_info']


                                class SesFe(object):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesFe']['meta_info']


                                class SesrFe(object):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrFe']['meta_info']


                                class UasFe(object):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasFe']['meta_info']


                                class BbeFe(object):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeFe']['meta_info']


                                class BberFe(object):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberFe']['meta_info']


                                class FcFe(object):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcFe']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30otn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.bbe_fe is not None and self.bbe_fe._has_data():
                                        return True

                                    if self.bbe_ne is not None and self.bbe_ne._has_data():
                                        return True

                                    if self.bber_fe is not None and self.bber_fe._has_data():
                                        return True

                                    if self.bber_ne is not None and self.bber_ne._has_data():
                                        return True

                                    if self.es_fe is not None and self.es_fe._has_data():
                                        return True

                                    if self.es_ne is not None and self.es_ne._has_data():
                                        return True

                                    if self.esr_fe is not None and self.esr_fe._has_data():
                                        return True

                                    if self.esr_ne is not None and self.esr_ne._has_data():
                                        return True

                                    if self.fc_fe is not None and self.fc_fe._has_data():
                                        return True

                                    if self.fc_ne is not None and self.fc_ne._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.ses_fe is not None and self.ses_fe._has_data():
                                        return True

                                    if self.ses_ne is not None and self.ses_ne._has_data():
                                        return True

                                    if self.sesr_fe is not None and self.sesr_fe._has_data():
                                        return True

                                    if self.sesr_ne is not None and self.sesr_ne._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uas_fe is not None and self.uas_fe._has_data():
                                        return True

                                    if self.uas_ne is not None and self.uas_ne._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30otns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.otu_second30otn is not None:
                                    for child_ref in self.otu_second30otn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.otu_second30fecs is not None and self.otu_second30fecs._has_data():
                                return True

                            if self.otu_second30otns is not None and self.otu_second30otns._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30']['meta_info']


                    class OtuHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: otu_hour24fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuHour24Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs>`
                        
                        .. attribute:: otu_hour24otns
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OtuHour24Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.otu_hour24fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs()
                            self.otu_hour24fecs.parent = self
                            self.otu_hour24otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns()
                            self.otu_hour24otns.parent = self


                        class OtuHour24Fecs(object):
                            """
                            port current performance data
                            
                            .. attribute:: otu_hour24fec
                            
                            	port 24 hour fec performance data
                            	**type**\: list of    :py:class:`OtuHour24Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.otu_hour24fec = YList()
                                self.otu_hour24fec.parent = self
                                self.otu_hour24fec.name = 'otu_hour24fec'


                            class OtuHour24Fec(object):
                                """
                                port 24 hour fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Q()
                                    self.q.parent = self
                                    self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.UcWords()
                                    self.uc_words.parent = self
                                    self.valid = None


                                class EcBits(object):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.EcBits']['meta_info']


                                class UcWords(object):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.UcWords']['meta_info']


                                class PreFecBer(object):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PreFecBer']['meta_info']


                                class PostFecBer(object):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PostFecBer']['meta_info']


                                class Q(object):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Q']['meta_info']


                                class Qmargin(object):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Qmargin']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24fec[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.ec_bits is not None and self.ec_bits._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                        return True

                                    if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                        return True

                                    if self.q is not None and self.q._has_data():
                                        return True

                                    if self.qmargin is not None and self.qmargin._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uc_words is not None and self.uc_words._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24fecs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.otu_hour24fec is not None:
                                    for child_ref in self.otu_hour24fec:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs']['meta_info']


                        class OtuHour24Otns(object):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: otu_hour24otn
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`OtuHour24Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.otu_hour24otn = YList()
                                self.otu_hour24otn.parent = self
                                self.otu_hour24otn.name = 'otu_hour24otn'


                            class OtuHour24Otn(object):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsFe()
                                    self.es_fe.parent = self
                                    self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsNe()
                                    self.es_ne.parent = self
                                    self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.Lbc()
                                    self.lbc.parent = self
                                    self.sec30_support = None
                                    self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self.timestamp = None
                                    self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.Lbc']['meta_info']


                                class EsNe(object):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsNe']['meta_info']


                                class EsrNe(object):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrNe']['meta_info']


                                class SesNe(object):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesNe']['meta_info']


                                class SesrNe(object):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrNe']['meta_info']


                                class UasNe(object):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasNe']['meta_info']


                                class BbeNe(object):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeNe']['meta_info']


                                class BberNe(object):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberNe']['meta_info']


                                class FcNe(object):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcNe']['meta_info']


                                class EsFe(object):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsFe']['meta_info']


                                class EsrFe(object):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrFe']['meta_info']


                                class SesFe(object):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesFe']['meta_info']


                                class SesrFe(object):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrFe']['meta_info']


                                class UasFe(object):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasFe']['meta_info']


                                class BbeFe(object):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeFe']['meta_info']


                                class BberFe(object):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberFe']['meta_info']


                                class FcFe(object):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcFe']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24otn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.bbe_fe is not None and self.bbe_fe._has_data():
                                        return True

                                    if self.bbe_ne is not None and self.bbe_ne._has_data():
                                        return True

                                    if self.bber_fe is not None and self.bber_fe._has_data():
                                        return True

                                    if self.bber_ne is not None and self.bber_ne._has_data():
                                        return True

                                    if self.es_fe is not None and self.es_fe._has_data():
                                        return True

                                    if self.es_ne is not None and self.es_ne._has_data():
                                        return True

                                    if self.esr_fe is not None and self.esr_fe._has_data():
                                        return True

                                    if self.esr_ne is not None and self.esr_ne._has_data():
                                        return True

                                    if self.fc_fe is not None and self.fc_fe._has_data():
                                        return True

                                    if self.fc_ne is not None and self.fc_ne._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.ses_fe is not None and self.ses_fe._has_data():
                                        return True

                                    if self.ses_ne is not None and self.ses_ne._has_data():
                                        return True

                                    if self.sesr_fe is not None and self.sesr_fe._has_data():
                                        return True

                                    if self.sesr_ne is not None and self.sesr_ne._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uas_fe is not None and self.uas_fe._has_data():
                                        return True

                                    if self.uas_ne is not None and self.uas_ne._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24otns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.otu_hour24otn is not None:
                                    for child_ref in self.otu_hour24otn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.otu_hour24fecs is not None and self.otu_hour24fecs._has_data():
                                return True

                            if self.otu_hour24otns is not None and self.otu_hour24otns._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.otu_hour24 is not None and self.otu_hour24._has_data():
                            return True

                        if self.otu_minute15 is not None and self.otu_minute15._has_data():
                            return True

                        if self.otu_second30 is not None and self.otu_second30._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:otu/Cisco-IOS-XR-pmengine-oper:otu-ports/Cisco-IOS-XR-pmengine-oper:otu-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.otu_current is not None and self.otu_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.Otu.OtuPorts.OtuPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:otu/Cisco-IOS-XR-pmengine-oper:otu-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.otu_port is not None:
                    for child_ref in self.otu_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.Otu.OtuPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:otu'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.otu_ports is not None and self.otu_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.Otu']['meta_info']


    class Stm(object):
        """
        STM controller performance data
        
        .. attribute:: stm_ports
        
        	Port performance data
        	**type**\:   :py:class:`StmPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.stm_ports = PerformanceManagement.Stm.StmPorts()
            self.stm_ports.parent = self


        class StmPorts(object):
            """
            Port performance data
            
            .. attribute:: stm_port
            
            	Port performance data
            	**type**\: list of    :py:class:`StmPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.stm_port = YList()
                self.stm_port.parent = self
                self.stm_port.name = 'stm_port'


            class StmPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: stm_current
                
                	port current performance data
                	**type**\:   :py:class:`StmCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.stm_current = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent()
                    self.stm_current.parent = self


                class StmCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: stm_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`StmHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24>`
                    
                    .. attribute:: stm_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`StmMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.stm_hour24 = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24()
                        self.stm_hour24.parent = self
                        self.stm_minute15 = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15()
                        self.stm_minute15.parent = self


                    class StmHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: stm_hour24stms
                        
                        	port current performance data
                        	**type**\:   :py:class:`StmHour24Stms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.stm_hour24stms = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms()
                            self.stm_hour24stms.parent = self


                        class StmHour24Stms(object):
                            """
                            port current performance data
                            
                            .. attribute:: stm_hour24stm
                            
                            	port 24 hour stm performance data
                            	**type**\: list of    :py:class:`StmHour24Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.stm_hour24stm = YList()
                                self.stm_hour24stm.parent = self
                                self.stm_hour24stm.name = 'stm_hour24stm'


                            class StmHour24Stm(object):
                                """
                                port 24 hour stm performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine()
                                    self.fe_line.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line()
                                    self.line.parent = self
                                    self.section = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section()
                                    self.section.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Section(object):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbEs>`
                                    
                                    .. attribute:: section_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbeRs>`
                                    
                                    .. attribute:: section_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEBs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionESs>`
                                    
                                    .. attribute:: section_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEsRs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSesRs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: section_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.section_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbEs()
                                        self.section_bb_es.parent = self
                                        self.section_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbeRs()
                                        self.section_bbe_rs.parent = self
                                        self.section_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEBs()
                                        self.section_e_bs.parent = self
                                        self.section_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self.section_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEsRs()
                                        self.section_es_rs.parent = self
                                        self.section_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self.section_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSesRs()
                                        self.section_ses_rs.parent = self
                                        self.section_status = None
                                        self.section_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionUaSs()
                                        self.section_ua_ss.parent = self


                                    class SectionESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionESs']['meta_info']


                                    class SectionEsRs(object):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-es-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEsRs']['meta_info']


                                    class SectionBbEs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-bb-es'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbEs']['meta_info']


                                    class SectionBbeRs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-bbe-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbeRs']['meta_info']


                                    class SectionSeSs(object):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSeSs']['meta_info']


                                    class SectionSesRs(object):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-ses-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSesRs']['meta_info']


                                    class SectionUaSs(object):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionUaSs']['meta_info']


                                    class SectionEBs(object):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-bs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEBs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.section_bb_es is not None and self.section_bb_es._has_data():
                                            return True

                                        if self.section_bbe_rs is not None and self.section_bbe_rs._has_data():
                                            return True

                                        if self.section_e_bs is not None and self.section_e_bs._has_data():
                                            return True

                                        if self.section_e_ss is not None and self.section_e_ss._has_data():
                                            return True

                                        if self.section_es_rs is not None and self.section_es_rs._has_data():
                                            return True

                                        if self.section_se_ss is not None and self.section_se_ss._has_data():
                                            return True

                                        if self.section_ses_rs is not None and self.section_ses_rs._has_data():
                                            return True

                                        if self.section_status is not None:
                                            return True

                                        if self.section_ua_ss is not None and self.section_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section']['meta_info']


                                class Line(object):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbEs>`
                                    
                                    .. attribute:: line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbeRs>`
                                    
                                    .. attribute:: line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEBs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineESs>`
                                    
                                    .. attribute:: line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEsRs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSeSs>`
                                    
                                    .. attribute:: line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSesRs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.line_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbEs()
                                        self.line_bb_es.parent = self
                                        self.line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbeRs()
                                        self.line_bbe_rs.parent = self
                                        self.line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEBs()
                                        self.line_e_bs.parent = self
                                        self.line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self.line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEsRs()
                                        self.line_es_rs.parent = self
                                        self.line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self.line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSesRs()
                                        self.line_ses_rs.parent = self
                                        self.line_status = None
                                        self.line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineUaSs()
                                        self.line_ua_ss.parent = self


                                    class LineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineESs']['meta_info']


                                    class LineEsRs(object):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-es-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEsRs']['meta_info']


                                    class LineBbEs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-bb-es'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbEs']['meta_info']


                                    class LineBbeRs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-bbe-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbeRs']['meta_info']


                                    class LineSeSs(object):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSeSs']['meta_info']


                                    class LineSesRs(object):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ses-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSesRs']['meta_info']


                                    class LineUaSs(object):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineUaSs']['meta_info']


                                    class LineEBs(object):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-bs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEBs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.line_bb_es is not None and self.line_bb_es._has_data():
                                            return True

                                        if self.line_bbe_rs is not None and self.line_bbe_rs._has_data():
                                            return True

                                        if self.line_e_bs is not None and self.line_e_bs._has_data():
                                            return True

                                        if self.line_e_ss is not None and self.line_e_ss._has_data():
                                            return True

                                        if self.line_es_rs is not None and self.line_es_rs._has_data():
                                            return True

                                        if self.line_se_ss is not None and self.line_se_ss._has_data():
                                            return True

                                        if self.line_ses_rs is not None and self.line_ses_rs._has_data():
                                            return True

                                        if self.line_status is not None:
                                            return True

                                        if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line']['meta_info']


                                class FeLine(object):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineBbeRs>`
                                    
                                    .. attribute:: far_end_line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEBs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_ebb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEbbEs>`
                                    
                                    .. attribute:: far_end_line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEsRs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSesRs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineBbeRs()
                                        self.far_end_line_bbe_rs.parent = self
                                        self.far_end_line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEBs()
                                        self.far_end_line_e_bs.parent = self
                                        self.far_end_line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self.far_end_line_ebb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEbbEs()
                                        self.far_end_line_ebb_es.parent = self
                                        self.far_end_line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEsRs()
                                        self.far_end_line_es_rs.parent = self
                                        self.far_end_line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self.far_end_line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSesRs()
                                        self.far_end_line_ses_rs.parent = self
                                        self.far_end_line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self


                                    class FarEndLineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineESs']['meta_info']


                                    class FarEndLineEsRs(object):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-es-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEsRs']['meta_info']


                                    class FarEndLineEbbEs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ebb-es'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEbbEs']['meta_info']


                                    class FarEndLineBbeRs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-bbe-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineBbeRs']['meta_info']


                                    class FarEndLineSeSs(object):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSeSs']['meta_info']


                                    class FarEndLineSesRs(object):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ses-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSesRs']['meta_info']


                                    class FarEndLineUaSs(object):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineUaSs']['meta_info']


                                    class FarEndLineEBs(object):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-bs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEBs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs._has_data():
                                            return True

                                        if self.far_end_line_e_bs is not None and self.far_end_line_e_bs._has_data():
                                            return True

                                        if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                            return True

                                        if self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es._has_data():
                                            return True

                                        if self.far_end_line_es_rs is not None and self.far_end_line_es_rs._has_data():
                                            return True

                                        if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                            return True

                                        if self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs._has_data():
                                            return True

                                        if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-hour24stm[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_line is not None and self.fe_line._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.line is not None and self.line._has_data():
                                        return True

                                    if self.section is not None and self.section._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-hour24stms'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.stm_hour24stm is not None:
                                    for child_ref in self.stm_hour24stm:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.stm_hour24stms is not None and self.stm_hour24stms._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24']['meta_info']


                    class StmMinute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: stm_minute15stms
                        
                        	port current performance data
                        	**type**\:   :py:class:`StmMinute15Stms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.stm_minute15stms = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms()
                            self.stm_minute15stms.parent = self


                        class StmMinute15Stms(object):
                            """
                            port current performance data
                            
                            .. attribute:: stm_minute15stm
                            
                            	port 15\-minute stm performance data
                            	**type**\: list of    :py:class:`StmMinute15Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.stm_minute15stm = YList()
                                self.stm_minute15stm.parent = self
                                self.stm_minute15stm.name = 'stm_minute15stm'


                            class StmMinute15Stm(object):
                                """
                                port 15\-minute stm performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine()
                                    self.fe_line.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line()
                                    self.line.parent = self
                                    self.section = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section()
                                    self.section.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Section(object):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbEs>`
                                    
                                    .. attribute:: section_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbeRs>`
                                    
                                    .. attribute:: section_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEBs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionESs>`
                                    
                                    .. attribute:: section_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEsRs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSesRs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: section_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.section_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbEs()
                                        self.section_bb_es.parent = self
                                        self.section_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbeRs()
                                        self.section_bbe_rs.parent = self
                                        self.section_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEBs()
                                        self.section_e_bs.parent = self
                                        self.section_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self.section_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEsRs()
                                        self.section_es_rs.parent = self
                                        self.section_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self.section_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSesRs()
                                        self.section_ses_rs.parent = self
                                        self.section_status = None
                                        self.section_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionUaSs()
                                        self.section_ua_ss.parent = self


                                    class SectionESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionESs']['meta_info']


                                    class SectionEsRs(object):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-es-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEsRs']['meta_info']


                                    class SectionBbEs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-bb-es'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbEs']['meta_info']


                                    class SectionBbeRs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-bbe-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbeRs']['meta_info']


                                    class SectionSeSs(object):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSeSs']['meta_info']


                                    class SectionSesRs(object):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-ses-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSesRs']['meta_info']


                                    class SectionUaSs(object):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionUaSs']['meta_info']


                                    class SectionEBs(object):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-bs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEBs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.section_bb_es is not None and self.section_bb_es._has_data():
                                            return True

                                        if self.section_bbe_rs is not None and self.section_bbe_rs._has_data():
                                            return True

                                        if self.section_e_bs is not None and self.section_e_bs._has_data():
                                            return True

                                        if self.section_e_ss is not None and self.section_e_ss._has_data():
                                            return True

                                        if self.section_es_rs is not None and self.section_es_rs._has_data():
                                            return True

                                        if self.section_se_ss is not None and self.section_se_ss._has_data():
                                            return True

                                        if self.section_ses_rs is not None and self.section_ses_rs._has_data():
                                            return True

                                        if self.section_status is not None:
                                            return True

                                        if self.section_ua_ss is not None and self.section_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section']['meta_info']


                                class Line(object):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbEs>`
                                    
                                    .. attribute:: line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbeRs>`
                                    
                                    .. attribute:: line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEBs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineESs>`
                                    
                                    .. attribute:: line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEsRs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSeSs>`
                                    
                                    .. attribute:: line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSesRs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.line_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbEs()
                                        self.line_bb_es.parent = self
                                        self.line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbeRs()
                                        self.line_bbe_rs.parent = self
                                        self.line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEBs()
                                        self.line_e_bs.parent = self
                                        self.line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self.line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEsRs()
                                        self.line_es_rs.parent = self
                                        self.line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self.line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSesRs()
                                        self.line_ses_rs.parent = self
                                        self.line_status = None
                                        self.line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineUaSs()
                                        self.line_ua_ss.parent = self


                                    class LineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineESs']['meta_info']


                                    class LineEsRs(object):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-es-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEsRs']['meta_info']


                                    class LineBbEs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-bb-es'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbEs']['meta_info']


                                    class LineBbeRs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-bbe-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbeRs']['meta_info']


                                    class LineSeSs(object):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSeSs']['meta_info']


                                    class LineSesRs(object):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ses-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSesRs']['meta_info']


                                    class LineUaSs(object):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineUaSs']['meta_info']


                                    class LineEBs(object):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-bs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEBs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.line_bb_es is not None and self.line_bb_es._has_data():
                                            return True

                                        if self.line_bbe_rs is not None and self.line_bbe_rs._has_data():
                                            return True

                                        if self.line_e_bs is not None and self.line_e_bs._has_data():
                                            return True

                                        if self.line_e_ss is not None and self.line_e_ss._has_data():
                                            return True

                                        if self.line_es_rs is not None and self.line_es_rs._has_data():
                                            return True

                                        if self.line_se_ss is not None and self.line_se_ss._has_data():
                                            return True

                                        if self.line_ses_rs is not None and self.line_ses_rs._has_data():
                                            return True

                                        if self.line_status is not None:
                                            return True

                                        if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line']['meta_info']


                                class FeLine(object):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineBbeRs>`
                                    
                                    .. attribute:: far_end_line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEBs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_ebb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEbbEs>`
                                    
                                    .. attribute:: far_end_line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEsRs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSesRs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineBbeRs()
                                        self.far_end_line_bbe_rs.parent = self
                                        self.far_end_line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEBs()
                                        self.far_end_line_e_bs.parent = self
                                        self.far_end_line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self.far_end_line_ebb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEbbEs()
                                        self.far_end_line_ebb_es.parent = self
                                        self.far_end_line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEsRs()
                                        self.far_end_line_es_rs.parent = self
                                        self.far_end_line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self.far_end_line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSesRs()
                                        self.far_end_line_ses_rs.parent = self
                                        self.far_end_line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self


                                    class FarEndLineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineESs']['meta_info']


                                    class FarEndLineEsRs(object):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-es-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEsRs']['meta_info']


                                    class FarEndLineEbbEs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ebb-es'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEbbEs']['meta_info']


                                    class FarEndLineBbeRs(object):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-bbe-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineBbeRs']['meta_info']


                                    class FarEndLineSeSs(object):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSeSs']['meta_info']


                                    class FarEndLineSesRs(object):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ses-rs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSesRs']['meta_info']


                                    class FarEndLineUaSs(object):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineUaSs']['meta_info']


                                    class FarEndLineEBs(object):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-bs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEBs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs._has_data():
                                            return True

                                        if self.far_end_line_e_bs is not None and self.far_end_line_e_bs._has_data():
                                            return True

                                        if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                            return True

                                        if self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es._has_data():
                                            return True

                                        if self.far_end_line_es_rs is not None and self.far_end_line_es_rs._has_data():
                                            return True

                                        if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                            return True

                                        if self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs._has_data():
                                            return True

                                        if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-minute15stm[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_line is not None and self.fe_line._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.line is not None and self.line._has_data():
                                        return True

                                    if self.section is not None and self.section._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-minute15stms'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.stm_minute15stm is not None:
                                    for child_ref in self.stm_minute15stm:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.stm_minute15stms is not None and self.stm_minute15stms._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.stm_hour24 is not None and self.stm_hour24._has_data():
                            return True

                        if self.stm_minute15 is not None and self.stm_minute15._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:stm/Cisco-IOS-XR-pmengine-oper:stm-ports/Cisco-IOS-XR-pmengine-oper:stm-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.stm_current is not None and self.stm_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.Stm.StmPorts.StmPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:stm/Cisco-IOS-XR-pmengine-oper:stm-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.stm_port is not None:
                    for child_ref in self.stm_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.Stm.StmPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:stm'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.stm_ports is not None and self.stm_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.Stm']['meta_info']


    class Sonet(object):
        """
        SONET controller performance data
        
        .. attribute:: sonet_ports
        
        	Port performance data
        	**type**\:   :py:class:`SonetPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.sonet_ports = PerformanceManagement.Sonet.SonetPorts()
            self.sonet_ports.parent = self


        class SonetPorts(object):
            """
            Port performance data
            
            .. attribute:: sonet_port
            
            	Port performance data
            	**type**\: list of    :py:class:`SonetPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.sonet_port = YList()
                self.sonet_port.parent = self
                self.sonet_port.name = 'sonet_port'


            class SonetPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: sonet_current
                
                	port current performance data
                	**type**\:   :py:class:`SonetCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.sonet_current = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent()
                    self.sonet_current.parent = self


                class SonetCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: sonet_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`SonetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24>`
                    
                    .. attribute:: sonet_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`SonetMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.sonet_hour24 = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24()
                        self.sonet_hour24.parent = self
                        self.sonet_minute15 = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15()
                        self.sonet_minute15.parent = self


                    class SonetMinute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: sonet_minute15_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetMinute15Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths>`
                        
                        .. attribute:: sonet_minute15ocns
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetMinute15Ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.sonet_minute15_paths = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths()
                            self.sonet_minute15_paths.parent = self
                            self.sonet_minute15ocns = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns()
                            self.sonet_minute15ocns.parent = self


                        class SonetMinute15Paths(object):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_minute15_path
                            
                            	port 15\-minute Path performance data
                            	**type**\: list of    :py:class:`SonetMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sonet_minute15_path = YList()
                                self.sonet_minute15_path.parent = self
                                self.sonet_minute15_path.name = 'sonet_minute15_path'


                            class SonetMinute15Path(object):
                                """
                                port 15\-minute Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath()
                                    self.fe_path.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path()
                                    self.path.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Path(object):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:   :py:class:`PmSonetPathWidthEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnumEnum>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.path_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self.path_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self.path_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self.path_status = None
                                        self.path_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self.path_width = None


                                    class PathESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs']['meta_info']


                                    class PathSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs']['meta_info']


                                    class PathCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs']['meta_info']


                                    class PathUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path_c_vs is not None and self.path_c_vs._has_data():
                                            return True

                                        if self.path_e_ss is not None and self.path_e_ss._has_data():
                                            return True

                                        if self.path_se_ss is not None and self.path_se_ss._has_data():
                                            return True

                                        if self.path_status is not None:
                                            return True

                                        if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                            return True

                                        if self.path_width is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path']['meta_info']


                                class FePath(object):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_ua_ss = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_path_c_vs is not None:
                                            return True

                                        if self.far_end_path_e_ss is not None:
                                            return True

                                        if self.far_end_path_se_ss is not None:
                                            return True

                                        if self.far_end_path_ua_ss is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15-path[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_path is not None and self.fe_path._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.path is not None and self.path._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15-paths'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sonet_minute15_path is not None:
                                    for child_ref in self.sonet_minute15_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths']['meta_info']


                        class SonetMinute15Ocns(object):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_minute15ocn
                            
                            	port 15\-minute ocn performance data
                            	**type**\: list of    :py:class:`SonetMinute15Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sonet_minute15ocn = YList()
                                self.sonet_minute15ocn.parent = self
                                self.sonet_minute15ocn.name = 'sonet_minute15ocn'


                            class SonetMinute15Ocn(object):
                                """
                                port 15\-minute ocn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine()
                                    self.fe_line.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line()
                                    self.line.parent = self
                                    self.section = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section()
                                    self.section.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Section(object):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.section_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self.section_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self.section_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self.section_sef_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self.section_status = None


                                    class SectionESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionESs']['meta_info']


                                    class SectionSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSeSs']['meta_info']


                                    class SectionSefSs(object):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-sef-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSefSs']['meta_info']


                                    class SectionCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionCVs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.section_c_vs is not None and self.section_c_vs._has_data():
                                            return True

                                        if self.section_e_ss is not None and self.section_e_ss._has_data():
                                            return True

                                        if self.section_se_ss is not None and self.section_se_ss._has_data():
                                            return True

                                        if self.section_sef_ss is not None and self.section_sef_ss._has_data():
                                            return True

                                        if self.section_status is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section']['meta_info']


                                class Line(object):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self.line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self.line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self.line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self.line_status = None
                                        self.line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self


                                    class LineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineESs']['meta_info']


                                    class LineSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineSeSs']['meta_info']


                                    class LineCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineCVs']['meta_info']


                                    class LineUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineUaSs']['meta_info']


                                    class LineFcLs(object):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-fc-ls'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineFcLs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.line_c_vs is not None and self.line_c_vs._has_data():
                                            return True

                                        if self.line_e_ss is not None and self.line_e_ss._has_data():
                                            return True

                                        if self.line_fc_ls is not None and self.line_fc_ls._has_data():
                                            return True

                                        if self.line_se_ss is not None and self.line_se_ss._has_data():
                                            return True

                                        if self.line_status is not None:
                                            return True

                                        if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line']['meta_info']


                                class FeLine(object):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineFcLs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self.far_end_line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self.far_end_line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self.far_end_line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self.far_end_line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self


                                    class FarEndLineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineESs']['meta_info']


                                    class FarEndLineSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineSeSs']['meta_info']


                                    class FarEndLineCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineCVs']['meta_info']


                                    class FarEndLineUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineUaSs']['meta_info']


                                    class FarEndLineFcLs(object):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-fc-ls'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineFcLs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_line_c_vs is not None and self.far_end_line_c_vs._has_data():
                                            return True

                                        if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                            return True

                                        if self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls._has_data():
                                            return True

                                        if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                            return True

                                        if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15ocn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_line is not None and self.fe_line._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.line is not None and self.line._has_data():
                                        return True

                                    if self.section is not None and self.section._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15ocns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sonet_minute15ocn is not None:
                                    for child_ref in self.sonet_minute15ocn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.sonet_minute15_paths is not None and self.sonet_minute15_paths._has_data():
                                return True

                            if self.sonet_minute15ocns is not None and self.sonet_minute15ocns._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15']['meta_info']


                    class SonetHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: sonet_hour24_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetHour24Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths>`
                        
                        .. attribute:: sonet_hour24ocns
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetHour24Ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.sonet_hour24_paths = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths()
                            self.sonet_hour24_paths.parent = self
                            self.sonet_hour24ocns = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns()
                            self.sonet_hour24ocns.parent = self


                        class SonetHour24Ocns(object):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_hour24ocn
                            
                            	port 24 hour ocn performance data
                            	**type**\: list of    :py:class:`SonetHour24Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sonet_hour24ocn = YList()
                                self.sonet_hour24ocn.parent = self
                                self.sonet_hour24ocn.name = 'sonet_hour24ocn'


                            class SonetHour24Ocn(object):
                                """
                                port 24 hour ocn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine()
                                    self.fe_line.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line()
                                    self.line.parent = self
                                    self.section = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section()
                                    self.section.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Section(object):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.section_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self.section_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self.section_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self.section_sef_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self.section_status = None


                                    class SectionESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionESs']['meta_info']


                                    class SectionSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSeSs']['meta_info']


                                    class SectionSefSs(object):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-sef-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSefSs']['meta_info']


                                    class SectionCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionCVs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.section_c_vs is not None and self.section_c_vs._has_data():
                                            return True

                                        if self.section_e_ss is not None and self.section_e_ss._has_data():
                                            return True

                                        if self.section_se_ss is not None and self.section_se_ss._has_data():
                                            return True

                                        if self.section_sef_ss is not None and self.section_sef_ss._has_data():
                                            return True

                                        if self.section_status is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section']['meta_info']


                                class Line(object):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self.line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self.line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self.line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self.line_status = None
                                        self.line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self


                                    class LineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineESs']['meta_info']


                                    class LineSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineSeSs']['meta_info']


                                    class LineCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineCVs']['meta_info']


                                    class LineUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineUaSs']['meta_info']


                                    class LineFcLs(object):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-fc-ls'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineFcLs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.line_c_vs is not None and self.line_c_vs._has_data():
                                            return True

                                        if self.line_e_ss is not None and self.line_e_ss._has_data():
                                            return True

                                        if self.line_fc_ls is not None and self.line_fc_ls._has_data():
                                            return True

                                        if self.line_se_ss is not None and self.line_se_ss._has_data():
                                            return True

                                        if self.line_status is not None:
                                            return True

                                        if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line']['meta_info']


                                class FeLine(object):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineFcLs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self.far_end_line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self.far_end_line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self.far_end_line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self.far_end_line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self


                                    class FarEndLineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineESs']['meta_info']


                                    class FarEndLineSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineSeSs']['meta_info']


                                    class FarEndLineCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineCVs']['meta_info']


                                    class FarEndLineUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineUaSs']['meta_info']


                                    class FarEndLineFcLs(object):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-fc-ls'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineFcLs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_line_c_vs is not None and self.far_end_line_c_vs._has_data():
                                            return True

                                        if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                            return True

                                        if self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls._has_data():
                                            return True

                                        if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                            return True

                                        if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24ocn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_line is not None and self.fe_line._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.line is not None and self.line._has_data():
                                        return True

                                    if self.section is not None and self.section._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24ocns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sonet_hour24ocn is not None:
                                    for child_ref in self.sonet_hour24ocn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns']['meta_info']


                        class SonetHour24Paths(object):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_hour24_path
                            
                            	port 24 hour Path performance data
                            	**type**\: list of    :py:class:`SonetHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sonet_hour24_path = YList()
                                self.sonet_hour24_path.parent = self
                                self.sonet_hour24_path.name = 'sonet_hour24_path'


                            class SonetHour24Path(object):
                                """
                                port 24 hour Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath()
                                    self.fe_path.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path()
                                    self.path.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Path(object):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:   :py:class:`PmSonetPathWidthEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnumEnum>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.path_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self.path_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self.path_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self.path_status = None
                                        self.path_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self.path_width = None


                                    class PathESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs']['meta_info']


                                    class PathSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs']['meta_info']


                                    class PathCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs']['meta_info']


                                    class PathUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path_c_vs is not None and self.path_c_vs._has_data():
                                            return True

                                        if self.path_e_ss is not None and self.path_e_ss._has_data():
                                            return True

                                        if self.path_se_ss is not None and self.path_se_ss._has_data():
                                            return True

                                        if self.path_status is not None:
                                            return True

                                        if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                            return True

                                        if self.path_width is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path']['meta_info']


                                class FePath(object):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_ua_ss = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_path_c_vs is not None:
                                            return True

                                        if self.far_end_path_e_ss is not None:
                                            return True

                                        if self.far_end_path_se_ss is not None:
                                            return True

                                        if self.far_end_path_ua_ss is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24-path[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_path is not None and self.fe_path._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.path is not None and self.path._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24-paths'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sonet_hour24_path is not None:
                                    for child_ref in self.sonet_hour24_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.sonet_hour24_paths is not None and self.sonet_hour24_paths._has_data():
                                return True

                            if self.sonet_hour24ocns is not None and self.sonet_hour24ocns._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.sonet_hour24 is not None and self.sonet_hour24._has_data():
                            return True

                        if self.sonet_minute15 is not None and self.sonet_minute15._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:sonet/Cisco-IOS-XR-pmengine-oper:sonet-ports/Cisco-IOS-XR-pmengine-oper:sonet-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.sonet_current is not None and self.sonet_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.Sonet.SonetPorts.SonetPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:sonet/Cisco-IOS-XR-pmengine-oper:sonet-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.sonet_port is not None:
                    for child_ref in self.sonet_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.Sonet.SonetPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:sonet'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.sonet_ports is not None and self.sonet_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.Sonet']['meta_info']


    class Optics(object):
        """
        OPTICS controller performance data
        
        .. attribute:: optics_ports
        
        	Port performance data
        	**type**\:   :py:class:`OpticsPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.optics_ports = PerformanceManagement.Optics.OpticsPorts()
            self.optics_ports.parent = self


        class OpticsPorts(object):
            """
            Port performance data
            
            .. attribute:: optics_port
            
            	Port performance data
            	**type**\: list of    :py:class:`OpticsPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.optics_port = YList()
                self.optics_port.parent = self
                self.optics_port.name = 'optics_port'


            class OpticsPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: optics_current
                
                	port current performance data
                	**type**\:   :py:class:`OpticsCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.optics_current = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent()
                    self.optics_current.parent = self


                class OpticsCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: optics_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`OpticsHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24>`
                    
                    .. attribute:: optics_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`OpticsMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15>`
                    
                    .. attribute:: optics_second30
                    
                    	port current performance data
                    	**type**\:   :py:class:`OpticsSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.optics_hour24 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24()
                        self.optics_hour24.parent = self
                        self.optics_minute15 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15()
                        self.optics_minute15.parent = self
                        self.optics_second30 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30()
                        self.optics_second30.parent = self


                    class OpticsHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: optics_hour24_optics
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OpticsHour24Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics>`
                        
                        .. attribute:: optics_hour24fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsHour24Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.optics_hour24_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics()
                            self.optics_hour24_optics.parent = self
                            self.optics_hour24fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs()
                            self.optics_hour24fecs.parent = self


                        class OpticsHour24Optics(object):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: optics_hour24_optic
                            
                            	port 24 hour optics performance data
                            	**type**\: list of    :py:class:`OpticsHour24Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.optics_hour24_optic = YList()
                                self.optics_hour24_optic.parent = self
                                self.optics_hour24_optic.name = 'optics_hour24_optic'


                            class OpticsHour24Optic(object):
                                """
                                port 24 hour optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd()
                                    self.cd.parent = self
                                    self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd()
                                    self.dgd.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc()
                                    self.lbc.parent = self
                                    self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr()
                                    self.opr.parent = self
                                    self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt()
                                    self.opt.parent = self
                                    self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr()
                                    self.osnr.parent = self
                                    self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr()
                                    self.pcr.parent = self
                                    self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl()
                                    self.pdl.parent = self
                                    self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd()
                                    self.pmd.parent = self
                                    self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn()
                                    self.pn.parent = self
                                    self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc']['meta_info']


                                class LbcPc(object):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc']['meta_info']


                                class Opt(object):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt']['meta_info']


                                class Opr(object):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr']['meta_info']


                                class Cd(object):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd']['meta_info']


                                class Dgd(object):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd']['meta_info']


                                class Pmd(object):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd']['meta_info']


                                class Osnr(object):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr']['meta_info']


                                class CenterWavelength(object):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength']['meta_info']


                                class Pdl(object):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl']['meta_info']


                                class Pcr(object):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr']['meta_info']


                                class Pn(object):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn']['meta_info']


                                class RxSigPow(object):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow']['meta_info']


                                class LowSigFreqOff(object):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24-optic[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.cd is not None and self.cd._has_data():
                                        return True

                                    if self.center_wavelength is not None and self.center_wavelength._has_data():
                                        return True

                                    if self.dgd is not None and self.dgd._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.lbc_pc is not None and self.lbc_pc._has_data():
                                        return True

                                    if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                        return True

                                    if self.opr is not None and self.opr._has_data():
                                        return True

                                    if self.opt is not None and self.opt._has_data():
                                        return True

                                    if self.osnr is not None and self.osnr._has_data():
                                        return True

                                    if self.pcr is not None and self.pcr._has_data():
                                        return True

                                    if self.pdl is not None and self.pdl._has_data():
                                        return True

                                    if self.pmd is not None and self.pmd._has_data():
                                        return True

                                    if self.pn is not None and self.pn._has_data():
                                        return True

                                    if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24-optics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.optics_hour24_optic is not None:
                                    for child_ref in self.optics_hour24_optic:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics']['meta_info']


                        class OpticsHour24Fecs(object):
                            """
                            port current performance data
                            
                            .. attribute:: optics_hour24fec
                            
                            	port 24 hour fec performance data
                            	**type**\: list of    :py:class:`OpticsHour24Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.optics_hour24fec = YList()
                                self.optics_hour24fec.parent = self
                                self.optics_hour24fec.name = 'optics_hour24fec'


                            class OpticsHour24Fec(object):
                                """
                                port 24 hour fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Q()
                                    self.q.parent = self
                                    self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.UcWords()
                                    self.uc_words.parent = self
                                    self.valid = None


                                class EcBits(object):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.EcBits']['meta_info']


                                class UcWords(object):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.UcWords']['meta_info']


                                class PreFecBer(object):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PreFecBer']['meta_info']


                                class PostFecBer(object):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PostFecBer']['meta_info']


                                class Q(object):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Q']['meta_info']


                                class Qmargin(object):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Qmargin']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24fec[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.ec_bits is not None and self.ec_bits._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                        return True

                                    if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                        return True

                                    if self.q is not None and self.q._has_data():
                                        return True

                                    if self.qmargin is not None and self.qmargin._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uc_words is not None and self.uc_words._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24fecs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.optics_hour24fec is not None:
                                    for child_ref in self.optics_hour24fec:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.optics_hour24_optics is not None and self.optics_hour24_optics._has_data():
                                return True

                            if self.optics_hour24fecs is not None and self.optics_hour24fecs._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24']['meta_info']


                    class OpticsMinute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: optics_minute15_optics
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsMinute15Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics>`
                        
                        .. attribute:: optics_minute15fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsMinute15Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.optics_minute15_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics()
                            self.optics_minute15_optics.parent = self
                            self.optics_minute15fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs()
                            self.optics_minute15fecs.parent = self


                        class OpticsMinute15Optics(object):
                            """
                            port current performance data
                            
                            .. attribute:: optics_minute15_optic
                            
                            	port 15\-minute optics performance data
                            	**type**\: list of    :py:class:`OpticsMinute15Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.optics_minute15_optic = YList()
                                self.optics_minute15_optic.parent = self
                                self.optics_minute15_optic.name = 'optics_minute15_optic'


                            class OpticsMinute15Optic(object):
                                """
                                port 15\-minute optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd()
                                    self.cd.parent = self
                                    self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd()
                                    self.dgd.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc()
                                    self.lbc.parent = self
                                    self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr()
                                    self.opr.parent = self
                                    self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt()
                                    self.opt.parent = self
                                    self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr()
                                    self.osnr.parent = self
                                    self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr()
                                    self.pcr.parent = self
                                    self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl()
                                    self.pdl.parent = self
                                    self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd()
                                    self.pmd.parent = self
                                    self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn()
                                    self.pn.parent = self
                                    self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc']['meta_info']


                                class LbcPc(object):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc']['meta_info']


                                class Opt(object):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt']['meta_info']


                                class Opr(object):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr']['meta_info']


                                class Cd(object):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd']['meta_info']


                                class Dgd(object):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd']['meta_info']


                                class Pmd(object):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd']['meta_info']


                                class Osnr(object):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr']['meta_info']


                                class CenterWavelength(object):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength']['meta_info']


                                class Pdl(object):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl']['meta_info']


                                class Pcr(object):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr']['meta_info']


                                class Pn(object):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn']['meta_info']


                                class RxSigPow(object):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow']['meta_info']


                                class LowSigFreqOff(object):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15-optic[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.cd is not None and self.cd._has_data():
                                        return True

                                    if self.center_wavelength is not None and self.center_wavelength._has_data():
                                        return True

                                    if self.dgd is not None and self.dgd._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.lbc_pc is not None and self.lbc_pc._has_data():
                                        return True

                                    if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                        return True

                                    if self.opr is not None and self.opr._has_data():
                                        return True

                                    if self.opt is not None and self.opt._has_data():
                                        return True

                                    if self.osnr is not None and self.osnr._has_data():
                                        return True

                                    if self.pcr is not None and self.pcr._has_data():
                                        return True

                                    if self.pdl is not None and self.pdl._has_data():
                                        return True

                                    if self.pmd is not None and self.pmd._has_data():
                                        return True

                                    if self.pn is not None and self.pn._has_data():
                                        return True

                                    if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15-optics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.optics_minute15_optic is not None:
                                    for child_ref in self.optics_minute15_optic:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics']['meta_info']


                        class OpticsMinute15Fecs(object):
                            """
                            port current performance data
                            
                            .. attribute:: optics_minute15fec
                            
                            	port 15\-minute fec performance data
                            	**type**\: list of    :py:class:`OpticsMinute15Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.optics_minute15fec = YList()
                                self.optics_minute15fec.parent = self
                                self.optics_minute15fec.name = 'optics_minute15fec'


                            class OpticsMinute15Fec(object):
                                """
                                port 15\-minute fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Q()
                                    self.q.parent = self
                                    self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.UcWords()
                                    self.uc_words.parent = self
                                    self.valid = None


                                class EcBits(object):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.EcBits']['meta_info']


                                class UcWords(object):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.UcWords']['meta_info']


                                class PreFecBer(object):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PreFecBer']['meta_info']


                                class PostFecBer(object):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PostFecBer']['meta_info']


                                class Q(object):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Q']['meta_info']


                                class Qmargin(object):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Qmargin']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15fec[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.ec_bits is not None and self.ec_bits._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                        return True

                                    if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                        return True

                                    if self.q is not None and self.q._has_data():
                                        return True

                                    if self.qmargin is not None and self.qmargin._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uc_words is not None and self.uc_words._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15fecs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.optics_minute15fec is not None:
                                    for child_ref in self.optics_minute15fec:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.optics_minute15_optics is not None and self.optics_minute15_optics._has_data():
                                return True

                            if self.optics_minute15fecs is not None and self.optics_minute15fecs._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15']['meta_info']


                    class OpticsSecond30(object):
                        """
                        port current performance data
                        
                        .. attribute:: optics_second30_optics
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsSecond30Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics>`
                        
                        .. attribute:: optics_second30fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsSecond30Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.optics_second30_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics()
                            self.optics_second30_optics.parent = self
                            self.optics_second30fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs()
                            self.optics_second30fecs.parent = self


                        class OpticsSecond30Fecs(object):
                            """
                            port current performance data
                            
                            .. attribute:: optics_second30fec
                            
                            	port 30\-second fec performance data
                            	**type**\: list of    :py:class:`OpticsSecond30Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.optics_second30fec = YList()
                                self.optics_second30fec.parent = self
                                self.optics_second30fec.name = 'optics_second30fec'


                            class OpticsSecond30Fec(object):
                                """
                                port 30\-second fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Q()
                                    self.q.parent = self
                                    self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.UcWords()
                                    self.uc_words.parent = self
                                    self.valid = None


                                class EcBits(object):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.EcBits']['meta_info']


                                class UcWords(object):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.UcWords']['meta_info']


                                class PreFecBer(object):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PreFecBer']['meta_info']


                                class PostFecBer(object):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PostFecBer']['meta_info']


                                class Q(object):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Q']['meta_info']


                                class Qmargin(object):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Qmargin']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30fec[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.ec_bits is not None and self.ec_bits._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                        return True

                                    if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                        return True

                                    if self.q is not None and self.q._has_data():
                                        return True

                                    if self.qmargin is not None and self.qmargin._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uc_words is not None and self.uc_words._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30fecs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.optics_second30fec is not None:
                                    for child_ref in self.optics_second30fec:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs']['meta_info']


                        class OpticsSecond30Optics(object):
                            """
                            port current performance data
                            
                            .. attribute:: optics_second30_optic
                            
                            	port 30\-second optics performance data
                            	**type**\: list of    :py:class:`OpticsSecond30Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.optics_second30_optic = YList()
                                self.optics_second30_optic.parent = self
                                self.optics_second30_optic.name = 'optics_second30_optic'


                            class OpticsSecond30Optic(object):
                                """
                                port 30\-second optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd()
                                    self.cd.parent = self
                                    self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd()
                                    self.dgd.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc()
                                    self.lbc.parent = self
                                    self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr()
                                    self.opr.parent = self
                                    self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt()
                                    self.opt.parent = self
                                    self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr()
                                    self.osnr.parent = self
                                    self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr()
                                    self.pcr.parent = self
                                    self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl()
                                    self.pdl.parent = self
                                    self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd()
                                    self.pmd.parent = self
                                    self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn()
                                    self.pn.parent = self
                                    self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc']['meta_info']


                                class LbcPc(object):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc']['meta_info']


                                class Opt(object):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt']['meta_info']


                                class Opr(object):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr']['meta_info']


                                class Cd(object):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd']['meta_info']


                                class Dgd(object):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd']['meta_info']


                                class Pmd(object):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd']['meta_info']


                                class Osnr(object):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr']['meta_info']


                                class CenterWavelength(object):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength']['meta_info']


                                class Pdl(object):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl']['meta_info']


                                class Pcr(object):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr']['meta_info']


                                class Pn(object):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn']['meta_info']


                                class RxSigPow(object):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow']['meta_info']


                                class LowSigFreqOff(object):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30-optic[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.cd is not None and self.cd._has_data():
                                        return True

                                    if self.center_wavelength is not None and self.center_wavelength._has_data():
                                        return True

                                    if self.dgd is not None and self.dgd._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.lbc_pc is not None and self.lbc_pc._has_data():
                                        return True

                                    if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                        return True

                                    if self.opr is not None and self.opr._has_data():
                                        return True

                                    if self.opt is not None and self.opt._has_data():
                                        return True

                                    if self.osnr is not None and self.osnr._has_data():
                                        return True

                                    if self.pcr is not None and self.pcr._has_data():
                                        return True

                                    if self.pdl is not None and self.pdl._has_data():
                                        return True

                                    if self.pmd is not None and self.pmd._has_data():
                                        return True

                                    if self.pn is not None and self.pn._has_data():
                                        return True

                                    if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30-optics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.optics_second30_optic is not None:
                                    for child_ref in self.optics_second30_optic:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.optics_second30_optics is not None and self.optics_second30_optics._has_data():
                                return True

                            if self.optics_second30fecs is not None and self.optics_second30fecs._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.optics_hour24 is not None and self.optics_hour24._has_data():
                            return True

                        if self.optics_minute15 is not None and self.optics_minute15._has_data():
                            return True

                        if self.optics_second30 is not None and self.optics_second30._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:optics/Cisco-IOS-XR-pmengine-oper:optics-ports/Cisco-IOS-XR-pmengine-oper:optics-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.optics_current is not None and self.optics_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.Optics.OpticsPorts.OpticsPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:optics/Cisco-IOS-XR-pmengine-oper:optics-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.optics_port is not None:
                    for child_ref in self.optics_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.Optics.OpticsPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:optics'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.optics_ports is not None and self.optics_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.Optics']['meta_info']


    class Sts(object):
        """
        STS controller performance data
        
        .. attribute:: sts_ports
        
        	Port performance data
        	**type**\:   :py:class:`StsPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.sts_ports = PerformanceManagement.Sts.StsPorts()
            self.sts_ports.parent = self


        class StsPorts(object):
            """
            Port performance data
            
            .. attribute:: sts_port
            
            	Port performance data
            	**type**\: list of    :py:class:`StsPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.sts_port = YList()
                self.sts_port.parent = self
                self.sts_port.name = 'sts_port'


            class StsPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: sts_current
                
                	port current performance data
                	**type**\:   :py:class:`StsCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.sts_current = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent()
                    self.sts_current.parent = self


                class StsCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: sts_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`StsHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24>`
                    
                    .. attribute:: sts_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`StsMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.sts_hour24 = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24()
                        self.sts_hour24.parent = self
                        self.sts_minute15 = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15()
                        self.sts_minute15.parent = self


                    class StsMinute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: sts_minute15_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`StsMinute15Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.sts_minute15_paths = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths()
                            self.sts_minute15_paths.parent = self


                        class StsMinute15Paths(object):
                            """
                            port current performance data
                            
                            .. attribute:: sts_minute15_path
                            
                            	port 15\-minute Path performance data
                            	**type**\: list of    :py:class:`StsMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sts_minute15_path = YList()
                                self.sts_minute15_path.parent = self
                                self.sts_minute15_path.name = 'sts_minute15_path'


                            class StsMinute15Path(object):
                                """
                                port 15\-minute Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath()
                                    self.fe_path.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path()
                                    self.path.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Path(object):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:   :py:class:`PmSonetPathWidthEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnumEnum>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.path_c_vs = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self.path_e_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self.path_se_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self.path_status = None
                                        self.path_ua_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self.path_width = None


                                    class PathESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs']['meta_info']


                                    class PathSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs']['meta_info']


                                    class PathCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs']['meta_info']


                                    class PathUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path_c_vs is not None and self.path_c_vs._has_data():
                                            return True

                                        if self.path_e_ss is not None and self.path_e_ss._has_data():
                                            return True

                                        if self.path_se_ss is not None and self.path_se_ss._has_data():
                                            return True

                                        if self.path_status is not None:
                                            return True

                                        if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                            return True

                                        if self.path_width is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path']['meta_info']


                                class FePath(object):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_ua_ss = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_path_c_vs is not None:
                                            return True

                                        if self.far_end_path_e_ss is not None:
                                            return True

                                        if self.far_end_path_se_ss is not None:
                                            return True

                                        if self.far_end_path_ua_ss is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-minute15-path[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_path is not None and self.fe_path._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.path is not None and self.path._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-minute15-paths'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sts_minute15_path is not None:
                                    for child_ref in self.sts_minute15_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.sts_minute15_paths is not None and self.sts_minute15_paths._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15']['meta_info']


                    class StsHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: sts_hour24_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`StsHour24Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.sts_hour24_paths = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths()
                            self.sts_hour24_paths.parent = self


                        class StsHour24Paths(object):
                            """
                            port current performance data
                            
                            .. attribute:: sts_hour24_path
                            
                            	port 24 hour Path performance data
                            	**type**\: list of    :py:class:`StsHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sts_hour24_path = YList()
                                self.sts_hour24_path.parent = self
                                self.sts_hour24_path.name = 'sts_hour24_path'


                            class StsHour24Path(object):
                                """
                                port 24 hour Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath()
                                    self.fe_path.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path()
                                    self.path.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Path(object):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:   :py:class:`PmSonetPathWidthEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnumEnum>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.path_c_vs = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self.path_e_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self.path_se_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self.path_status = None
                                        self.path_ua_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self.path_width = None


                                    class PathESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs']['meta_info']


                                    class PathSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs']['meta_info']


                                    class PathCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs']['meta_info']


                                    class PathUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path_c_vs is not None and self.path_c_vs._has_data():
                                            return True

                                        if self.path_e_ss is not None and self.path_e_ss._has_data():
                                            return True

                                        if self.path_se_ss is not None and self.path_se_ss._has_data():
                                            return True

                                        if self.path_status is not None:
                                            return True

                                        if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                            return True

                                        if self.path_width is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path']['meta_info']


                                class FePath(object):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_path_c_vs = None
                                        self.far_end_path_e_ss = None
                                        self.far_end_path_se_ss = None
                                        self.far_end_path_ua_ss = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_path_c_vs is not None:
                                            return True

                                        if self.far_end_path_e_ss is not None:
                                            return True

                                        if self.far_end_path_se_ss is not None:
                                            return True

                                        if self.far_end_path_ua_ss is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-hour24-path[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_path is not None and self.fe_path._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.path is not None and self.path._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-hour24-paths'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sts_hour24_path is not None:
                                    for child_ref in self.sts_hour24_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.sts_hour24_paths is not None and self.sts_hour24_paths._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.sts_hour24 is not None and self.sts_hour24._has_data():
                            return True

                        if self.sts_minute15 is not None and self.sts_minute15._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:sts/Cisco-IOS-XR-pmengine-oper:sts-ports/Cisco-IOS-XR-pmengine-oper:sts-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.sts_current is not None and self.sts_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.Sts.StsPorts.StsPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:sts/Cisco-IOS-XR-pmengine-oper:sts-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.sts_port is not None:
                    for child_ref in self.sts_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.Sts.StsPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:sts'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.sts_ports is not None and self.sts_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.Sts']['meta_info']


    class Dwdm(object):
        """
        DWDM controller performance data
        
        .. attribute:: dwdm_ports
        
        	Port performance data
        	**type**\:   :py:class:`DwdmPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.dwdm_ports = PerformanceManagement.Dwdm.DwdmPorts()
            self.dwdm_ports.parent = self


        class DwdmPorts(object):
            """
            Port performance data
            
            .. attribute:: dwdm_port
            
            	Port performance data
            	**type**\: list of    :py:class:`DwdmPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.dwdm_port = YList()
                self.dwdm_port.parent = self
                self.dwdm_port.name = 'dwdm_port'


            class DwdmPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: dwdm_current
                
                	port current performance data
                	**type**\:   :py:class:`DwdmCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.dwdm_current = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent()
                    self.dwdm_current.parent = self


                class DwdmCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: dwdm_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`DwdmHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24>`
                    
                    .. attribute:: dwdm_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`DwdmMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dwdm_hour24 = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24()
                        self.dwdm_hour24.parent = self
                        self.dwdm_minute15 = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15()
                        self.dwdm_minute15.parent = self


                    class DwdmMinute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: dwdm_minute15_optics
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmMinute15Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics>`
                        
                        .. attribute:: dwdm_minute15fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmMinute15Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs>`
                        
                        .. attribute:: dwdm_minute15otns
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmMinute15Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dwdm_minute15_optics = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics()
                            self.dwdm_minute15_optics.parent = self
                            self.dwdm_minute15fecs = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs()
                            self.dwdm_minute15fecs.parent = self
                            self.dwdm_minute15otns = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns()
                            self.dwdm_minute15otns.parent = self


                        class DwdmMinute15Fecs(object):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15fec
                            
                            	port 15\-minute fec performance data
                            	**type**\: list of    :py:class:`DwdmMinute15Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dwdm_minute15fec = YList()
                                self.dwdm_minute15fec.parent = self
                                self.dwdm_minute15fec.name = 'dwdm_minute15fec'


                            class DwdmMinute15Fec(object):
                                """
                                port 15\-minute fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.ec_bits = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.post_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self.pre_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self.q = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Q()
                                    self.q.parent = self
                                    self.qmargin = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.uc_words = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.UcWords()
                                    self.uc_words.parent = self
                                    self.valid = None


                                class EcBits(object):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.EcBits']['meta_info']


                                class UcWords(object):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.UcWords']['meta_info']


                                class PreFecBer(object):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PreFecBer']['meta_info']


                                class PostFecBer(object):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PostFecBer']['meta_info']


                                class Q(object):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Q']['meta_info']


                                class Qmargin(object):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Qmargin']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15fec[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.ec_bits is not None and self.ec_bits._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                        return True

                                    if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                        return True

                                    if self.q is not None and self.q._has_data():
                                        return True

                                    if self.qmargin is not None and self.qmargin._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uc_words is not None and self.uc_words._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15fecs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dwdm_minute15fec is not None:
                                    for child_ref in self.dwdm_minute15fec:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs']['meta_info']


                        class DwdmMinute15Optics(object):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15_optic
                            
                            	port 15\-minute optics performance data
                            	**type**\: list of    :py:class:`DwdmMinute15Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dwdm_minute15_optic = YList()
                                self.dwdm_minute15_optic.parent = self
                                self.dwdm_minute15_optic.name = 'dwdm_minute15_optic'


                            class DwdmMinute15Optic(object):
                                """
                                port 15\-minute optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.cd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd()
                                    self.cd.parent = self
                                    self.center_wavelength = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self.dgd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd()
                                    self.dgd.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc()
                                    self.lbc.parent = self
                                    self.lbc_pc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self.low_sig_freq_off = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self.opr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr()
                                    self.opr.parent = self
                                    self.opt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt()
                                    self.opt.parent = self
                                    self.osnr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr()
                                    self.osnr.parent = self
                                    self.pcr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr()
                                    self.pcr.parent = self
                                    self.pdl = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl()
                                    self.pdl.parent = self
                                    self.pmd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd()
                                    self.pmd.parent = self
                                    self.pn = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn()
                                    self.pn.parent = self
                                    self.rx_sig_pow = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc']['meta_info']


                                class LbcPc(object):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc']['meta_info']


                                class Opt(object):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt']['meta_info']


                                class Opr(object):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr']['meta_info']


                                class Cd(object):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd']['meta_info']


                                class Dgd(object):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd']['meta_info']


                                class Pmd(object):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd']['meta_info']


                                class Osnr(object):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr']['meta_info']


                                class CenterWavelength(object):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength']['meta_info']


                                class Pdl(object):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl']['meta_info']


                                class Pcr(object):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr']['meta_info']


                                class Pn(object):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn']['meta_info']


                                class RxSigPow(object):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow']['meta_info']


                                class LowSigFreqOff(object):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15-optic[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.cd is not None and self.cd._has_data():
                                        return True

                                    if self.center_wavelength is not None and self.center_wavelength._has_data():
                                        return True

                                    if self.dgd is not None and self.dgd._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.lbc_pc is not None and self.lbc_pc._has_data():
                                        return True

                                    if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                        return True

                                    if self.opr is not None and self.opr._has_data():
                                        return True

                                    if self.opt is not None and self.opt._has_data():
                                        return True

                                    if self.osnr is not None and self.osnr._has_data():
                                        return True

                                    if self.pcr is not None and self.pcr._has_data():
                                        return True

                                    if self.pdl is not None and self.pdl._has_data():
                                        return True

                                    if self.pmd is not None and self.pmd._has_data():
                                        return True

                                    if self.pn is not None and self.pn._has_data():
                                        return True

                                    if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15-optics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dwdm_minute15_optic is not None:
                                    for child_ref in self.dwdm_minute15_optic:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics']['meta_info']


                        class DwdmMinute15Otns(object):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15otn
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of    :py:class:`DwdmMinute15Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dwdm_minute15otn = YList()
                                self.dwdm_minute15otn.parent = self
                                self.dwdm_minute15otn.name = 'dwdm_minute15otn'


                            class DwdmMinute15Otn(object):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.bbe_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self.bbe_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self.bber_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self.bber_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self.es_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsFe()
                                    self.es_fe.parent = self
                                    self.es_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsNe()
                                    self.es_ne.parent = self
                                    self.esr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self.esr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self.fc_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self.fc_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.Lbc()
                                    self.lbc.parent = self
                                    self.sec30_support = None
                                    self.ses_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self.ses_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self.sesr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self.sesr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self.timestamp = None
                                    self.uas_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self.uas_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.Lbc']['meta_info']


                                class EsNe(object):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsNe']['meta_info']


                                class EsrNe(object):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrNe']['meta_info']


                                class SesNe(object):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesNe']['meta_info']


                                class SesrNe(object):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrNe']['meta_info']


                                class UasNe(object):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasNe']['meta_info']


                                class BbeNe(object):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeNe']['meta_info']


                                class BberNe(object):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberNe']['meta_info']


                                class FcNe(object):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcNe']['meta_info']


                                class EsFe(object):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsFe']['meta_info']


                                class EsrFe(object):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrFe']['meta_info']


                                class SesFe(object):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesFe']['meta_info']


                                class SesrFe(object):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrFe']['meta_info']


                                class UasFe(object):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasFe']['meta_info']


                                class BbeFe(object):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeFe']['meta_info']


                                class BberFe(object):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberFe']['meta_info']


                                class FcFe(object):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcFe']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15otn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.bbe_fe is not None and self.bbe_fe._has_data():
                                        return True

                                    if self.bbe_ne is not None and self.bbe_ne._has_data():
                                        return True

                                    if self.bber_fe is not None and self.bber_fe._has_data():
                                        return True

                                    if self.bber_ne is not None and self.bber_ne._has_data():
                                        return True

                                    if self.es_fe is not None and self.es_fe._has_data():
                                        return True

                                    if self.es_ne is not None and self.es_ne._has_data():
                                        return True

                                    if self.esr_fe is not None and self.esr_fe._has_data():
                                        return True

                                    if self.esr_ne is not None and self.esr_ne._has_data():
                                        return True

                                    if self.fc_fe is not None and self.fc_fe._has_data():
                                        return True

                                    if self.fc_ne is not None and self.fc_ne._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.ses_fe is not None and self.ses_fe._has_data():
                                        return True

                                    if self.ses_ne is not None and self.ses_ne._has_data():
                                        return True

                                    if self.sesr_fe is not None and self.sesr_fe._has_data():
                                        return True

                                    if self.sesr_ne is not None and self.sesr_ne._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uas_fe is not None and self.uas_fe._has_data():
                                        return True

                                    if self.uas_ne is not None and self.uas_ne._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15otns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dwdm_minute15otn is not None:
                                    for child_ref in self.dwdm_minute15otn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dwdm_minute15_optics is not None and self.dwdm_minute15_optics._has_data():
                                return True

                            if self.dwdm_minute15fecs is not None and self.dwdm_minute15fecs._has_data():
                                return True

                            if self.dwdm_minute15otns is not None and self.dwdm_minute15otns._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15']['meta_info']


                    class DwdmHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: dwdm_hour24_optics
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`DwdmHour24Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics>`
                        
                        .. attribute:: dwdm_hour24fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmHour24Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs>`
                        
                        .. attribute:: dwdm_hour24otns
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`DwdmHour24Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dwdm_hour24_optics = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics()
                            self.dwdm_hour24_optics.parent = self
                            self.dwdm_hour24fecs = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs()
                            self.dwdm_hour24fecs.parent = self
                            self.dwdm_hour24otns = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns()
                            self.dwdm_hour24otns.parent = self


                        class DwdmHour24Optics(object):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: dwdm_hour24_optic
                            
                            	port 24 hour optics performance data
                            	**type**\: list of    :py:class:`DwdmHour24Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dwdm_hour24_optic = YList()
                                self.dwdm_hour24_optic.parent = self
                                self.dwdm_hour24_optic.name = 'dwdm_hour24_optic'


                            class DwdmHour24Optic(object):
                                """
                                port 24 hour optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.cd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd()
                                    self.cd.parent = self
                                    self.center_wavelength = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self.dgd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd()
                                    self.dgd.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc()
                                    self.lbc.parent = self
                                    self.lbc_pc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self.low_sig_freq_off = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self.opr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr()
                                    self.opr.parent = self
                                    self.opt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt()
                                    self.opt.parent = self
                                    self.osnr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr()
                                    self.osnr.parent = self
                                    self.pcr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr()
                                    self.pcr.parent = self
                                    self.pdl = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl()
                                    self.pdl.parent = self
                                    self.pmd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd()
                                    self.pmd.parent = self
                                    self.pn = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn()
                                    self.pn.parent = self
                                    self.rx_sig_pow = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc']['meta_info']


                                class LbcPc(object):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc']['meta_info']


                                class Opt(object):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt']['meta_info']


                                class Opr(object):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr']['meta_info']


                                class Cd(object):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd']['meta_info']


                                class Dgd(object):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd']['meta_info']


                                class Pmd(object):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd']['meta_info']


                                class Osnr(object):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr']['meta_info']


                                class CenterWavelength(object):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength']['meta_info']


                                class Pdl(object):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl']['meta_info']


                                class Pcr(object):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr']['meta_info']


                                class Pn(object):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn']['meta_info']


                                class RxSigPow(object):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow']['meta_info']


                                class LowSigFreqOff(object):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24-optic[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.cd is not None and self.cd._has_data():
                                        return True

                                    if self.center_wavelength is not None and self.center_wavelength._has_data():
                                        return True

                                    if self.dgd is not None and self.dgd._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.lbc_pc is not None and self.lbc_pc._has_data():
                                        return True

                                    if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                        return True

                                    if self.opr is not None and self.opr._has_data():
                                        return True

                                    if self.opt is not None and self.opt._has_data():
                                        return True

                                    if self.osnr is not None and self.osnr._has_data():
                                        return True

                                    if self.pcr is not None and self.pcr._has_data():
                                        return True

                                    if self.pdl is not None and self.pdl._has_data():
                                        return True

                                    if self.pmd is not None and self.pmd._has_data():
                                        return True

                                    if self.pn is not None and self.pn._has_data():
                                        return True

                                    if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24-optics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dwdm_hour24_optic is not None:
                                    for child_ref in self.dwdm_hour24_optic:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics']['meta_info']


                        class DwdmHour24Fecs(object):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_hour24fec
                            
                            	port 24 hour fec performance data
                            	**type**\: list of    :py:class:`DwdmHour24Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dwdm_hour24fec = YList()
                                self.dwdm_hour24fec.parent = self
                                self.dwdm_hour24fec.name = 'dwdm_hour24fec'


                            class DwdmHour24Fec(object):
                                """
                                port 24 hour fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.ec_bits = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.post_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self.pre_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self.q = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Q()
                                    self.q.parent = self
                                    self.qmargin = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self.sec30_support = None
                                    self.timestamp = None
                                    self.uc_words = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.UcWords()
                                    self.uc_words.parent = self
                                    self.valid = None


                                class EcBits(object):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.EcBits']['meta_info']


                                class UcWords(object):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.UcWords']['meta_info']


                                class PreFecBer(object):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PreFecBer']['meta_info']


                                class PostFecBer(object):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PostFecBer']['meta_info']


                                class Q(object):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Q']['meta_info']


                                class Qmargin(object):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.average = None
                                        self.maximum = None
                                        self.maximum_tca_report = None
                                        self.maximum_threshold = None
                                        self.minimum = None
                                        self.minimum_tca_report = None
                                        self.minimum_threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.average is not None:
                                            return True

                                        if self.maximum is not None:
                                            return True

                                        if self.maximum_tca_report is not None:
                                            return True

                                        if self.maximum_threshold is not None:
                                            return True

                                        if self.minimum is not None:
                                            return True

                                        if self.minimum_tca_report is not None:
                                            return True

                                        if self.minimum_threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Qmargin']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24fec[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.ec_bits is not None and self.ec_bits._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                        return True

                                    if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                        return True

                                    if self.q is not None and self.q._has_data():
                                        return True

                                    if self.qmargin is not None and self.qmargin._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uc_words is not None and self.uc_words._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24fecs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dwdm_hour24fec is not None:
                                    for child_ref in self.dwdm_hour24fec:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs']['meta_info']


                        class DwdmHour24Otns(object):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: dwdm_hour24otn
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`DwdmHour24Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dwdm_hour24otn = YList()
                                self.dwdm_hour24otn.parent = self
                                self.dwdm_hour24otn.name = 'dwdm_hour24otn'


                            class DwdmHour24Otn(object):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.bbe_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self.bbe_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self.bber_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self.bber_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self.es_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsFe()
                                    self.es_fe.parent = self
                                    self.es_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsNe()
                                    self.es_ne.parent = self
                                    self.esr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self.esr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self.fc_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self.fc_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.Lbc()
                                    self.lbc.parent = self
                                    self.sec30_support = None
                                    self.ses_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self.ses_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self.sesr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self.sesr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self.timestamp = None
                                    self.uas_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self.uas_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self.valid = None


                                class Lbc(object):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.Lbc']['meta_info']


                                class EsNe(object):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsNe']['meta_info']


                                class EsrNe(object):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrNe']['meta_info']


                                class SesNe(object):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesNe']['meta_info']


                                class SesrNe(object):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrNe']['meta_info']


                                class UasNe(object):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasNe']['meta_info']


                                class BbeNe(object):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeNe']['meta_info']


                                class BberNe(object):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberNe']['meta_info']


                                class FcNe(object):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcNe']['meta_info']


                                class EsFe(object):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsFe']['meta_info']


                                class EsrFe(object):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrFe']['meta_info']


                                class SesFe(object):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesFe']['meta_info']


                                class SesrFe(object):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrFe']['meta_info']


                                class UasFe(object):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasFe']['meta_info']


                                class BbeFe(object):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeFe']['meta_info']


                                class BberFe(object):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberFe']['meta_info']


                                class FcFe(object):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcFe']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24otn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.bbe_fe is not None and self.bbe_fe._has_data():
                                        return True

                                    if self.bbe_ne is not None and self.bbe_ne._has_data():
                                        return True

                                    if self.bber_fe is not None and self.bber_fe._has_data():
                                        return True

                                    if self.bber_ne is not None and self.bber_ne._has_data():
                                        return True

                                    if self.es_fe is not None and self.es_fe._has_data():
                                        return True

                                    if self.es_ne is not None and self.es_ne._has_data():
                                        return True

                                    if self.esr_fe is not None and self.esr_fe._has_data():
                                        return True

                                    if self.esr_ne is not None and self.esr_ne._has_data():
                                        return True

                                    if self.fc_fe is not None and self.fc_fe._has_data():
                                        return True

                                    if self.fc_ne is not None and self.fc_ne._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.lbc is not None and self.lbc._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.ses_fe is not None and self.ses_fe._has_data():
                                        return True

                                    if self.ses_ne is not None and self.ses_ne._has_data():
                                        return True

                                    if self.sesr_fe is not None and self.sesr_fe._has_data():
                                        return True

                                    if self.sesr_ne is not None and self.sesr_ne._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.uas_fe is not None and self.uas_fe._has_data():
                                        return True

                                    if self.uas_ne is not None and self.uas_ne._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24otns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dwdm_hour24otn is not None:
                                    for child_ref in self.dwdm_hour24otn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dwdm_hour24_optics is not None and self.dwdm_hour24_optics._has_data():
                                return True

                            if self.dwdm_hour24fecs is not None and self.dwdm_hour24fecs._has_data():
                                return True

                            if self.dwdm_hour24otns is not None and self.dwdm_hour24otns._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dwdm_hour24 is not None and self.dwdm_hour24._has_data():
                            return True

                        if self.dwdm_minute15 is not None and self.dwdm_minute15._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:dwdm/Cisco-IOS-XR-pmengine-oper:dwdm-ports/Cisco-IOS-XR-pmengine-oper:dwdm-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.dwdm_current is not None and self.dwdm_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts.DwdmPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:dwdm/Cisco-IOS-XR-pmengine-oper:dwdm-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.dwdm_port is not None:
                    for child_ref in self.dwdm_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.Dwdm.DwdmPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:dwdm'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.dwdm_ports is not None and self.dwdm_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.Dwdm']['meta_info']


    class Oc(object):
        """
        OC controller performance data
        
        .. attribute:: oc_ports
        
        	Port performance data
        	**type**\:   :py:class:`OcPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.oc_ports = PerformanceManagement.Oc.OcPorts()
            self.oc_ports.parent = self


        class OcPorts(object):
            """
            Port performance data
            
            .. attribute:: oc_port
            
            	Port performance data
            	**type**\: list of    :py:class:`OcPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.oc_port = YList()
                self.oc_port.parent = self
                self.oc_port.name = 'oc_port'


            class OcPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: oc_current
                
                	port current performance data
                	**type**\:   :py:class:`OcCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.oc_current = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent()
                    self.oc_current.parent = self


                class OcCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: oc_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`OcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24>`
                    
                    .. attribute:: oc_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`OcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.oc_hour24 = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24()
                        self.oc_hour24.parent = self
                        self.oc_minute15 = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15()
                        self.oc_minute15.parent = self


                    class OcHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: oc_hour24ocns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OcHour24Ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.oc_hour24ocns = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns()
                            self.oc_hour24ocns.parent = self


                        class OcHour24Ocns(object):
                            """
                            port current performance data
                            
                            .. attribute:: oc_hour24ocn
                            
                            	port 24 hour ocn performance data
                            	**type**\: list of    :py:class:`OcHour24Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.oc_hour24ocn = YList()
                                self.oc_hour24ocn.parent = self
                                self.oc_hour24ocn.name = 'oc_hour24ocn'


                            class OcHour24Ocn(object):
                                """
                                port 24 hour ocn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine()
                                    self.fe_line.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line()
                                    self.line.parent = self
                                    self.section = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section()
                                    self.section.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Section(object):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.section_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self.section_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self.section_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self.section_sef_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self.section_status = None


                                    class SectionESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionESs']['meta_info']


                                    class SectionSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSeSs']['meta_info']


                                    class SectionSefSs(object):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-sef-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSefSs']['meta_info']


                                    class SectionCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionCVs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.section_c_vs is not None and self.section_c_vs._has_data():
                                            return True

                                        if self.section_e_ss is not None and self.section_e_ss._has_data():
                                            return True

                                        if self.section_se_ss is not None and self.section_se_ss._has_data():
                                            return True

                                        if self.section_sef_ss is not None and self.section_sef_ss._has_data():
                                            return True

                                        if self.section_status is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section']['meta_info']


                                class Line(object):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self.line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self.line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self.line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self.line_status = None
                                        self.line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self


                                    class LineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineESs']['meta_info']


                                    class LineSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineSeSs']['meta_info']


                                    class LineCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineCVs']['meta_info']


                                    class LineUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineUaSs']['meta_info']


                                    class LineFcLs(object):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-fc-ls'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineFcLs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.line_c_vs is not None and self.line_c_vs._has_data():
                                            return True

                                        if self.line_e_ss is not None and self.line_e_ss._has_data():
                                            return True

                                        if self.line_fc_ls is not None and self.line_fc_ls._has_data():
                                            return True

                                        if self.line_se_ss is not None and self.line_se_ss._has_data():
                                            return True

                                        if self.line_status is not None:
                                            return True

                                        if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line']['meta_info']


                                class FeLine(object):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineFcLs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self.far_end_line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self.far_end_line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self.far_end_line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self.far_end_line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self


                                    class FarEndLineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineESs']['meta_info']


                                    class FarEndLineSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineSeSs']['meta_info']


                                    class FarEndLineCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineCVs']['meta_info']


                                    class FarEndLineUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineUaSs']['meta_info']


                                    class FarEndLineFcLs(object):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-fc-ls'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineFcLs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_line_c_vs is not None and self.far_end_line_c_vs._has_data():
                                            return True

                                        if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                            return True

                                        if self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls._has_data():
                                            return True

                                        if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                            return True

                                        if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-hour24ocn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_line is not None and self.fe_line._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.line is not None and self.line._has_data():
                                        return True

                                    if self.section is not None and self.section._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-hour24ocns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.oc_hour24ocn is not None:
                                    for child_ref in self.oc_hour24ocn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.oc_hour24ocns is not None and self.oc_hour24ocns._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24']['meta_info']


                    class OcMinute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: oc_minute15ocns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OcMinute15Ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.oc_minute15ocns = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns()
                            self.oc_minute15ocns.parent = self


                        class OcMinute15Ocns(object):
                            """
                            port current performance data
                            
                            .. attribute:: oc_minute15ocn
                            
                            	port 15\-minute ocn performance data
                            	**type**\: list of    :py:class:`OcMinute15Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.oc_minute15ocn = YList()
                                self.oc_minute15ocn.parent = self
                                self.oc_minute15ocn.name = 'oc_minute15ocn'


                            class OcMinute15Ocn(object):
                                """
                                port 15\-minute ocn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.fe_line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine()
                                    self.fe_line.parent = self
                                    self.index = None
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear_time = None
                                    self.line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line()
                                    self.line.parent = self
                                    self.section = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section()
                                    self.section.parent = self
                                    self.timestamp = None
                                    self.valid = None


                                class Section(object):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.section_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self.section_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self.section_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self.section_sef_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self.section_status = None


                                    class SectionESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionESs']['meta_info']


                                    class SectionSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSeSs']['meta_info']


                                    class SectionSefSs(object):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-sef-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSefSs']['meta_info']


                                    class SectionCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionCVs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.section_c_vs is not None and self.section_c_vs._has_data():
                                            return True

                                        if self.section_e_ss is not None and self.section_e_ss._has_data():
                                            return True

                                        if self.section_se_ss is not None and self.section_se_ss._has_data():
                                            return True

                                        if self.section_sef_ss is not None and self.section_sef_ss._has_data():
                                            return True

                                        if self.section_status is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section']['meta_info']


                                class Line(object):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self.line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self.line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self.line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self.line_status = None
                                        self.line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self


                                    class LineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineESs']['meta_info']


                                    class LineSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineSeSs']['meta_info']


                                    class LineCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineCVs']['meta_info']


                                    class LineUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineUaSs']['meta_info']


                                    class LineFcLs(object):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-fc-ls'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineFcLs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.line_c_vs is not None and self.line_c_vs._has_data():
                                            return True

                                        if self.line_e_ss is not None and self.line_e_ss._has_data():
                                            return True

                                        if self.line_fc_ls is not None and self.line_fc_ls._has_data():
                                            return True

                                        if self.line_se_ss is not None and self.line_se_ss._has_data():
                                            return True

                                        if self.line_status is not None:
                                            return True

                                        if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line']['meta_info']


                                class FeLine(object):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineFcLs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.far_end_line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self.far_end_line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self.far_end_line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self.far_end_line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self.far_end_line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self


                                    class FarEndLineESs(object):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineESs']['meta_info']


                                    class FarEndLineSeSs(object):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineSeSs']['meta_info']


                                    class FarEndLineCVs(object):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-c-vs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineCVs']['meta_info']


                                    class FarEndLineUaSs(object):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineUaSs']['meta_info']


                                    class FarEndLineFcLs(object):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.data = None
                                            self.tca_report = None
                                            self.threshold = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-fc-ls'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.data is not None:
                                                return True

                                            if self.tca_report is not None:
                                                return True

                                            if self.threshold is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineFcLs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.far_end_line_c_vs is not None and self.far_end_line_c_vs._has_data():
                                            return True

                                        if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                            return True

                                        if self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls._has_data():
                                            return True

                                        if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                            return True

                                        if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-minute15ocn[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.fe_line is not None and self.fe_line._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.line is not None and self.line._has_data():
                                        return True

                                    if self.section is not None and self.section._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-minute15ocns'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.oc_minute15ocn is not None:
                                    for child_ref in self.oc_minute15ocn:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.oc_minute15ocns is not None and self.oc_minute15ocns._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.oc_hour24 is not None and self.oc_hour24._has_data():
                            return True

                        if self.oc_minute15 is not None and self.oc_minute15._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:oc/Cisco-IOS-XR-pmengine-oper:oc-ports/Cisco-IOS-XR-pmengine-oper:oc-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.oc_current is not None and self.oc_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.Oc.OcPorts.OcPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:oc/Cisco-IOS-XR-pmengine-oper:oc-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.oc_port is not None:
                    for child_ref in self.oc_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.Oc.OcPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:oc'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.oc_ports is not None and self.oc_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.Oc']['meta_info']


    class Ethernet(object):
        """
        EHERNET controller performance data
        
        .. attribute:: ethernet_ports
        
        	Port performance data
        	**type**\:   :py:class:`EthernetPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.ethernet_ports = PerformanceManagement.Ethernet.EthernetPorts()
            self.ethernet_ports.parent = self


        class EthernetPorts(object):
            """
            Port performance data
            
            .. attribute:: ethernet_port
            
            	Port performance data
            	**type**\: list of    :py:class:`EthernetPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.ethernet_port = YList()
                self.ethernet_port.parent = self
                self.ethernet_port.name = 'ethernet_port'


            class EthernetPort(object):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ethernet_current
                
                	port current performance data
                	**type**\:   :py:class:`EthernetCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.ethernet_current = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent()
                    self.ethernet_current.parent = self


                class EthernetCurrent(object):
                    """
                    port current performance data
                    
                    .. attribute:: ethernet_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`EthernetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24>`
                    
                    .. attribute:: ethernet_second30
                    
                    	port current performance data
                    	**type**\:   :py:class:`EthernetSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30>`
                    
                    .. attribute:: minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`Minute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ethernet_hour24 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24()
                        self.ethernet_hour24.parent = self
                        self.ethernet_second30 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30()
                        self.ethernet_second30.parent = self
                        self.minute15 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15()
                        self.minute15.parent = self


                    class EthernetSecond30(object):
                        """
                        port current performance data
                        
                        .. attribute:: second30_ethers
                        
                        	ETHERNET port interval performance data
                        	**type**\:   :py:class:`Second30Ethers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.second30_ethers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers()
                            self.second30_ethers.parent = self


                        class Second30Ethers(object):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: second30_ether
                            
                            	ETHERNET port 30 second ether performance data
                            	**type**\: list of    :py:class:`Second30Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.second30_ether = YList()
                                self.second30_ether.parent = self
                                self.second30_ether.name = 'second30_ether'


                            class Second30Ether(object):
                                """
                                ETHERNET port 30 second ether performance
                                data
                                
                                .. attribute:: slot_number  <key>
                                
                                	interval slot number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021QFrames>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat>`
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021QFrames>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64Octet>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat>`
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.slot_number = None
                                    self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021QFrames()
                                    self.in8021q_frames.parent = self
                                    self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self.index = None
                                    self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021QFrames()
                                    self.out8021q_frames.parent = self
                                    self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64Octet()
                                    self.outpkt64octet.parent = self
                                    self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self.sec30_support = None
                                    self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self.timestamp = None
                                    self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self.valid = None


                                class RxPkt(object):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt']['meta_info']


                                class StatPkt(object):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stat-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt']['meta_info']


                                class OctetStat(object):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:octet-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat']['meta_info']


                                class OversizePktStat(object):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oversize-pkt-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat']['meta_info']


                                class FcsErrorsStat(object):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fcs-errors-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat']['meta_info']


                                class LongFramesStat(object):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:long-frames-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat']['meta_info']


                                class JabberStat(object):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:jabber-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat']['meta_info']


                                class Ether64Octets(object):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether64-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets']['meta_info']


                                class Ether65127Octet(object):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether65127-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet']['meta_info']


                                class Ether128255Octet(object):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether128255-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet']['meta_info']


                                class Ether256511Octet(object):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether256511-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet']['meta_info']


                                class Ether5121023Octet(object):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether5121023-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet']['meta_info']


                                class Ether10241518Octet(object):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether10241518-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet']['meta_info']


                                class InUcastPkt(object):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-ucast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt']['meta_info']


                                class InMcastPkt(object):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt']['meta_info']


                                class InBcastPkt(object):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-bcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt']['meta_info']


                                class OutUcastPkt(object):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-ucast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt']['meta_info']


                                class OutBcastPkt(object):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-bcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt']['meta_info']


                                class OutMcastPkt(object):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-mcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt']['meta_info']


                                class TxPkt(object):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt']['meta_info']


                                class IfInErrors(object):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-errors'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors']['meta_info']


                                class IfInOctets(object):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets']['meta_info']


                                class EtherStatMulticastPkt(object):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-multicast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt']['meta_info']


                                class EtherStatBroadcastPkt(object):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-broadcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt']['meta_info']


                                class EtherStatUndersizedPkt(object):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-undersized-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt']['meta_info']


                                class OutOctets(object):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets']['meta_info']


                                class InPauseFrame(object):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pause-frame'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame']['meta_info']


                                class InGoodBytes(object):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-bytes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes']['meta_info']


                                class In8021QFrames(object):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in8021q-frames'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021QFrames']['meta_info']


                                class InPkts1519MaxOctets(object):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1519-max-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets']['meta_info']


                                class InGoodPkts(object):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-pkts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts']['meta_info']


                                class InDropOverrun(object):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-overrun'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun']['meta_info']


                                class InDropAbort(object):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-abort'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort']['meta_info']


                                class InDropInvalidVlan(object):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan']['meta_info']


                                class InDropInvalidDmac(object):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-dmac'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac']['meta_info']


                                class InDropInvalidEncap(object):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-encap'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap']['meta_info']


                                class InDropOther(object):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther']['meta_info']


                                class InMibGiant(object):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-giant'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant']['meta_info']


                                class InMibJabber(object):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-jabber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber']['meta_info']


                                class InMibcrc(object):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mibcrc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc']['meta_info']


                                class InErrorCollisions(object):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-collisions'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions']['meta_info']


                                class InErrorSymbol(object):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-symbol'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol']['meta_info']


                                class OutGoodBytes(object):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-bytes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes']['meta_info']


                                class Out8021QFrames(object):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out8021q-frames'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021QFrames']['meta_info']


                                class OutPauseFrames(object):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pause-frames'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames']['meta_info']


                                class OutPkts1519MaxOctets(object):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts1519-max-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets']['meta_info']


                                class OutGoodPkts(object):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-pkts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts']['meta_info']


                                class OutDropUnderrun(object):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-underrun'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun']['meta_info']


                                class OutDropAbort(object):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-abort'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort']['meta_info']


                                class OutDropOther(object):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther']['meta_info']


                                class OutErrorOther(object):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-error-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther']['meta_info']


                                class InErrorGiant(object):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-giant'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant']['meta_info']


                                class InErrorRunt(object):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-runt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt']['meta_info']


                                class InErrorJabbers(object):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-jabbers'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers']['meta_info']


                                class InErrorFragments(object):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-fragments'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments']['meta_info']


                                class InErrorOther(object):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther']['meta_info']


                                class InPkt64Octet(object):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkt64-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet']['meta_info']


                                class InPkts65To127Octets(object):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts65-to127-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets']['meta_info']


                                class InPkts128To255Octets(object):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts128-to255-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets']['meta_info']


                                class InPkts256To511Octets(object):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts256-to511-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets']['meta_info']


                                class InPkts512To1023Octets(object):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts512-to1023-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets']['meta_info']


                                class InPkts1024To1518Octets(object):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1024-to1518-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets']['meta_info']


                                class Outpkt64Octet(object):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:outpkt64octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64Octet']['meta_info']


                                class OutPkts65127Octets(object):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts65127-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets']['meta_info']


                                class OutPkts128255Octets(object):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts128255-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets']['meta_info']


                                class OutPkts256511Octets(object):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts256511-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets']['meta_info']


                                class OutPkts5121023Octets(object):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts5121023-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets']['meta_info']


                                class OutPkts10241518Octets(object):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts10241518-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets']['meta_info']


                                class RxUtil(object):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-util'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil']['meta_info']


                                class TxUtil(object):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-util'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil']['meta_info']


                                class TxUndersizedPkt(object):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-undersized-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt']['meta_info']


                                class TxOversizedPkt(object):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-oversized-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt']['meta_info']


                                class TxFragments(object):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-fragments'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments']['meta_info']


                                class TxJabber(object):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-jabber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber']['meta_info']


                                class TxBadFcs(object):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-bad-fcs'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.slot_number is None:
                                        raise YPYModelError('Key property slot_number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:second30-ether[Cisco-IOS-XR-pmengine-oper:slot-number = ' + str(self.slot_number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.slot_number is not None:
                                        return True

                                    if self.ether10241518_octet is not None and self.ether10241518_octet._has_data():
                                        return True

                                    if self.ether128255_octet is not None and self.ether128255_octet._has_data():
                                        return True

                                    if self.ether256511_octet is not None and self.ether256511_octet._has_data():
                                        return True

                                    if self.ether5121023_octet is not None and self.ether5121023_octet._has_data():
                                        return True

                                    if self.ether64_octets is not None and self.ether64_octets._has_data():
                                        return True

                                    if self.ether65127_octet is not None and self.ether65127_octet._has_data():
                                        return True

                                    if self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt._has_data():
                                        return True

                                    if self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt._has_data():
                                        return True

                                    if self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt._has_data():
                                        return True

                                    if self.fcs_errors_stat is not None and self.fcs_errors_stat._has_data():
                                        return True

                                    if self.if_in_errors is not None and self.if_in_errors._has_data():
                                        return True

                                    if self.if_in_octets is not None and self.if_in_octets._has_data():
                                        return True

                                    if self.in8021q_frames is not None and self.in8021q_frames._has_data():
                                        return True

                                    if self.in_bcast_pkt is not None and self.in_bcast_pkt._has_data():
                                        return True

                                    if self.in_drop_abort is not None and self.in_drop_abort._has_data():
                                        return True

                                    if self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac._has_data():
                                        return True

                                    if self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap._has_data():
                                        return True

                                    if self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan._has_data():
                                        return True

                                    if self.in_drop_other is not None and self.in_drop_other._has_data():
                                        return True

                                    if self.in_drop_overrun is not None and self.in_drop_overrun._has_data():
                                        return True

                                    if self.in_error_collisions is not None and self.in_error_collisions._has_data():
                                        return True

                                    if self.in_error_fragments is not None and self.in_error_fragments._has_data():
                                        return True

                                    if self.in_error_giant is not None and self.in_error_giant._has_data():
                                        return True

                                    if self.in_error_jabbers is not None and self.in_error_jabbers._has_data():
                                        return True

                                    if self.in_error_other is not None and self.in_error_other._has_data():
                                        return True

                                    if self.in_error_runt is not None and self.in_error_runt._has_data():
                                        return True

                                    if self.in_error_symbol is not None and self.in_error_symbol._has_data():
                                        return True

                                    if self.in_good_bytes is not None and self.in_good_bytes._has_data():
                                        return True

                                    if self.in_good_pkts is not None and self.in_good_pkts._has_data():
                                        return True

                                    if self.in_mcast_pkt is not None and self.in_mcast_pkt._has_data():
                                        return True

                                    if self.in_mib_giant is not None and self.in_mib_giant._has_data():
                                        return True

                                    if self.in_mib_jabber is not None and self.in_mib_jabber._has_data():
                                        return True

                                    if self.in_mibcrc is not None and self.in_mibcrc._has_data():
                                        return True

                                    if self.in_pause_frame is not None and self.in_pause_frame._has_data():
                                        return True

                                    if self.in_pkt64_octet is not None and self.in_pkt64_octet._has_data():
                                        return True

                                    if self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets._has_data():
                                        return True

                                    if self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets._has_data():
                                        return True

                                    if self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets._has_data():
                                        return True

                                    if self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets._has_data():
                                        return True

                                    if self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets._has_data():
                                        return True

                                    if self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets._has_data():
                                        return True

                                    if self.in_ucast_pkt is not None and self.in_ucast_pkt._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.jabber_stat is not None and self.jabber_stat._has_data():
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.long_frames_stat is not None and self.long_frames_stat._has_data():
                                        return True

                                    if self.octet_stat is not None and self.octet_stat._has_data():
                                        return True

                                    if self.out8021q_frames is not None and self.out8021q_frames._has_data():
                                        return True

                                    if self.out_bcast_pkt is not None and self.out_bcast_pkt._has_data():
                                        return True

                                    if self.out_drop_abort is not None and self.out_drop_abort._has_data():
                                        return True

                                    if self.out_drop_other is not None and self.out_drop_other._has_data():
                                        return True

                                    if self.out_drop_underrun is not None and self.out_drop_underrun._has_data():
                                        return True

                                    if self.out_error_other is not None and self.out_error_other._has_data():
                                        return True

                                    if self.out_good_bytes is not None and self.out_good_bytes._has_data():
                                        return True

                                    if self.out_good_pkts is not None and self.out_good_pkts._has_data():
                                        return True

                                    if self.out_mcast_pkt is not None and self.out_mcast_pkt._has_data():
                                        return True

                                    if self.out_octets is not None and self.out_octets._has_data():
                                        return True

                                    if self.out_pause_frames is not None and self.out_pause_frames._has_data():
                                        return True

                                    if self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets._has_data():
                                        return True

                                    if self.out_pkts128255_octets is not None and self.out_pkts128255_octets._has_data():
                                        return True

                                    if self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets._has_data():
                                        return True

                                    if self.out_pkts256511_octets is not None and self.out_pkts256511_octets._has_data():
                                        return True

                                    if self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets._has_data():
                                        return True

                                    if self.out_pkts65127_octets is not None and self.out_pkts65127_octets._has_data():
                                        return True

                                    if self.out_ucast_pkt is not None and self.out_ucast_pkt._has_data():
                                        return True

                                    if self.outpkt64octet is not None and self.outpkt64octet._has_data():
                                        return True

                                    if self.oversize_pkt_stat is not None and self.oversize_pkt_stat._has_data():
                                        return True

                                    if self.rx_pkt is not None and self.rx_pkt._has_data():
                                        return True

                                    if self.rx_util is not None and self.rx_util._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.stat_pkt is not None and self.stat_pkt._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.tx_bad_fcs is not None and self.tx_bad_fcs._has_data():
                                        return True

                                    if self.tx_fragments is not None and self.tx_fragments._has_data():
                                        return True

                                    if self.tx_jabber is not None and self.tx_jabber._has_data():
                                        return True

                                    if self.tx_oversized_pkt is not None and self.tx_oversized_pkt._has_data():
                                        return True

                                    if self.tx_pkt is not None and self.tx_pkt._has_data():
                                        return True

                                    if self.tx_undersized_pkt is not None and self.tx_undersized_pkt._has_data():
                                        return True

                                    if self.tx_util is not None and self.tx_util._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:second30-ethers'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.second30_ether is not None:
                                    for child_ref in self.second30_ether:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-second30'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.second30_ethers is not None and self.second30_ethers._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30']['meta_info']


                    class EthernetHour24(object):
                        """
                        port current performance data
                        
                        .. attribute:: ethernet_hour24_ether_s
                        
                        	port current performance data
                        	**type**\:   :py:class:`EthernetHour24EtherS <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ethernet_hour24_ether_s = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS()
                            self.ethernet_hour24_ether_s.parent = self


                        class EthernetHour24EtherS(object):
                            """
                            port current performance data
                            
                            .. attribute:: ethernet_hour24_ether
                            
                            	port 24 hour ethernet performance data
                            	**type**\: list of    :py:class:`EthernetHour24Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ethernet_hour24_ether = YList()
                                self.ethernet_hour24_ether.parent = self
                                self.ethernet_hour24_ether.name = 'ethernet_hour24_ether'


                            class EthernetHour24Ether(object):
                                """
                                port 24 hour ethernet performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021QFrames>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat>`
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021QFrames>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64Octet>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat>`
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.number = None
                                    self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021QFrames()
                                    self.in8021q_frames.parent = self
                                    self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self.index = None
                                    self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021QFrames()
                                    self.out8021q_frames.parent = self
                                    self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64Octet()
                                    self.outpkt64octet.parent = self
                                    self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self.sec30_support = None
                                    self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self.timestamp = None
                                    self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self.valid = None


                                class RxPkt(object):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt']['meta_info']


                                class StatPkt(object):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stat-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt']['meta_info']


                                class OctetStat(object):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:octet-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat']['meta_info']


                                class OversizePktStat(object):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oversize-pkt-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat']['meta_info']


                                class FcsErrorsStat(object):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fcs-errors-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat']['meta_info']


                                class LongFramesStat(object):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:long-frames-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat']['meta_info']


                                class JabberStat(object):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:jabber-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat']['meta_info']


                                class Ether64Octets(object):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether64-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets']['meta_info']


                                class Ether65127Octet(object):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether65127-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet']['meta_info']


                                class Ether128255Octet(object):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether128255-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet']['meta_info']


                                class Ether256511Octet(object):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether256511-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet']['meta_info']


                                class Ether5121023Octet(object):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether5121023-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet']['meta_info']


                                class Ether10241518Octet(object):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether10241518-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet']['meta_info']


                                class InUcastPkt(object):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-ucast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt']['meta_info']


                                class InMcastPkt(object):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt']['meta_info']


                                class InBcastPkt(object):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-bcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt']['meta_info']


                                class OutUcastPkt(object):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-ucast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt']['meta_info']


                                class OutBcastPkt(object):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-bcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt']['meta_info']


                                class OutMcastPkt(object):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-mcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt']['meta_info']


                                class TxPkt(object):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt']['meta_info']


                                class IfInErrors(object):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-errors'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors']['meta_info']


                                class IfInOctets(object):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets']['meta_info']


                                class EtherStatMulticastPkt(object):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-multicast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt']['meta_info']


                                class EtherStatBroadcastPkt(object):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-broadcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt']['meta_info']


                                class EtherStatUndersizedPkt(object):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-undersized-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt']['meta_info']


                                class OutOctets(object):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets']['meta_info']


                                class InPauseFrame(object):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pause-frame'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame']['meta_info']


                                class InGoodBytes(object):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-bytes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes']['meta_info']


                                class In8021QFrames(object):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in8021q-frames'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021QFrames']['meta_info']


                                class InPkts1519MaxOctets(object):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1519-max-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets']['meta_info']


                                class InGoodPkts(object):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-pkts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts']['meta_info']


                                class InDropOverrun(object):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-overrun'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun']['meta_info']


                                class InDropAbort(object):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-abort'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort']['meta_info']


                                class InDropInvalidVlan(object):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan']['meta_info']


                                class InDropInvalidDmac(object):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-dmac'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac']['meta_info']


                                class InDropInvalidEncap(object):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-encap'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap']['meta_info']


                                class InDropOther(object):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther']['meta_info']


                                class InMibGiant(object):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-giant'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant']['meta_info']


                                class InMibJabber(object):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-jabber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber']['meta_info']


                                class InMibcrc(object):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mibcrc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc']['meta_info']


                                class InErrorCollisions(object):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-collisions'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions']['meta_info']


                                class InErrorSymbol(object):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-symbol'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol']['meta_info']


                                class OutGoodBytes(object):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-bytes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes']['meta_info']


                                class Out8021QFrames(object):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out8021q-frames'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021QFrames']['meta_info']


                                class OutPauseFrames(object):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pause-frames'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames']['meta_info']


                                class OutPkts1519MaxOctets(object):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts1519-max-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets']['meta_info']


                                class OutGoodPkts(object):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-pkts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts']['meta_info']


                                class OutDropUnderrun(object):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-underrun'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun']['meta_info']


                                class OutDropAbort(object):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-abort'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort']['meta_info']


                                class OutDropOther(object):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther']['meta_info']


                                class OutErrorOther(object):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-error-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther']['meta_info']


                                class InErrorGiant(object):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-giant'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant']['meta_info']


                                class InErrorRunt(object):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-runt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt']['meta_info']


                                class InErrorJabbers(object):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-jabbers'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers']['meta_info']


                                class InErrorFragments(object):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-fragments'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments']['meta_info']


                                class InErrorOther(object):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther']['meta_info']


                                class InPkt64Octet(object):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkt64-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet']['meta_info']


                                class InPkts65To127Octets(object):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts65-to127-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets']['meta_info']


                                class InPkts128To255Octets(object):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts128-to255-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets']['meta_info']


                                class InPkts256To511Octets(object):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts256-to511-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets']['meta_info']


                                class InPkts512To1023Octets(object):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts512-to1023-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets']['meta_info']


                                class InPkts1024To1518Octets(object):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1024-to1518-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets']['meta_info']


                                class Outpkt64Octet(object):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:outpkt64octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64Octet']['meta_info']


                                class OutPkts65127Octets(object):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts65127-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets']['meta_info']


                                class OutPkts128255Octets(object):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts128255-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets']['meta_info']


                                class OutPkts256511Octets(object):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts256511-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets']['meta_info']


                                class OutPkts5121023Octets(object):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts5121023-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets']['meta_info']


                                class OutPkts10241518Octets(object):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts10241518-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets']['meta_info']


                                class RxUtil(object):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-util'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil']['meta_info']


                                class TxUtil(object):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-util'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil']['meta_info']


                                class TxUndersizedPkt(object):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-undersized-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt']['meta_info']


                                class TxOversizedPkt(object):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-oversized-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt']['meta_info']


                                class TxFragments(object):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-fragments'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments']['meta_info']


                                class TxJabber(object):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-jabber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber']['meta_info']


                                class TxBadFcs(object):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-bad-fcs'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.number is None:
                                        raise YPYModelError('Key property number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-hour24-ether[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.number is not None:
                                        return True

                                    if self.ether10241518_octet is not None and self.ether10241518_octet._has_data():
                                        return True

                                    if self.ether128255_octet is not None and self.ether128255_octet._has_data():
                                        return True

                                    if self.ether256511_octet is not None and self.ether256511_octet._has_data():
                                        return True

                                    if self.ether5121023_octet is not None and self.ether5121023_octet._has_data():
                                        return True

                                    if self.ether64_octets is not None and self.ether64_octets._has_data():
                                        return True

                                    if self.ether65127_octet is not None and self.ether65127_octet._has_data():
                                        return True

                                    if self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt._has_data():
                                        return True

                                    if self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt._has_data():
                                        return True

                                    if self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt._has_data():
                                        return True

                                    if self.fcs_errors_stat is not None and self.fcs_errors_stat._has_data():
                                        return True

                                    if self.if_in_errors is not None and self.if_in_errors._has_data():
                                        return True

                                    if self.if_in_octets is not None and self.if_in_octets._has_data():
                                        return True

                                    if self.in8021q_frames is not None and self.in8021q_frames._has_data():
                                        return True

                                    if self.in_bcast_pkt is not None and self.in_bcast_pkt._has_data():
                                        return True

                                    if self.in_drop_abort is not None and self.in_drop_abort._has_data():
                                        return True

                                    if self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac._has_data():
                                        return True

                                    if self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap._has_data():
                                        return True

                                    if self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan._has_data():
                                        return True

                                    if self.in_drop_other is not None and self.in_drop_other._has_data():
                                        return True

                                    if self.in_drop_overrun is not None and self.in_drop_overrun._has_data():
                                        return True

                                    if self.in_error_collisions is not None and self.in_error_collisions._has_data():
                                        return True

                                    if self.in_error_fragments is not None and self.in_error_fragments._has_data():
                                        return True

                                    if self.in_error_giant is not None and self.in_error_giant._has_data():
                                        return True

                                    if self.in_error_jabbers is not None and self.in_error_jabbers._has_data():
                                        return True

                                    if self.in_error_other is not None and self.in_error_other._has_data():
                                        return True

                                    if self.in_error_runt is not None and self.in_error_runt._has_data():
                                        return True

                                    if self.in_error_symbol is not None and self.in_error_symbol._has_data():
                                        return True

                                    if self.in_good_bytes is not None and self.in_good_bytes._has_data():
                                        return True

                                    if self.in_good_pkts is not None and self.in_good_pkts._has_data():
                                        return True

                                    if self.in_mcast_pkt is not None and self.in_mcast_pkt._has_data():
                                        return True

                                    if self.in_mib_giant is not None and self.in_mib_giant._has_data():
                                        return True

                                    if self.in_mib_jabber is not None and self.in_mib_jabber._has_data():
                                        return True

                                    if self.in_mibcrc is not None and self.in_mibcrc._has_data():
                                        return True

                                    if self.in_pause_frame is not None and self.in_pause_frame._has_data():
                                        return True

                                    if self.in_pkt64_octet is not None and self.in_pkt64_octet._has_data():
                                        return True

                                    if self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets._has_data():
                                        return True

                                    if self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets._has_data():
                                        return True

                                    if self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets._has_data():
                                        return True

                                    if self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets._has_data():
                                        return True

                                    if self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets._has_data():
                                        return True

                                    if self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets._has_data():
                                        return True

                                    if self.in_ucast_pkt is not None and self.in_ucast_pkt._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.jabber_stat is not None and self.jabber_stat._has_data():
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.long_frames_stat is not None and self.long_frames_stat._has_data():
                                        return True

                                    if self.octet_stat is not None and self.octet_stat._has_data():
                                        return True

                                    if self.out8021q_frames is not None and self.out8021q_frames._has_data():
                                        return True

                                    if self.out_bcast_pkt is not None and self.out_bcast_pkt._has_data():
                                        return True

                                    if self.out_drop_abort is not None and self.out_drop_abort._has_data():
                                        return True

                                    if self.out_drop_other is not None and self.out_drop_other._has_data():
                                        return True

                                    if self.out_drop_underrun is not None and self.out_drop_underrun._has_data():
                                        return True

                                    if self.out_error_other is not None and self.out_error_other._has_data():
                                        return True

                                    if self.out_good_bytes is not None and self.out_good_bytes._has_data():
                                        return True

                                    if self.out_good_pkts is not None and self.out_good_pkts._has_data():
                                        return True

                                    if self.out_mcast_pkt is not None and self.out_mcast_pkt._has_data():
                                        return True

                                    if self.out_octets is not None and self.out_octets._has_data():
                                        return True

                                    if self.out_pause_frames is not None and self.out_pause_frames._has_data():
                                        return True

                                    if self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets._has_data():
                                        return True

                                    if self.out_pkts128255_octets is not None and self.out_pkts128255_octets._has_data():
                                        return True

                                    if self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets._has_data():
                                        return True

                                    if self.out_pkts256511_octets is not None and self.out_pkts256511_octets._has_data():
                                        return True

                                    if self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets._has_data():
                                        return True

                                    if self.out_pkts65127_octets is not None and self.out_pkts65127_octets._has_data():
                                        return True

                                    if self.out_ucast_pkt is not None and self.out_ucast_pkt._has_data():
                                        return True

                                    if self.outpkt64octet is not None and self.outpkt64octet._has_data():
                                        return True

                                    if self.oversize_pkt_stat is not None and self.oversize_pkt_stat._has_data():
                                        return True

                                    if self.rx_pkt is not None and self.rx_pkt._has_data():
                                        return True

                                    if self.rx_util is not None and self.rx_util._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.stat_pkt is not None and self.stat_pkt._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.tx_bad_fcs is not None and self.tx_bad_fcs._has_data():
                                        return True

                                    if self.tx_fragments is not None and self.tx_fragments._has_data():
                                        return True

                                    if self.tx_jabber is not None and self.tx_jabber._has_data():
                                        return True

                                    if self.tx_oversized_pkt is not None and self.tx_oversized_pkt._has_data():
                                        return True

                                    if self.tx_pkt is not None and self.tx_pkt._has_data():
                                        return True

                                    if self.tx_undersized_pkt is not None and self.tx_undersized_pkt._has_data():
                                        return True

                                    if self.tx_util is not None and self.tx_util._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-hour24-ether-s'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ethernet_hour24_ether is not None:
                                    for child_ref in self.ethernet_hour24_ether:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-hour24'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ethernet_hour24_ether_s is not None and self.ethernet_hour24_ether_s._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24']['meta_info']


                    class Minute15(object):
                        """
                        port current performance data
                        
                        .. attribute:: minute15_ethers
                        
                        	ETHERNET port interval performance data
                        	**type**\:   :py:class:`Minute15Ethers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.minute15_ethers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers()
                            self.minute15_ethers.parent = self


                        class Minute15Ethers(object):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: minute15_ether
                            
                            	ETHERNET port 15\-minute ether performance data
                            	**type**\: list of    :py:class:`Minute15Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.minute15_ether = YList()
                                self.minute15_ether.parent = self
                                self.minute15_ether.name = 'minute15_ether'


                            class Minute15Ether(object):
                                """
                                ETHERNET port 15\-minute ether performance
                                data
                                
                                .. attribute:: slot_number  <key>
                                
                                	interval slot number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021QFrames>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat>`
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021QFrames>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64Octet>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat>`
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.slot_number = None
                                    self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021QFrames()
                                    self.in8021q_frames.parent = self
                                    self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self.index = None
                                    self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self.last_clear15_min_time = None
                                    self.last_clear24_hr_time = None
                                    self.last_clear30_sec_time = None
                                    self.last_clear_time = None
                                    self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021QFrames()
                                    self.out8021q_frames.parent = self
                                    self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64Octet()
                                    self.outpkt64octet.parent = self
                                    self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self.sec30_support = None
                                    self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self.timestamp = None
                                    self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self.valid = None


                                class RxPkt(object):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt']['meta_info']


                                class StatPkt(object):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stat-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt']['meta_info']


                                class OctetStat(object):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:octet-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat']['meta_info']


                                class OversizePktStat(object):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oversize-pkt-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat']['meta_info']


                                class FcsErrorsStat(object):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fcs-errors-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat']['meta_info']


                                class LongFramesStat(object):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:long-frames-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat']['meta_info']


                                class JabberStat(object):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:jabber-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat']['meta_info']


                                class Ether64Octets(object):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether64-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets']['meta_info']


                                class Ether65127Octet(object):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether65127-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet']['meta_info']


                                class Ether128255Octet(object):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether128255-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet']['meta_info']


                                class Ether256511Octet(object):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether256511-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet']['meta_info']


                                class Ether5121023Octet(object):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether5121023-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet']['meta_info']


                                class Ether10241518Octet(object):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether10241518-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet']['meta_info']


                                class InUcastPkt(object):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-ucast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt']['meta_info']


                                class InMcastPkt(object):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt']['meta_info']


                                class InBcastPkt(object):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-bcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt']['meta_info']


                                class OutUcastPkt(object):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-ucast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt']['meta_info']


                                class OutBcastPkt(object):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-bcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt']['meta_info']


                                class OutMcastPkt(object):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-mcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt']['meta_info']


                                class TxPkt(object):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt']['meta_info']


                                class IfInErrors(object):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-errors'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors']['meta_info']


                                class IfInOctets(object):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets']['meta_info']


                                class EtherStatMulticastPkt(object):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-multicast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt']['meta_info']


                                class EtherStatBroadcastPkt(object):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-broadcast-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt']['meta_info']


                                class EtherStatUndersizedPkt(object):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-undersized-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt']['meta_info']


                                class OutOctets(object):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets']['meta_info']


                                class InPauseFrame(object):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pause-frame'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame']['meta_info']


                                class InGoodBytes(object):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-bytes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes']['meta_info']


                                class In8021QFrames(object):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in8021q-frames'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021QFrames']['meta_info']


                                class InPkts1519MaxOctets(object):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1519-max-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets']['meta_info']


                                class InGoodPkts(object):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-pkts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts']['meta_info']


                                class InDropOverrun(object):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-overrun'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun']['meta_info']


                                class InDropAbort(object):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-abort'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort']['meta_info']


                                class InDropInvalidVlan(object):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan']['meta_info']


                                class InDropInvalidDmac(object):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-dmac'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac']['meta_info']


                                class InDropInvalidEncap(object):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-encap'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap']['meta_info']


                                class InDropOther(object):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther']['meta_info']


                                class InMibGiant(object):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-giant'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant']['meta_info']


                                class InMibJabber(object):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-jabber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber']['meta_info']


                                class InMibcrc(object):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mibcrc'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc']['meta_info']


                                class InErrorCollisions(object):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-collisions'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions']['meta_info']


                                class InErrorSymbol(object):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-symbol'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol']['meta_info']


                                class OutGoodBytes(object):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-bytes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes']['meta_info']


                                class Out8021QFrames(object):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out8021q-frames'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021QFrames']['meta_info']


                                class OutPauseFrames(object):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pause-frames'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames']['meta_info']


                                class OutPkts1519MaxOctets(object):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts1519-max-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets']['meta_info']


                                class OutGoodPkts(object):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-pkts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts']['meta_info']


                                class OutDropUnderrun(object):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-underrun'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun']['meta_info']


                                class OutDropAbort(object):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-abort'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort']['meta_info']


                                class OutDropOther(object):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther']['meta_info']


                                class OutErrorOther(object):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-error-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther']['meta_info']


                                class InErrorGiant(object):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-giant'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant']['meta_info']


                                class InErrorRunt(object):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-runt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt']['meta_info']


                                class InErrorJabbers(object):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-jabbers'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers']['meta_info']


                                class InErrorFragments(object):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-fragments'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments']['meta_info']


                                class InErrorOther(object):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-other'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther']['meta_info']


                                class InPkt64Octet(object):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkt64-octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet']['meta_info']


                                class InPkts65To127Octets(object):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts65-to127-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets']['meta_info']


                                class InPkts128To255Octets(object):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts128-to255-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets']['meta_info']


                                class InPkts256To511Octets(object):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts256-to511-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets']['meta_info']


                                class InPkts512To1023Octets(object):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts512-to1023-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets']['meta_info']


                                class InPkts1024To1518Octets(object):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1024-to1518-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets']['meta_info']


                                class Outpkt64Octet(object):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:outpkt64octet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64Octet']['meta_info']


                                class OutPkts65127Octets(object):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts65127-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets']['meta_info']


                                class OutPkts128255Octets(object):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts128255-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets']['meta_info']


                                class OutPkts256511Octets(object):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts256511-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets']['meta_info']


                                class OutPkts5121023Octets(object):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts5121023-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets']['meta_info']


                                class OutPkts10241518Octets(object):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts10241518-octets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets']['meta_info']


                                class RxUtil(object):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-util'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil']['meta_info']


                                class TxUtil(object):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-util'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil']['meta_info']


                                class TxUndersizedPkt(object):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-undersized-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt']['meta_info']


                                class TxOversizedPkt(object):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-oversized-pkt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt']['meta_info']


                                class TxFragments(object):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-fragments'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments']['meta_info']


                                class TxJabber(object):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-jabber'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber']['meta_info']


                                class TxBadFcs(object):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.data = None
                                        self.tca_report = None
                                        self.threshold = None
                                        self.valid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-bad-fcs'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data is not None:
                                            return True

                                        if self.tca_report is not None:
                                            return True

                                        if self.threshold is not None:
                                            return True

                                        if self.valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.slot_number is None:
                                        raise YPYModelError('Key property slot_number is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:minute15-ether[Cisco-IOS-XR-pmengine-oper:slot-number = ' + str(self.slot_number) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.slot_number is not None:
                                        return True

                                    if self.ether10241518_octet is not None and self.ether10241518_octet._has_data():
                                        return True

                                    if self.ether128255_octet is not None and self.ether128255_octet._has_data():
                                        return True

                                    if self.ether256511_octet is not None and self.ether256511_octet._has_data():
                                        return True

                                    if self.ether5121023_octet is not None and self.ether5121023_octet._has_data():
                                        return True

                                    if self.ether64_octets is not None and self.ether64_octets._has_data():
                                        return True

                                    if self.ether65127_octet is not None and self.ether65127_octet._has_data():
                                        return True

                                    if self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt._has_data():
                                        return True

                                    if self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt._has_data():
                                        return True

                                    if self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt._has_data():
                                        return True

                                    if self.fcs_errors_stat is not None and self.fcs_errors_stat._has_data():
                                        return True

                                    if self.if_in_errors is not None and self.if_in_errors._has_data():
                                        return True

                                    if self.if_in_octets is not None and self.if_in_octets._has_data():
                                        return True

                                    if self.in8021q_frames is not None and self.in8021q_frames._has_data():
                                        return True

                                    if self.in_bcast_pkt is not None and self.in_bcast_pkt._has_data():
                                        return True

                                    if self.in_drop_abort is not None and self.in_drop_abort._has_data():
                                        return True

                                    if self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac._has_data():
                                        return True

                                    if self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap._has_data():
                                        return True

                                    if self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan._has_data():
                                        return True

                                    if self.in_drop_other is not None and self.in_drop_other._has_data():
                                        return True

                                    if self.in_drop_overrun is not None and self.in_drop_overrun._has_data():
                                        return True

                                    if self.in_error_collisions is not None and self.in_error_collisions._has_data():
                                        return True

                                    if self.in_error_fragments is not None and self.in_error_fragments._has_data():
                                        return True

                                    if self.in_error_giant is not None and self.in_error_giant._has_data():
                                        return True

                                    if self.in_error_jabbers is not None and self.in_error_jabbers._has_data():
                                        return True

                                    if self.in_error_other is not None and self.in_error_other._has_data():
                                        return True

                                    if self.in_error_runt is not None and self.in_error_runt._has_data():
                                        return True

                                    if self.in_error_symbol is not None and self.in_error_symbol._has_data():
                                        return True

                                    if self.in_good_bytes is not None and self.in_good_bytes._has_data():
                                        return True

                                    if self.in_good_pkts is not None and self.in_good_pkts._has_data():
                                        return True

                                    if self.in_mcast_pkt is not None and self.in_mcast_pkt._has_data():
                                        return True

                                    if self.in_mib_giant is not None and self.in_mib_giant._has_data():
                                        return True

                                    if self.in_mib_jabber is not None and self.in_mib_jabber._has_data():
                                        return True

                                    if self.in_mibcrc is not None and self.in_mibcrc._has_data():
                                        return True

                                    if self.in_pause_frame is not None and self.in_pause_frame._has_data():
                                        return True

                                    if self.in_pkt64_octet is not None and self.in_pkt64_octet._has_data():
                                        return True

                                    if self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets._has_data():
                                        return True

                                    if self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets._has_data():
                                        return True

                                    if self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets._has_data():
                                        return True

                                    if self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets._has_data():
                                        return True

                                    if self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets._has_data():
                                        return True

                                    if self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets._has_data():
                                        return True

                                    if self.in_ucast_pkt is not None and self.in_ucast_pkt._has_data():
                                        return True

                                    if self.index is not None:
                                        return True

                                    if self.jabber_stat is not None and self.jabber_stat._has_data():
                                        return True

                                    if self.last_clear15_min_time is not None:
                                        return True

                                    if self.last_clear24_hr_time is not None:
                                        return True

                                    if self.last_clear30_sec_time is not None:
                                        return True

                                    if self.last_clear_time is not None:
                                        return True

                                    if self.long_frames_stat is not None and self.long_frames_stat._has_data():
                                        return True

                                    if self.octet_stat is not None and self.octet_stat._has_data():
                                        return True

                                    if self.out8021q_frames is not None and self.out8021q_frames._has_data():
                                        return True

                                    if self.out_bcast_pkt is not None and self.out_bcast_pkt._has_data():
                                        return True

                                    if self.out_drop_abort is not None and self.out_drop_abort._has_data():
                                        return True

                                    if self.out_drop_other is not None and self.out_drop_other._has_data():
                                        return True

                                    if self.out_drop_underrun is not None and self.out_drop_underrun._has_data():
                                        return True

                                    if self.out_error_other is not None and self.out_error_other._has_data():
                                        return True

                                    if self.out_good_bytes is not None and self.out_good_bytes._has_data():
                                        return True

                                    if self.out_good_pkts is not None and self.out_good_pkts._has_data():
                                        return True

                                    if self.out_mcast_pkt is not None and self.out_mcast_pkt._has_data():
                                        return True

                                    if self.out_octets is not None and self.out_octets._has_data():
                                        return True

                                    if self.out_pause_frames is not None and self.out_pause_frames._has_data():
                                        return True

                                    if self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets._has_data():
                                        return True

                                    if self.out_pkts128255_octets is not None and self.out_pkts128255_octets._has_data():
                                        return True

                                    if self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets._has_data():
                                        return True

                                    if self.out_pkts256511_octets is not None and self.out_pkts256511_octets._has_data():
                                        return True

                                    if self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets._has_data():
                                        return True

                                    if self.out_pkts65127_octets is not None and self.out_pkts65127_octets._has_data():
                                        return True

                                    if self.out_ucast_pkt is not None and self.out_ucast_pkt._has_data():
                                        return True

                                    if self.outpkt64octet is not None and self.outpkt64octet._has_data():
                                        return True

                                    if self.oversize_pkt_stat is not None and self.oversize_pkt_stat._has_data():
                                        return True

                                    if self.rx_pkt is not None and self.rx_pkt._has_data():
                                        return True

                                    if self.rx_util is not None and self.rx_util._has_data():
                                        return True

                                    if self.sec30_support is not None:
                                        return True

                                    if self.stat_pkt is not None and self.stat_pkt._has_data():
                                        return True

                                    if self.timestamp is not None:
                                        return True

                                    if self.tx_bad_fcs is not None and self.tx_bad_fcs._has_data():
                                        return True

                                    if self.tx_fragments is not None and self.tx_fragments._has_data():
                                        return True

                                    if self.tx_jabber is not None and self.tx_jabber._has_data():
                                        return True

                                    if self.tx_oversized_pkt is not None and self.tx_oversized_pkt._has_data():
                                        return True

                                    if self.tx_pkt is not None and self.tx_pkt._has_data():
                                        return True

                                    if self.tx_undersized_pkt is not None and self.tx_undersized_pkt._has_data():
                                        return True

                                    if self.tx_util is not None and self.tx_util._has_data():
                                        return True

                                    if self.valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:minute15-ethers'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.minute15_ether is not None:
                                    for child_ref in self.minute15_ether:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:minute15'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.minute15_ethers is not None and self.minute15_ethers._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-current'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ethernet_hour24 is not None and self.ethernet_hour24._has_data():
                            return True

                        if self.ethernet_second30 is not None and self.ethernet_second30._has_data():
                            return True

                        if self.minute15 is not None and self.minute15._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:ethernet/Cisco-IOS-XR-pmengine-oper:ethernet-ports/Cisco-IOS-XR-pmengine-oper:ethernet-port[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.ethernet_current is not None and self.ethernet_current._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts.EthernetPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:ethernet/Cisco-IOS-XR-pmengine-oper:ethernet-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.ethernet_port is not None:
                    for child_ref in self.ethernet_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagement.Ethernet.EthernetPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management/Cisco-IOS-XR-pmengine-oper:ethernet'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.ethernet_ports is not None and self.ethernet_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagement.Ethernet']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-pmengine-oper:performance-management'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.dwdm is not None and self.dwdm._has_data():
            return True

        if self.ethernet is not None and self.ethernet._has_data():
            return True

        if self.ho_vc is not None and self.ho_vc._has_data():
            return True

        if self.oc is not None and self.oc._has_data():
            return True

        if self.odu is not None and self.odu._has_data():
            return True

        if self.optics is not None and self.optics._has_data():
            return True

        if self.otu is not None and self.otu._has_data():
            return True

        if self.sonet is not None and self.sonet._has_data():
            return True

        if self.stm is not None and self.stm._has_data():
            return True

        if self.sts is not None and self.sts._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
        return meta._meta_table['PerformanceManagement']['meta_info']


class PerformanceManagementHistory(object):
    """
    performance management history
    
    .. attribute:: global_
    
    	global History performace data
    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_>`
    
    

    """

    _prefix = 'pmengine-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.global_ = PerformanceManagementHistory.Global_()
        self.global_.parent = self


    class Global_(object):
        """
        global History performace data
        
        .. attribute:: periodic
        
        	History performace data
        	**type**\:   :py:class:`Periodic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.periodic = PerformanceManagementHistory.Global_.Periodic()
            self.periodic.parent = self


        class Periodic(object):
            """
            History performace data
            
            .. attribute:: dwdm_history
            
            	DWDM controller History performance data
            	**type**\:   :py:class:`DwdmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory>`
            
            .. attribute:: ethernet_history
            
            	EHERNET controller History performance data
            	**type**\:   :py:class:`EthernetHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory>`
            
            .. attribute:: ho_vc_history
            
            	HO\_VC controller History performance data
            	**type**\:   :py:class:`HoVcHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory>`
            
            .. attribute:: oc_history
            
            	OC controller History performance data
            	**type**\:   :py:class:`OcHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory>`
            
            .. attribute:: odu_history
            
            	ODU controller History performance data
            	**type**\:   :py:class:`OduHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory>`
            
            .. attribute:: optics_history
            
            	OPTICS controller History performance data
            	**type**\:   :py:class:`OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory>`
            
            .. attribute:: otu_history
            
            	OTU controller History performance data
            	**type**\:   :py:class:`OtuHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory>`
            
            .. attribute:: sonet_history
            
            	SONET controller History performance data
            	**type**\:   :py:class:`SonetHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory>`
            
            .. attribute:: stm_history
            
            	STM controller History performance data
            	**type**\:   :py:class:`StmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory>`
            
            .. attribute:: sts_history
            
            	STS controller History performance data
            	**type**\:   :py:class:`StsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.dwdm_history = PerformanceManagementHistory.Global_.Periodic.DwdmHistory()
                self.dwdm_history.parent = self
                self.ethernet_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory()
                self.ethernet_history.parent = self
                self.ho_vc_history = PerformanceManagementHistory.Global_.Periodic.HoVcHistory()
                self.ho_vc_history.parent = self
                self.oc_history = PerformanceManagementHistory.Global_.Periodic.OcHistory()
                self.oc_history.parent = self
                self.odu_history = PerformanceManagementHistory.Global_.Periodic.OduHistory()
                self.odu_history.parent = self
                self.optics_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory()
                self.optics_history.parent = self
                self.otu_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory()
                self.otu_history.parent = self
                self.sonet_history = PerformanceManagementHistory.Global_.Periodic.SonetHistory()
                self.sonet_history.parent = self
                self.stm_history = PerformanceManagementHistory.Global_.Periodic.StmHistory()
                self.stm_history.parent = self
                self.sts_history = PerformanceManagementHistory.Global_.Periodic.StsHistory()
                self.sts_history.parent = self


            class SonetHistory(object):
                """
                SONET controller History performance data
                
                .. attribute:: sonet_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`SonetPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.sonet_port_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories()
                    self.sonet_port_histories.parent = self


                class SonetPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: sonet_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`SonetPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.sonet_port_history = YList()
                        self.sonet_port_history.parent = self
                        self.sonet_port_history.name = 'sonet_port_history'


                    class SonetPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: sonet_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History>`
                        
                        .. attribute:: sonet_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.sonet_hour24_history = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History()
                            self.sonet_hour24_history.parent = self
                            self.sonet_minute15_history = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History()
                            self.sonet_minute15_history.parent = self


                        class SonetMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_minute15_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`SonetMinute15PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories>`
                            
                            .. attribute:: sonet_minute15ocn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`SonetMinute15OcnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sonet_minute15_path_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories()
                                self.sonet_minute15_path_histories.parent = self
                                self.sonet_minute15ocn_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories()
                                self.sonet_minute15ocn_histories.parent = self


                            class SonetMinute15OcnHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_minute15ocn_history
                                
                                	port 15\-minute ocn performance data
                                	**type**\: list of    :py:class:`SonetMinute15OcnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.sonet_minute15ocn_history = YList()
                                    self.sonet_minute15ocn_history.parent = self
                                    self.sonet_minute15ocn_history.name = 'sonet_minute15ocn_history'


                                class SonetMinute15OcnHistory(object):
                                    """
                                    port 15\-minute ocn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sonet_minute15ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`SonetMinute15OcnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.sonet_minute15ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances()
                                        self.sonet_minute15ocn_time_line_instances.parent = self


                                    class SonetMinute15OcnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_minute15ocn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`SonetMinute15OcnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.sonet_minute15ocn_time_line_instance = YList()
                                            self.sonet_minute15ocn_time_line_instance.parent = self
                                            self.sonet_minute15ocn_time_line_instance.name = 'sonet_minute15ocn_time_line_instance'


                                        class SonetMinute15OcnTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self.section = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Section(object):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self.section_status = None


                                                class SectionESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionESs']['meta_info']


                                                class SectionSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSeSs']['meta_info']


                                                class SectionSefSs(object):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-sef-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSefSs']['meta_info']


                                                class SectionCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionCVs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.section_c_vs is not None and self.section_c_vs._has_data():
                                                        return True

                                                    if self.section_e_ss is not None and self.section_e_ss._has_data():
                                                        return True

                                                    if self.section_se_ss is not None and self.section_se_ss._has_data():
                                                        return True

                                                    if self.section_sef_ss is not None and self.section_sef_ss._has_data():
                                                        return True

                                                    if self.section_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section']['meta_info']


                                            class Line(object):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self.line_status = None
                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self


                                                class LineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineESs']['meta_info']


                                                class LineSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineSeSs']['meta_info']


                                                class LineCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineCVs']['meta_info']


                                                class LineUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineUaSs']['meta_info']


                                                class LineFcLs(object):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-fc-ls'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineFcLs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.line_c_vs is not None and self.line_c_vs._has_data():
                                                        return True

                                                    if self.line_e_ss is not None and self.line_e_ss._has_data():
                                                        return True

                                                    if self.line_fc_ls is not None and self.line_fc_ls._has_data():
                                                        return True

                                                    if self.line_se_ss is not None and self.line_se_ss._has_data():
                                                        return True

                                                    if self.line_status is not None:
                                                        return True

                                                    if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line']['meta_info']


                                            class FeLine(object):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self


                                                class FarEndLineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineESs']['meta_info']


                                                class FarEndLineSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs']['meta_info']


                                                class FarEndLineCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs']['meta_info']


                                                class FarEndLineUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs']['meta_info']


                                                class FarEndLineFcLs(object):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-fc-ls'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_line_c_vs is not None and self.far_end_line_c_vs._has_data():
                                                        return True

                                                    if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                                        return True

                                                    if self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls._has_data():
                                                        return True

                                                    if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                                        return True

                                                    if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15ocn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_line is not None and self.fe_line._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.line is not None and self.line._has_data():
                                                    return True

                                                if self.section is not None and self.section._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15ocn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.sonet_minute15ocn_time_line_instance is not None:
                                                for child_ref in self.sonet_minute15ocn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15ocn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.sonet_minute15ocn_time_line_instances is not None and self.sonet_minute15ocn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15ocn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sonet_minute15ocn_history is not None:
                                        for child_ref in self.sonet_minute15ocn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories']['meta_info']


                            class SonetMinute15PathHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_minute15_path_history
                                
                                	port 15\-minute Path performance data
                                	**type**\: list of    :py:class:`SonetMinute15PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.sonet_minute15_path_history = YList()
                                    self.sonet_minute15_path_history.parent = self
                                    self.sonet_minute15_path_history.name = 'sonet_minute15_path_history'


                                class SonetMinute15PathHistory(object):
                                    """
                                    port 15\-minute Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sonet_minute15_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`SonetMinute15PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.sonet_minute15_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances()
                                        self.sonet_minute15_path_time_line_instances.parent = self


                                    class SonetMinute15PathTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_minute15_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`SonetMinute15PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.sonet_minute15_path_time_line_instance = YList()
                                            self.sonet_minute15_path_time_line_instance.parent = self
                                            self.sonet_minute15_path_time_line_instance.name = 'sonet_minute15_path_time_line_instance'


                                        class SonetMinute15PathTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Path(object):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:   :py:class:`PmSonetPathWidthEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnumEnum>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self.path_status = None
                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self.path_width = None


                                                class PathESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs']['meta_info']


                                                class PathSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs']['meta_info']


                                                class PathCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs']['meta_info']


                                                class PathUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.path_c_vs is not None and self.path_c_vs._has_data():
                                                        return True

                                                    if self.path_e_ss is not None and self.path_e_ss._has_data():
                                                        return True

                                                    if self.path_se_ss is not None and self.path_se_ss._has_data():
                                                        return True

                                                    if self.path_status is not None:
                                                        return True

                                                    if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                                        return True

                                                    if self.path_width is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path']['meta_info']


                                            class FePath(object):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_ua_ss = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_path_c_vs is not None:
                                                        return True

                                                    if self.far_end_path_e_ss is not None:
                                                        return True

                                                    if self.far_end_path_se_ss is not None:
                                                        return True

                                                    if self.far_end_path_ua_ss is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15-path-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_path is not None and self.fe_path._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.path is not None and self.path._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15-path-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.sonet_minute15_path_time_line_instance is not None:
                                                for child_ref in self.sonet_minute15_path_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15-path-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.sonet_minute15_path_time_line_instances is not None and self.sonet_minute15_path_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15-path-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sonet_minute15_path_history is not None:
                                        for child_ref in self.sonet_minute15_path_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sonet_minute15_path_histories is not None and self.sonet_minute15_path_histories._has_data():
                                    return True

                                if self.sonet_minute15ocn_histories is not None and self.sonet_minute15ocn_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History']['meta_info']


                        class SonetHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_hour24_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`SonetHour24PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories>`
                            
                            .. attribute:: sonet_hour24ocn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`SonetHour24OcnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sonet_hour24_path_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories()
                                self.sonet_hour24_path_histories.parent = self
                                self.sonet_hour24ocn_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories()
                                self.sonet_hour24ocn_histories.parent = self


                            class SonetHour24PathHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_hour24_path_history
                                
                                	port 24 hour Path performance data
                                	**type**\: list of    :py:class:`SonetHour24PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.sonet_hour24_path_history = YList()
                                    self.sonet_hour24_path_history.parent = self
                                    self.sonet_hour24_path_history.name = 'sonet_hour24_path_history'


                                class SonetHour24PathHistory(object):
                                    """
                                    port 24 hour Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sonet_hour24_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`SonetHour24PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.sonet_hour24_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances()
                                        self.sonet_hour24_path_time_line_instances.parent = self


                                    class SonetHour24PathTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_hour24_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`SonetHour24PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.sonet_hour24_path_time_line_instance = YList()
                                            self.sonet_hour24_path_time_line_instance.parent = self
                                            self.sonet_hour24_path_time_line_instance.name = 'sonet_hour24_path_time_line_instance'


                                        class SonetHour24PathTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Path(object):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:   :py:class:`PmSonetPathWidthEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnumEnum>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self.path_status = None
                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self.path_width = None


                                                class PathESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs']['meta_info']


                                                class PathSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs']['meta_info']


                                                class PathCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs']['meta_info']


                                                class PathUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.path_c_vs is not None and self.path_c_vs._has_data():
                                                        return True

                                                    if self.path_e_ss is not None and self.path_e_ss._has_data():
                                                        return True

                                                    if self.path_se_ss is not None and self.path_se_ss._has_data():
                                                        return True

                                                    if self.path_status is not None:
                                                        return True

                                                    if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                                        return True

                                                    if self.path_width is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path']['meta_info']


                                            class FePath(object):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_ua_ss = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_path_c_vs is not None:
                                                        return True

                                                    if self.far_end_path_e_ss is not None:
                                                        return True

                                                    if self.far_end_path_se_ss is not None:
                                                        return True

                                                    if self.far_end_path_ua_ss is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24-path-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_path is not None and self.fe_path._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.path is not None and self.path._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24-path-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.sonet_hour24_path_time_line_instance is not None:
                                                for child_ref in self.sonet_hour24_path_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24-path-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.sonet_hour24_path_time_line_instances is not None and self.sonet_hour24_path_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24-path-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sonet_hour24_path_history is not None:
                                        for child_ref in self.sonet_hour24_path_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories']['meta_info']


                            class SonetHour24OcnHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_hour24ocn_history
                                
                                	port 24 hour ocn performance data
                                	**type**\: list of    :py:class:`SonetHour24OcnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.sonet_hour24ocn_history = YList()
                                    self.sonet_hour24ocn_history.parent = self
                                    self.sonet_hour24ocn_history.name = 'sonet_hour24ocn_history'


                                class SonetHour24OcnHistory(object):
                                    """
                                    port 24 hour ocn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sonet_hour24ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`SonetHour24OcnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.sonet_hour24ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances()
                                        self.sonet_hour24ocn_time_line_instances.parent = self


                                    class SonetHour24OcnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_hour24ocn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`SonetHour24OcnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.sonet_hour24ocn_time_line_instance = YList()
                                            self.sonet_hour24ocn_time_line_instance.parent = self
                                            self.sonet_hour24ocn_time_line_instance.name = 'sonet_hour24ocn_time_line_instance'


                                        class SonetHour24OcnTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self.section = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Section(object):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self.section_status = None


                                                class SectionESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionESs']['meta_info']


                                                class SectionSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSeSs']['meta_info']


                                                class SectionSefSs(object):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-sef-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSefSs']['meta_info']


                                                class SectionCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionCVs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.section_c_vs is not None and self.section_c_vs._has_data():
                                                        return True

                                                    if self.section_e_ss is not None and self.section_e_ss._has_data():
                                                        return True

                                                    if self.section_se_ss is not None and self.section_se_ss._has_data():
                                                        return True

                                                    if self.section_sef_ss is not None and self.section_sef_ss._has_data():
                                                        return True

                                                    if self.section_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section']['meta_info']


                                            class Line(object):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self.line_status = None
                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self


                                                class LineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineESs']['meta_info']


                                                class LineSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineSeSs']['meta_info']


                                                class LineCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineCVs']['meta_info']


                                                class LineUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineUaSs']['meta_info']


                                                class LineFcLs(object):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-fc-ls'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineFcLs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.line_c_vs is not None and self.line_c_vs._has_data():
                                                        return True

                                                    if self.line_e_ss is not None and self.line_e_ss._has_data():
                                                        return True

                                                    if self.line_fc_ls is not None and self.line_fc_ls._has_data():
                                                        return True

                                                    if self.line_se_ss is not None and self.line_se_ss._has_data():
                                                        return True

                                                    if self.line_status is not None:
                                                        return True

                                                    if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line']['meta_info']


                                            class FeLine(object):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self


                                                class FarEndLineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineESs']['meta_info']


                                                class FarEndLineSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs']['meta_info']


                                                class FarEndLineCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineCVs']['meta_info']


                                                class FarEndLineUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs']['meta_info']


                                                class FarEndLineFcLs(object):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-fc-ls'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_line_c_vs is not None and self.far_end_line_c_vs._has_data():
                                                        return True

                                                    if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                                        return True

                                                    if self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls._has_data():
                                                        return True

                                                    if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                                        return True

                                                    if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24ocn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_line is not None and self.fe_line._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.line is not None and self.line._has_data():
                                                    return True

                                                if self.section is not None and self.section._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24ocn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.sonet_hour24ocn_time_line_instance is not None:
                                                for child_ref in self.sonet_hour24ocn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24ocn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.sonet_hour24ocn_time_line_instances is not None and self.sonet_hour24ocn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24ocn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sonet_hour24ocn_history is not None:
                                        for child_ref in self.sonet_hour24ocn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sonet-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sonet_hour24_path_histories is not None and self.sonet_hour24_path_histories._has_data():
                                    return True

                                if self.sonet_hour24ocn_histories is not None and self.sonet_hour24ocn_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:sonet-history/Cisco-IOS-XR-pmengine-oper:sonet-port-histories/Cisco-IOS-XR-pmengine-oper:sonet-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.sonet_hour24_history is not None and self.sonet_hour24_history._has_data():
                                return True

                            if self.sonet_minute15_history is not None and self.sonet_minute15_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:sonet-history/Cisco-IOS-XR-pmengine-oper:sonet-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.sonet_port_history is not None:
                            for child_ref in self.sonet_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:sonet-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.sonet_port_histories is not None and self.sonet_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.SonetHistory']['meta_info']


            class StsHistory(object):
                """
                STS controller History performance data
                
                .. attribute:: sts_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`StsPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.sts_port_histories = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories()
                    self.sts_port_histories.parent = self


                class StsPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: sts_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`StsPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.sts_port_history = YList()
                        self.sts_port_history.parent = self
                        self.sts_port_history.name = 'sts_port_history'


                    class StsPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: sts_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`StsHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History>`
                        
                        .. attribute:: sts_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`StsMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.sts_hour24_history = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History()
                            self.sts_hour24_history.parent = self
                            self.sts_minute15_history = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History()
                            self.sts_minute15_history.parent = self


                        class StsMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: sts_minute15_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`StsMinute15PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sts_minute15_path_histories = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories()
                                self.sts_minute15_path_histories.parent = self


                            class StsMinute15PathHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: sts_minute15_path_history
                                
                                	port 15\-minute Path performance data
                                	**type**\: list of    :py:class:`StsMinute15PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.sts_minute15_path_history = YList()
                                    self.sts_minute15_path_history.parent = self
                                    self.sts_minute15_path_history.name = 'sts_minute15_path_history'


                                class StsMinute15PathHistory(object):
                                    """
                                    port 15\-minute Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sts_minute15_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`StsMinute15PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.sts_minute15_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances()
                                        self.sts_minute15_path_time_line_instances.parent = self


                                    class StsMinute15PathTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sts_minute15_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`StsMinute15PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.sts_minute15_path_time_line_instance = YList()
                                            self.sts_minute15_path_time_line_instance.parent = self
                                            self.sts_minute15_path_time_line_instance.name = 'sts_minute15_path_time_line_instance'


                                        class StsMinute15PathTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Path(object):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:   :py:class:`PmSonetPathWidthEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnumEnum>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self.path_status = None
                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self.path_width = None


                                                class PathESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs']['meta_info']


                                                class PathSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs']['meta_info']


                                                class PathCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs']['meta_info']


                                                class PathUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.path_c_vs is not None and self.path_c_vs._has_data():
                                                        return True

                                                    if self.path_e_ss is not None and self.path_e_ss._has_data():
                                                        return True

                                                    if self.path_se_ss is not None and self.path_se_ss._has_data():
                                                        return True

                                                    if self.path_status is not None:
                                                        return True

                                                    if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                                        return True

                                                    if self.path_width is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path']['meta_info']


                                            class FePath(object):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_ua_ss = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_path_c_vs is not None:
                                                        return True

                                                    if self.far_end_path_e_ss is not None:
                                                        return True

                                                    if self.far_end_path_se_ss is not None:
                                                        return True

                                                    if self.far_end_path_ua_ss is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-minute15-path-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_path is not None and self.fe_path._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.path is not None and self.path._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-minute15-path-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.sts_minute15_path_time_line_instance is not None:
                                                for child_ref in self.sts_minute15_path_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-minute15-path-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.sts_minute15_path_time_line_instances is not None and self.sts_minute15_path_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-minute15-path-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sts_minute15_path_history is not None:
                                        for child_ref in self.sts_minute15_path_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sts_minute15_path_histories is not None and self.sts_minute15_path_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History']['meta_info']


                        class StsHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: sts_hour24_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`StsHour24PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sts_hour24_path_histories = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories()
                                self.sts_hour24_path_histories.parent = self


                            class StsHour24PathHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: sts_hour24_path_history
                                
                                	port 24 hour Path performance data
                                	**type**\: list of    :py:class:`StsHour24PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.sts_hour24_path_history = YList()
                                    self.sts_hour24_path_history.parent = self
                                    self.sts_hour24_path_history.name = 'sts_hour24_path_history'


                                class StsHour24PathHistory(object):
                                    """
                                    port 24 hour Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sts_hour24_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`StsHour24PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.sts_hour24_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances()
                                        self.sts_hour24_path_time_line_instances.parent = self


                                    class StsHour24PathTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sts_hour24_path_time_line_instance
                                        
                                        	port 15\-minute sts performance data
                                        	**type**\: list of    :py:class:`StsHour24PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.sts_hour24_path_time_line_instance = YList()
                                            self.sts_hour24_path_time_line_instance.parent = self
                                            self.sts_hour24_path_time_line_instance.name = 'sts_hour24_path_time_line_instance'


                                        class StsHour24PathTimeLineInstance(object):
                                            """
                                            port 15\-minute sts performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Path(object):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:   :py:class:`PmSonetPathWidthEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnumEnum>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self.path_status = None
                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self.path_width = None


                                                class PathESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs']['meta_info']


                                                class PathSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs']['meta_info']


                                                class PathCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs']['meta_info']


                                                class PathUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.path_c_vs is not None and self.path_c_vs._has_data():
                                                        return True

                                                    if self.path_e_ss is not None and self.path_e_ss._has_data():
                                                        return True

                                                    if self.path_se_ss is not None and self.path_se_ss._has_data():
                                                        return True

                                                    if self.path_status is not None:
                                                        return True

                                                    if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                                        return True

                                                    if self.path_width is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path']['meta_info']


                                            class FePath(object):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_ua_ss = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_path_c_vs is not None:
                                                        return True

                                                    if self.far_end_path_e_ss is not None:
                                                        return True

                                                    if self.far_end_path_se_ss is not None:
                                                        return True

                                                    if self.far_end_path_ua_ss is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-hour24-path-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_path is not None and self.fe_path._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.path is not None and self.path._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-hour24-path-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.sts_hour24_path_time_line_instance is not None:
                                                for child_ref in self.sts_hour24_path_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-hour24-path-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.sts_hour24_path_time_line_instances is not None and self.sts_hour24_path_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-hour24-path-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sts_hour24_path_history is not None:
                                        for child_ref in self.sts_hour24_path_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sts-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sts_hour24_path_histories is not None and self.sts_hour24_path_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:sts-history/Cisco-IOS-XR-pmengine-oper:sts-port-histories/Cisco-IOS-XR-pmengine-oper:sts-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.sts_hour24_history is not None and self.sts_hour24_history._has_data():
                                return True

                            if self.sts_minute15_history is not None and self.sts_minute15_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:sts-history/Cisco-IOS-XR-pmengine-oper:sts-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.sts_port_history is not None:
                            for child_ref in self.sts_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:sts-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.sts_port_histories is not None and self.sts_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StsHistory']['meta_info']


            class EthernetHistory(object):
                """
                EHERNET controller History performance data
                
                .. attribute:: ethernet_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`EthernetPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ethernet_port_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories()
                    self.ethernet_port_histories.parent = self


                class EthernetPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: ethernet_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`EthernetPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ethernet_port_history = YList()
                        self.ethernet_port_history.parent = self
                        self.ethernet_port_history.name = 'ethernet_port_history'


                    class EthernetPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: ethernet_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`EthernetHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History>`
                        
                        .. attribute:: ethernet_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`EthernetMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History>`
                        
                        .. attribute:: ethernet_second30_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`EthernetSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.ethernet_hour24_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History()
                            self.ethernet_hour24_history.parent = self
                            self.ethernet_minute15_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History()
                            self.ethernet_minute15_history.parent = self
                            self.ethernet_second30_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History()
                            self.ethernet_second30_history.parent = self


                        class EthernetSecond30History(object):
                            """
                            port current performance data
                            
                            .. attribute:: second30_ether_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:   :py:class:`Second30EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.second30_ether_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories()
                                self.second30_ether_histories.parent = self


                            class Second30EtherHistories(object):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: second30_ether_history
                                
                                	ETHERNET port 30 sec ether performance data
                                	**type**\: list of    :py:class:`Second30EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.second30_ether_history = YList()
                                    self.second30_ether_history.parent = self
                                    self.second30_ether_history.name = 'second30_ether_history'


                                class Second30EtherHistory(object):
                                    """
                                    ETHERNET port 30 sec ether performance
                                    data
                                    
                                    .. attribute:: slot_number  <key>
                                    
                                    	interval slot number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: second30_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`Second30EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.slot_number = None
                                        self.second30_ether_time_line_instances = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances()
                                        self.second30_ether_time_line_instances.parent = self


                                    class Second30EtherTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: second30_ether_time_line_instance
                                        
                                        	port 30 sec otn performance data
                                        	**type**\: list of    :py:class:`Second30EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.second30_ether_time_line_instance = YList()
                                            self.second30_ether_time_line_instance.parent = self
                                            self.second30_ether_time_line_instance.name = 'second30_ether_time_line_instance'


                                        class Second30EtherTimeLineInstance(object):
                                            """
                                            port 30 sec otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021QFrames>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021QFrames>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64Octet>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ether10241518_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self.ether128255_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self.ether256511_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self.ether5121023_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self.ether64_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self.ether65127_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self.fcs_errors_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self.if_in_errors = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self.if_in_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self.in8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021QFrames()
                                                self.in8021q_frames.parent = self
                                                self.in_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self.in_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self.in_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self.in_drop_overrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self.in_error_collisions = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self.in_error_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self.in_error_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self.in_error_jabbers = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self.in_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self.in_error_runt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self.in_error_symbol = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self.in_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self.in_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self.in_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self.in_mib_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self.in_mib_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self.in_mibcrc = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self.in_pause_frame = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self.in_pkt64_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self.in_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self.index = None
                                                self.jabber_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.long_frames_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self.octet_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self.out8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021QFrames()
                                                self.out8021q_frames.parent = self
                                                self.out_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self.out_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self.out_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self.out_drop_underrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self.out_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self.out_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self.out_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self.out_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self.out_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self.out_pause_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self.out_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self.outpkt64octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64Octet()
                                                self.outpkt64octet.parent = self
                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self.rx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self.rx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self.sec30_support = None
                                                self.stat_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self.timestamp = None
                                                self.tx_bad_fcs = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self.tx_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self.tx_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self.tx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self.tx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self.valid = None


                                            class RxPkt(object):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt']['meta_info']


                                            class StatPkt(object):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stat-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt']['meta_info']


                                            class OctetStat(object):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:octet-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat']['meta_info']


                                            class OversizePktStat(object):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oversize-pkt-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat']['meta_info']


                                            class FcsErrorsStat(object):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fcs-errors-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat']['meta_info']


                                            class LongFramesStat(object):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:long-frames-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat']['meta_info']


                                            class JabberStat(object):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:jabber-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat']['meta_info']


                                            class Ether64Octets(object):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether64-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets']['meta_info']


                                            class Ether65127Octet(object):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether65127-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet']['meta_info']


                                            class Ether128255Octet(object):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether128255-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet']['meta_info']


                                            class Ether256511Octet(object):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether256511-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet']['meta_info']


                                            class Ether5121023Octet(object):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether5121023-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet']['meta_info']


                                            class Ether10241518Octet(object):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether10241518-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet']['meta_info']


                                            class InUcastPkt(object):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-ucast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt']['meta_info']


                                            class InMcastPkt(object):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt']['meta_info']


                                            class InBcastPkt(object):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-bcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt']['meta_info']


                                            class OutUcastPkt(object):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-ucast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt']['meta_info']


                                            class OutBcastPkt(object):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-bcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt']['meta_info']


                                            class OutMcastPkt(object):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-mcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt']['meta_info']


                                            class TxPkt(object):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt']['meta_info']


                                            class IfInErrors(object):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-errors'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors']['meta_info']


                                            class IfInOctets(object):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets']['meta_info']


                                            class EtherStatMulticastPkt(object):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-multicast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt']['meta_info']


                                            class EtherStatBroadcastPkt(object):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-broadcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt']['meta_info']


                                            class EtherStatUndersizedPkt(object):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-undersized-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt']['meta_info']


                                            class OutOctets(object):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets']['meta_info']


                                            class InPauseFrame(object):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pause-frame'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame']['meta_info']


                                            class InGoodBytes(object):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-bytes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes']['meta_info']


                                            class In8021QFrames(object):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in8021q-frames'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021QFrames']['meta_info']


                                            class InPkts1519MaxOctets(object):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1519-max-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets']['meta_info']


                                            class InGoodPkts(object):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-pkts'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts']['meta_info']


                                            class InDropOverrun(object):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-overrun'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun']['meta_info']


                                            class InDropAbort(object):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-abort'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort']['meta_info']


                                            class InDropInvalidVlan(object):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-vlan'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan']['meta_info']


                                            class InDropInvalidDmac(object):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-dmac'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac']['meta_info']


                                            class InDropInvalidEncap(object):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-encap'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap']['meta_info']


                                            class InDropOther(object):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther']['meta_info']


                                            class InMibGiant(object):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-giant'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant']['meta_info']


                                            class InMibJabber(object):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-jabber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber']['meta_info']


                                            class InMibcrc(object):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mibcrc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc']['meta_info']


                                            class InErrorCollisions(object):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-collisions'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions']['meta_info']


                                            class InErrorSymbol(object):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-symbol'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol']['meta_info']


                                            class OutGoodBytes(object):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-bytes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes']['meta_info']


                                            class Out8021QFrames(object):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out8021q-frames'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021QFrames']['meta_info']


                                            class OutPauseFrames(object):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pause-frames'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames']['meta_info']


                                            class OutPkts1519MaxOctets(object):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts1519-max-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets']['meta_info']


                                            class OutGoodPkts(object):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-pkts'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts']['meta_info']


                                            class OutDropUnderrun(object):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-underrun'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun']['meta_info']


                                            class OutDropAbort(object):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-abort'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort']['meta_info']


                                            class OutDropOther(object):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther']['meta_info']


                                            class OutErrorOther(object):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-error-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther']['meta_info']


                                            class InErrorGiant(object):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-giant'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant']['meta_info']


                                            class InErrorRunt(object):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-runt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt']['meta_info']


                                            class InErrorJabbers(object):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-jabbers'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers']['meta_info']


                                            class InErrorFragments(object):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-fragments'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments']['meta_info']


                                            class InErrorOther(object):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther']['meta_info']


                                            class InPkt64Octet(object):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkt64-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet']['meta_info']


                                            class InPkts65To127Octets(object):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts65-to127-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets']['meta_info']


                                            class InPkts128To255Octets(object):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts128-to255-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets']['meta_info']


                                            class InPkts256To511Octets(object):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts256-to511-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets']['meta_info']


                                            class InPkts512To1023Octets(object):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts512-to1023-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets']['meta_info']


                                            class InPkts1024To1518Octets(object):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1024-to1518-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets']['meta_info']


                                            class Outpkt64Octet(object):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:outpkt64octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64Octet']['meta_info']


                                            class OutPkts65127Octets(object):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts65127-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets']['meta_info']


                                            class OutPkts128255Octets(object):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts128255-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets']['meta_info']


                                            class OutPkts256511Octets(object):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts256511-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets']['meta_info']


                                            class OutPkts5121023Octets(object):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts5121023-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets']['meta_info']


                                            class OutPkts10241518Octets(object):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts10241518-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets']['meta_info']


                                            class RxUtil(object):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-util'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil']['meta_info']


                                            class TxUtil(object):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-util'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil']['meta_info']


                                            class TxUndersizedPkt(object):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-undersized-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt']['meta_info']


                                            class TxOversizedPkt(object):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-oversized-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt']['meta_info']


                                            class TxFragments(object):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-fragments'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments']['meta_info']


                                            class TxJabber(object):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-jabber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber']['meta_info']


                                            class TxBadFcs(object):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-bad-fcs'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:second30-ether-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ether10241518_octet is not None and self.ether10241518_octet._has_data():
                                                    return True

                                                if self.ether128255_octet is not None and self.ether128255_octet._has_data():
                                                    return True

                                                if self.ether256511_octet is not None and self.ether256511_octet._has_data():
                                                    return True

                                                if self.ether5121023_octet is not None and self.ether5121023_octet._has_data():
                                                    return True

                                                if self.ether64_octets is not None and self.ether64_octets._has_data():
                                                    return True

                                                if self.ether65127_octet is not None and self.ether65127_octet._has_data():
                                                    return True

                                                if self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt._has_data():
                                                    return True

                                                if self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt._has_data():
                                                    return True

                                                if self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt._has_data():
                                                    return True

                                                if self.fcs_errors_stat is not None and self.fcs_errors_stat._has_data():
                                                    return True

                                                if self.if_in_errors is not None and self.if_in_errors._has_data():
                                                    return True

                                                if self.if_in_octets is not None and self.if_in_octets._has_data():
                                                    return True

                                                if self.in8021q_frames is not None and self.in8021q_frames._has_data():
                                                    return True

                                                if self.in_bcast_pkt is not None and self.in_bcast_pkt._has_data():
                                                    return True

                                                if self.in_drop_abort is not None and self.in_drop_abort._has_data():
                                                    return True

                                                if self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac._has_data():
                                                    return True

                                                if self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap._has_data():
                                                    return True

                                                if self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan._has_data():
                                                    return True

                                                if self.in_drop_other is not None and self.in_drop_other._has_data():
                                                    return True

                                                if self.in_drop_overrun is not None and self.in_drop_overrun._has_data():
                                                    return True

                                                if self.in_error_collisions is not None and self.in_error_collisions._has_data():
                                                    return True

                                                if self.in_error_fragments is not None and self.in_error_fragments._has_data():
                                                    return True

                                                if self.in_error_giant is not None and self.in_error_giant._has_data():
                                                    return True

                                                if self.in_error_jabbers is not None and self.in_error_jabbers._has_data():
                                                    return True

                                                if self.in_error_other is not None and self.in_error_other._has_data():
                                                    return True

                                                if self.in_error_runt is not None and self.in_error_runt._has_data():
                                                    return True

                                                if self.in_error_symbol is not None and self.in_error_symbol._has_data():
                                                    return True

                                                if self.in_good_bytes is not None and self.in_good_bytes._has_data():
                                                    return True

                                                if self.in_good_pkts is not None and self.in_good_pkts._has_data():
                                                    return True

                                                if self.in_mcast_pkt is not None and self.in_mcast_pkt._has_data():
                                                    return True

                                                if self.in_mib_giant is not None and self.in_mib_giant._has_data():
                                                    return True

                                                if self.in_mib_jabber is not None and self.in_mib_jabber._has_data():
                                                    return True

                                                if self.in_mibcrc is not None and self.in_mibcrc._has_data():
                                                    return True

                                                if self.in_pause_frame is not None and self.in_pause_frame._has_data():
                                                    return True

                                                if self.in_pkt64_octet is not None and self.in_pkt64_octet._has_data():
                                                    return True

                                                if self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets._has_data():
                                                    return True

                                                if self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets._has_data():
                                                    return True

                                                if self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets._has_data():
                                                    return True

                                                if self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets._has_data():
                                                    return True

                                                if self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets._has_data():
                                                    return True

                                                if self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets._has_data():
                                                    return True

                                                if self.in_ucast_pkt is not None and self.in_ucast_pkt._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.jabber_stat is not None and self.jabber_stat._has_data():
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.long_frames_stat is not None and self.long_frames_stat._has_data():
                                                    return True

                                                if self.octet_stat is not None and self.octet_stat._has_data():
                                                    return True

                                                if self.out8021q_frames is not None and self.out8021q_frames._has_data():
                                                    return True

                                                if self.out_bcast_pkt is not None and self.out_bcast_pkt._has_data():
                                                    return True

                                                if self.out_drop_abort is not None and self.out_drop_abort._has_data():
                                                    return True

                                                if self.out_drop_other is not None and self.out_drop_other._has_data():
                                                    return True

                                                if self.out_drop_underrun is not None and self.out_drop_underrun._has_data():
                                                    return True

                                                if self.out_error_other is not None and self.out_error_other._has_data():
                                                    return True

                                                if self.out_good_bytes is not None and self.out_good_bytes._has_data():
                                                    return True

                                                if self.out_good_pkts is not None and self.out_good_pkts._has_data():
                                                    return True

                                                if self.out_mcast_pkt is not None and self.out_mcast_pkt._has_data():
                                                    return True

                                                if self.out_octets is not None and self.out_octets._has_data():
                                                    return True

                                                if self.out_pause_frames is not None and self.out_pause_frames._has_data():
                                                    return True

                                                if self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets._has_data():
                                                    return True

                                                if self.out_pkts128255_octets is not None and self.out_pkts128255_octets._has_data():
                                                    return True

                                                if self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets._has_data():
                                                    return True

                                                if self.out_pkts256511_octets is not None and self.out_pkts256511_octets._has_data():
                                                    return True

                                                if self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets._has_data():
                                                    return True

                                                if self.out_pkts65127_octets is not None and self.out_pkts65127_octets._has_data():
                                                    return True

                                                if self.out_ucast_pkt is not None and self.out_ucast_pkt._has_data():
                                                    return True

                                                if self.outpkt64octet is not None and self.outpkt64octet._has_data():
                                                    return True

                                                if self.oversize_pkt_stat is not None and self.oversize_pkt_stat._has_data():
                                                    return True

                                                if self.rx_pkt is not None and self.rx_pkt._has_data():
                                                    return True

                                                if self.rx_util is not None and self.rx_util._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.stat_pkt is not None and self.stat_pkt._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.tx_bad_fcs is not None and self.tx_bad_fcs._has_data():
                                                    return True

                                                if self.tx_fragments is not None and self.tx_fragments._has_data():
                                                    return True

                                                if self.tx_jabber is not None and self.tx_jabber._has_data():
                                                    return True

                                                if self.tx_oversized_pkt is not None and self.tx_oversized_pkt._has_data():
                                                    return True

                                                if self.tx_pkt is not None and self.tx_pkt._has_data():
                                                    return True

                                                if self.tx_undersized_pkt is not None and self.tx_undersized_pkt._has_data():
                                                    return True

                                                if self.tx_util is not None and self.tx_util._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:second30-ether-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.second30_ether_time_line_instance is not None:
                                                for child_ref in self.second30_ether_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.slot_number is None:
                                            raise YPYModelError('Key property slot_number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:second30-ether-history[Cisco-IOS-XR-pmengine-oper:slot-number = ' + str(self.slot_number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.slot_number is not None:
                                            return True

                                        if self.second30_ether_time_line_instances is not None and self.second30_ether_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:second30-ether-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.second30_ether_history is not None:
                                        for child_ref in self.second30_ether_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-second30-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.second30_ether_histories is not None and self.second30_ether_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History']['meta_info']


                        class EthernetHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: ethernet_hour24_ether_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`EthernetHour24EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ethernet_hour24_ether_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories()
                                self.ethernet_hour24_ether_histories.parent = self


                            class EthernetHour24EtherHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: ethernet_hour24_ether_history
                                
                                	port 24 hour ethernet performance data
                                	**type**\: list of    :py:class:`EthernetHour24EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ethernet_hour24_ether_history = YList()
                                    self.ethernet_hour24_ether_history.parent = self
                                    self.ethernet_hour24_ether_history.name = 'ethernet_hour24_ether_history'


                                class EthernetHour24EtherHistory(object):
                                    """
                                    port 24 hour ethernet performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ethernet_hour24_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`EthernetHour24EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.ethernet_hour24_ether_time_line_instances = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances()
                                        self.ethernet_hour24_ether_time_line_instances.parent = self


                                    class EthernetHour24EtherTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ethernet_hour24_ether_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`EthernetHour24EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ethernet_hour24_ether_time_line_instance = YList()
                                            self.ethernet_hour24_ether_time_line_instance.parent = self
                                            self.ethernet_hour24_ether_time_line_instance.name = 'ethernet_hour24_ether_time_line_instance'


                                        class EthernetHour24EtherTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021QFrames>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021QFrames>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64Octet>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ether10241518_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self.ether128255_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self.ether256511_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self.ether5121023_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self.ether64_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self.ether65127_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self.fcs_errors_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self.if_in_errors = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self.if_in_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self.in8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021QFrames()
                                                self.in8021q_frames.parent = self
                                                self.in_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self.in_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self.in_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self.in_drop_overrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self.in_error_collisions = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self.in_error_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self.in_error_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self.in_error_jabbers = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self.in_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self.in_error_runt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self.in_error_symbol = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self.in_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self.in_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self.in_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self.in_mib_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self.in_mib_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self.in_mibcrc = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self.in_pause_frame = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self.in_pkt64_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self.in_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self.index = None
                                                self.jabber_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.long_frames_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self.octet_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self.out8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021QFrames()
                                                self.out8021q_frames.parent = self
                                                self.out_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self.out_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self.out_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self.out_drop_underrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self.out_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self.out_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self.out_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self.out_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self.out_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self.out_pause_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self.out_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self.outpkt64octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64Octet()
                                                self.outpkt64octet.parent = self
                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self.rx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self.rx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self.sec30_support = None
                                                self.stat_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self.timestamp = None
                                                self.tx_bad_fcs = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self.tx_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self.tx_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self.tx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self.tx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self.valid = None


                                            class RxPkt(object):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt']['meta_info']


                                            class StatPkt(object):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stat-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt']['meta_info']


                                            class OctetStat(object):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:octet-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat']['meta_info']


                                            class OversizePktStat(object):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oversize-pkt-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat']['meta_info']


                                            class FcsErrorsStat(object):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fcs-errors-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat']['meta_info']


                                            class LongFramesStat(object):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:long-frames-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat']['meta_info']


                                            class JabberStat(object):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:jabber-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat']['meta_info']


                                            class Ether64Octets(object):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether64-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets']['meta_info']


                                            class Ether65127Octet(object):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether65127-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet']['meta_info']


                                            class Ether128255Octet(object):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether128255-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet']['meta_info']


                                            class Ether256511Octet(object):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether256511-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet']['meta_info']


                                            class Ether5121023Octet(object):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether5121023-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet']['meta_info']


                                            class Ether10241518Octet(object):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether10241518-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet']['meta_info']


                                            class InUcastPkt(object):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-ucast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt']['meta_info']


                                            class InMcastPkt(object):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt']['meta_info']


                                            class InBcastPkt(object):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-bcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt']['meta_info']


                                            class OutUcastPkt(object):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-ucast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt']['meta_info']


                                            class OutBcastPkt(object):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-bcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt']['meta_info']


                                            class OutMcastPkt(object):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-mcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt']['meta_info']


                                            class TxPkt(object):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt']['meta_info']


                                            class IfInErrors(object):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-errors'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors']['meta_info']


                                            class IfInOctets(object):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets']['meta_info']


                                            class EtherStatMulticastPkt(object):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-multicast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt']['meta_info']


                                            class EtherStatBroadcastPkt(object):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-broadcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt']['meta_info']


                                            class EtherStatUndersizedPkt(object):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-undersized-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt']['meta_info']


                                            class OutOctets(object):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets']['meta_info']


                                            class InPauseFrame(object):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pause-frame'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame']['meta_info']


                                            class InGoodBytes(object):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-bytes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes']['meta_info']


                                            class In8021QFrames(object):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in8021q-frames'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021QFrames']['meta_info']


                                            class InPkts1519MaxOctets(object):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1519-max-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets']['meta_info']


                                            class InGoodPkts(object):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-pkts'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts']['meta_info']


                                            class InDropOverrun(object):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-overrun'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun']['meta_info']


                                            class InDropAbort(object):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-abort'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort']['meta_info']


                                            class InDropInvalidVlan(object):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-vlan'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan']['meta_info']


                                            class InDropInvalidDmac(object):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-dmac'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac']['meta_info']


                                            class InDropInvalidEncap(object):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-encap'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap']['meta_info']


                                            class InDropOther(object):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther']['meta_info']


                                            class InMibGiant(object):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-giant'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant']['meta_info']


                                            class InMibJabber(object):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-jabber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber']['meta_info']


                                            class InMibcrc(object):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mibcrc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc']['meta_info']


                                            class InErrorCollisions(object):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-collisions'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions']['meta_info']


                                            class InErrorSymbol(object):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-symbol'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol']['meta_info']


                                            class OutGoodBytes(object):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-bytes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes']['meta_info']


                                            class Out8021QFrames(object):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out8021q-frames'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021QFrames']['meta_info']


                                            class OutPauseFrames(object):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pause-frames'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames']['meta_info']


                                            class OutPkts1519MaxOctets(object):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts1519-max-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets']['meta_info']


                                            class OutGoodPkts(object):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-pkts'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts']['meta_info']


                                            class OutDropUnderrun(object):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-underrun'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun']['meta_info']


                                            class OutDropAbort(object):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-abort'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort']['meta_info']


                                            class OutDropOther(object):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther']['meta_info']


                                            class OutErrorOther(object):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-error-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther']['meta_info']


                                            class InErrorGiant(object):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-giant'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant']['meta_info']


                                            class InErrorRunt(object):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-runt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt']['meta_info']


                                            class InErrorJabbers(object):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-jabbers'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers']['meta_info']


                                            class InErrorFragments(object):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-fragments'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments']['meta_info']


                                            class InErrorOther(object):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther']['meta_info']


                                            class InPkt64Octet(object):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkt64-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet']['meta_info']


                                            class InPkts65To127Octets(object):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts65-to127-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets']['meta_info']


                                            class InPkts128To255Octets(object):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts128-to255-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets']['meta_info']


                                            class InPkts256To511Octets(object):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts256-to511-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets']['meta_info']


                                            class InPkts512To1023Octets(object):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts512-to1023-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets']['meta_info']


                                            class InPkts1024To1518Octets(object):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1024-to1518-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets']['meta_info']


                                            class Outpkt64Octet(object):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:outpkt64octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64Octet']['meta_info']


                                            class OutPkts65127Octets(object):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts65127-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets']['meta_info']


                                            class OutPkts128255Octets(object):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts128255-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets']['meta_info']


                                            class OutPkts256511Octets(object):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts256511-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets']['meta_info']


                                            class OutPkts5121023Octets(object):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts5121023-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets']['meta_info']


                                            class OutPkts10241518Octets(object):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts10241518-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets']['meta_info']


                                            class RxUtil(object):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-util'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil']['meta_info']


                                            class TxUtil(object):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-util'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil']['meta_info']


                                            class TxUndersizedPkt(object):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-undersized-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt']['meta_info']


                                            class TxOversizedPkt(object):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-oversized-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt']['meta_info']


                                            class TxFragments(object):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-fragments'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments']['meta_info']


                                            class TxJabber(object):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-jabber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber']['meta_info']


                                            class TxBadFcs(object):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-bad-fcs'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-hour24-ether-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ether10241518_octet is not None and self.ether10241518_octet._has_data():
                                                    return True

                                                if self.ether128255_octet is not None and self.ether128255_octet._has_data():
                                                    return True

                                                if self.ether256511_octet is not None and self.ether256511_octet._has_data():
                                                    return True

                                                if self.ether5121023_octet is not None and self.ether5121023_octet._has_data():
                                                    return True

                                                if self.ether64_octets is not None and self.ether64_octets._has_data():
                                                    return True

                                                if self.ether65127_octet is not None and self.ether65127_octet._has_data():
                                                    return True

                                                if self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt._has_data():
                                                    return True

                                                if self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt._has_data():
                                                    return True

                                                if self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt._has_data():
                                                    return True

                                                if self.fcs_errors_stat is not None and self.fcs_errors_stat._has_data():
                                                    return True

                                                if self.if_in_errors is not None and self.if_in_errors._has_data():
                                                    return True

                                                if self.if_in_octets is not None and self.if_in_octets._has_data():
                                                    return True

                                                if self.in8021q_frames is not None and self.in8021q_frames._has_data():
                                                    return True

                                                if self.in_bcast_pkt is not None and self.in_bcast_pkt._has_data():
                                                    return True

                                                if self.in_drop_abort is not None and self.in_drop_abort._has_data():
                                                    return True

                                                if self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac._has_data():
                                                    return True

                                                if self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap._has_data():
                                                    return True

                                                if self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan._has_data():
                                                    return True

                                                if self.in_drop_other is not None and self.in_drop_other._has_data():
                                                    return True

                                                if self.in_drop_overrun is not None and self.in_drop_overrun._has_data():
                                                    return True

                                                if self.in_error_collisions is not None and self.in_error_collisions._has_data():
                                                    return True

                                                if self.in_error_fragments is not None and self.in_error_fragments._has_data():
                                                    return True

                                                if self.in_error_giant is not None and self.in_error_giant._has_data():
                                                    return True

                                                if self.in_error_jabbers is not None and self.in_error_jabbers._has_data():
                                                    return True

                                                if self.in_error_other is not None and self.in_error_other._has_data():
                                                    return True

                                                if self.in_error_runt is not None and self.in_error_runt._has_data():
                                                    return True

                                                if self.in_error_symbol is not None and self.in_error_symbol._has_data():
                                                    return True

                                                if self.in_good_bytes is not None and self.in_good_bytes._has_data():
                                                    return True

                                                if self.in_good_pkts is not None and self.in_good_pkts._has_data():
                                                    return True

                                                if self.in_mcast_pkt is not None and self.in_mcast_pkt._has_data():
                                                    return True

                                                if self.in_mib_giant is not None and self.in_mib_giant._has_data():
                                                    return True

                                                if self.in_mib_jabber is not None and self.in_mib_jabber._has_data():
                                                    return True

                                                if self.in_mibcrc is not None and self.in_mibcrc._has_data():
                                                    return True

                                                if self.in_pause_frame is not None and self.in_pause_frame._has_data():
                                                    return True

                                                if self.in_pkt64_octet is not None and self.in_pkt64_octet._has_data():
                                                    return True

                                                if self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets._has_data():
                                                    return True

                                                if self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets._has_data():
                                                    return True

                                                if self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets._has_data():
                                                    return True

                                                if self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets._has_data():
                                                    return True

                                                if self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets._has_data():
                                                    return True

                                                if self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets._has_data():
                                                    return True

                                                if self.in_ucast_pkt is not None and self.in_ucast_pkt._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.jabber_stat is not None and self.jabber_stat._has_data():
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.long_frames_stat is not None and self.long_frames_stat._has_data():
                                                    return True

                                                if self.octet_stat is not None and self.octet_stat._has_data():
                                                    return True

                                                if self.out8021q_frames is not None and self.out8021q_frames._has_data():
                                                    return True

                                                if self.out_bcast_pkt is not None and self.out_bcast_pkt._has_data():
                                                    return True

                                                if self.out_drop_abort is not None and self.out_drop_abort._has_data():
                                                    return True

                                                if self.out_drop_other is not None and self.out_drop_other._has_data():
                                                    return True

                                                if self.out_drop_underrun is not None and self.out_drop_underrun._has_data():
                                                    return True

                                                if self.out_error_other is not None and self.out_error_other._has_data():
                                                    return True

                                                if self.out_good_bytes is not None and self.out_good_bytes._has_data():
                                                    return True

                                                if self.out_good_pkts is not None and self.out_good_pkts._has_data():
                                                    return True

                                                if self.out_mcast_pkt is not None and self.out_mcast_pkt._has_data():
                                                    return True

                                                if self.out_octets is not None and self.out_octets._has_data():
                                                    return True

                                                if self.out_pause_frames is not None and self.out_pause_frames._has_data():
                                                    return True

                                                if self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets._has_data():
                                                    return True

                                                if self.out_pkts128255_octets is not None and self.out_pkts128255_octets._has_data():
                                                    return True

                                                if self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets._has_data():
                                                    return True

                                                if self.out_pkts256511_octets is not None and self.out_pkts256511_octets._has_data():
                                                    return True

                                                if self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets._has_data():
                                                    return True

                                                if self.out_pkts65127_octets is not None and self.out_pkts65127_octets._has_data():
                                                    return True

                                                if self.out_ucast_pkt is not None and self.out_ucast_pkt._has_data():
                                                    return True

                                                if self.outpkt64octet is not None and self.outpkt64octet._has_data():
                                                    return True

                                                if self.oversize_pkt_stat is not None and self.oversize_pkt_stat._has_data():
                                                    return True

                                                if self.rx_pkt is not None and self.rx_pkt._has_data():
                                                    return True

                                                if self.rx_util is not None and self.rx_util._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.stat_pkt is not None and self.stat_pkt._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.tx_bad_fcs is not None and self.tx_bad_fcs._has_data():
                                                    return True

                                                if self.tx_fragments is not None and self.tx_fragments._has_data():
                                                    return True

                                                if self.tx_jabber is not None and self.tx_jabber._has_data():
                                                    return True

                                                if self.tx_oversized_pkt is not None and self.tx_oversized_pkt._has_data():
                                                    return True

                                                if self.tx_pkt is not None and self.tx_pkt._has_data():
                                                    return True

                                                if self.tx_undersized_pkt is not None and self.tx_undersized_pkt._has_data():
                                                    return True

                                                if self.tx_util is not None and self.tx_util._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-hour24-ether-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ethernet_hour24_ether_time_line_instance is not None:
                                                for child_ref in self.ethernet_hour24_ether_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-hour24-ether-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.ethernet_hour24_ether_time_line_instances is not None and self.ethernet_hour24_ether_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-hour24-ether-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ethernet_hour24_ether_history is not None:
                                        for child_ref in self.ethernet_hour24_ether_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ethernet_hour24_ether_histories is not None and self.ethernet_hour24_ether_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History']['meta_info']


                        class EthernetMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: minute15_ether_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:   :py:class:`Minute15EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.minute15_ether_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories()
                                self.minute15_ether_histories.parent = self


                            class Minute15EtherHistories(object):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: minute15_ether_history
                                
                                	ETHERNET port 15\-minute ether performance data
                                	**type**\: list of    :py:class:`Minute15EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.minute15_ether_history = YList()
                                    self.minute15_ether_history.parent = self
                                    self.minute15_ether_history.name = 'minute15_ether_history'


                                class Minute15EtherHistory(object):
                                    """
                                    ETHERNET port 15\-minute ether performance
                                    data
                                    
                                    .. attribute:: slot_number  <key>
                                    
                                    	interval slot number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minute15_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`Minute15EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.slot_number = None
                                        self.minute15_ether_time_line_instances = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances()
                                        self.minute15_ether_time_line_instances.parent = self


                                    class Minute15EtherTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: minute15_ether_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`Minute15EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.minute15_ether_time_line_instance = YList()
                                            self.minute15_ether_time_line_instance.parent = self
                                            self.minute15_ether_time_line_instance.name = 'minute15_ether_time_line_instance'


                                        class Minute15EtherTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021QFrames>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021QFrames>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64Octet>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ether10241518_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self.ether128255_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self.ether256511_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self.ether5121023_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self.ether64_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self.ether65127_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self.fcs_errors_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self.if_in_errors = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self.if_in_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self.in8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021QFrames()
                                                self.in8021q_frames.parent = self
                                                self.in_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self.in_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self.in_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self.in_drop_overrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self.in_error_collisions = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self.in_error_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self.in_error_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self.in_error_jabbers = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self.in_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self.in_error_runt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self.in_error_symbol = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self.in_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self.in_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self.in_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self.in_mib_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self.in_mib_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self.in_mibcrc = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self.in_pause_frame = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self.in_pkt64_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self.in_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self.index = None
                                                self.jabber_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.long_frames_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self.octet_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self.out8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021QFrames()
                                                self.out8021q_frames.parent = self
                                                self.out_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self.out_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self.out_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self.out_drop_underrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self.out_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self.out_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self.out_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self.out_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self.out_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self.out_pause_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self.out_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self.outpkt64octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64Octet()
                                                self.outpkt64octet.parent = self
                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self.rx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self.rx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self.sec30_support = None
                                                self.stat_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self.timestamp = None
                                                self.tx_bad_fcs = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self.tx_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self.tx_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self.tx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self.tx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self.valid = None


                                            class RxPkt(object):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt']['meta_info']


                                            class StatPkt(object):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stat-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt']['meta_info']


                                            class OctetStat(object):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:octet-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat']['meta_info']


                                            class OversizePktStat(object):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oversize-pkt-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat']['meta_info']


                                            class FcsErrorsStat(object):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fcs-errors-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat']['meta_info']


                                            class LongFramesStat(object):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:long-frames-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat']['meta_info']


                                            class JabberStat(object):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:jabber-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat']['meta_info']


                                            class Ether64Octets(object):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether64-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets']['meta_info']


                                            class Ether65127Octet(object):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether65127-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet']['meta_info']


                                            class Ether128255Octet(object):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether128255-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet']['meta_info']


                                            class Ether256511Octet(object):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether256511-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet']['meta_info']


                                            class Ether5121023Octet(object):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether5121023-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet']['meta_info']


                                            class Ether10241518Octet(object):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether10241518-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet']['meta_info']


                                            class InUcastPkt(object):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-ucast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt']['meta_info']


                                            class InMcastPkt(object):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt']['meta_info']


                                            class InBcastPkt(object):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-bcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt']['meta_info']


                                            class OutUcastPkt(object):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-ucast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt']['meta_info']


                                            class OutBcastPkt(object):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-bcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt']['meta_info']


                                            class OutMcastPkt(object):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-mcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt']['meta_info']


                                            class TxPkt(object):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt']['meta_info']


                                            class IfInErrors(object):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-errors'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors']['meta_info']


                                            class IfInOctets(object):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:if-in-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets']['meta_info']


                                            class EtherStatMulticastPkt(object):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-multicast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt']['meta_info']


                                            class EtherStatBroadcastPkt(object):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-broadcast-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt']['meta_info']


                                            class EtherStatUndersizedPkt(object):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ether-stat-undersized-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt']['meta_info']


                                            class OutOctets(object):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets']['meta_info']


                                            class InPauseFrame(object):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pause-frame'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame']['meta_info']


                                            class InGoodBytes(object):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-bytes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes']['meta_info']


                                            class In8021QFrames(object):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in8021q-frames'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021QFrames']['meta_info']


                                            class InPkts1519MaxOctets(object):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1519-max-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets']['meta_info']


                                            class InGoodPkts(object):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-good-pkts'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts']['meta_info']


                                            class InDropOverrun(object):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-overrun'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun']['meta_info']


                                            class InDropAbort(object):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-abort'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort']['meta_info']


                                            class InDropInvalidVlan(object):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-vlan'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan']['meta_info']


                                            class InDropInvalidDmac(object):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-dmac'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac']['meta_info']


                                            class InDropInvalidEncap(object):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-invalid-encap'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap']['meta_info']


                                            class InDropOther(object):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-drop-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther']['meta_info']


                                            class InMibGiant(object):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-giant'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant']['meta_info']


                                            class InMibJabber(object):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mib-jabber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber']['meta_info']


                                            class InMibcrc(object):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-mibcrc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc']['meta_info']


                                            class InErrorCollisions(object):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-collisions'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions']['meta_info']


                                            class InErrorSymbol(object):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-symbol'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol']['meta_info']


                                            class OutGoodBytes(object):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-bytes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes']['meta_info']


                                            class Out8021QFrames(object):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out8021q-frames'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021QFrames']['meta_info']


                                            class OutPauseFrames(object):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pause-frames'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames']['meta_info']


                                            class OutPkts1519MaxOctets(object):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts1519-max-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets']['meta_info']


                                            class OutGoodPkts(object):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-good-pkts'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts']['meta_info']


                                            class OutDropUnderrun(object):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-underrun'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun']['meta_info']


                                            class OutDropAbort(object):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-abort'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort']['meta_info']


                                            class OutDropOther(object):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-drop-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther']['meta_info']


                                            class OutErrorOther(object):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-error-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther']['meta_info']


                                            class InErrorGiant(object):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-giant'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant']['meta_info']


                                            class InErrorRunt(object):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-runt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt']['meta_info']


                                            class InErrorJabbers(object):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-jabbers'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers']['meta_info']


                                            class InErrorFragments(object):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-fragments'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments']['meta_info']


                                            class InErrorOther(object):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-error-other'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther']['meta_info']


                                            class InPkt64Octet(object):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkt64-octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet']['meta_info']


                                            class InPkts65To127Octets(object):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts65-to127-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets']['meta_info']


                                            class InPkts128To255Octets(object):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts128-to255-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets']['meta_info']


                                            class InPkts256To511Octets(object):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts256-to511-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets']['meta_info']


                                            class InPkts512To1023Octets(object):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts512-to1023-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets']['meta_info']


                                            class InPkts1024To1518Octets(object):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:in-pkts1024-to1518-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets']['meta_info']


                                            class Outpkt64Octet(object):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:outpkt64octet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64Octet']['meta_info']


                                            class OutPkts65127Octets(object):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts65127-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets']['meta_info']


                                            class OutPkts128255Octets(object):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts128255-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets']['meta_info']


                                            class OutPkts256511Octets(object):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts256511-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets']['meta_info']


                                            class OutPkts5121023Octets(object):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts5121023-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets']['meta_info']


                                            class OutPkts10241518Octets(object):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:out-pkts10241518-octets'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets']['meta_info']


                                            class RxUtil(object):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-util'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil']['meta_info']


                                            class TxUtil(object):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-util'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil']['meta_info']


                                            class TxUndersizedPkt(object):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-undersized-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt']['meta_info']


                                            class TxOversizedPkt(object):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-oversized-pkt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt']['meta_info']


                                            class TxFragments(object):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-fragments'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments']['meta_info']


                                            class TxJabber(object):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-jabber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber']['meta_info']


                                            class TxBadFcs(object):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:tx-bad-fcs'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:minute15-ether-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ether10241518_octet is not None and self.ether10241518_octet._has_data():
                                                    return True

                                                if self.ether128255_octet is not None and self.ether128255_octet._has_data():
                                                    return True

                                                if self.ether256511_octet is not None and self.ether256511_octet._has_data():
                                                    return True

                                                if self.ether5121023_octet is not None and self.ether5121023_octet._has_data():
                                                    return True

                                                if self.ether64_octets is not None and self.ether64_octets._has_data():
                                                    return True

                                                if self.ether65127_octet is not None and self.ether65127_octet._has_data():
                                                    return True

                                                if self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt._has_data():
                                                    return True

                                                if self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt._has_data():
                                                    return True

                                                if self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt._has_data():
                                                    return True

                                                if self.fcs_errors_stat is not None and self.fcs_errors_stat._has_data():
                                                    return True

                                                if self.if_in_errors is not None and self.if_in_errors._has_data():
                                                    return True

                                                if self.if_in_octets is not None and self.if_in_octets._has_data():
                                                    return True

                                                if self.in8021q_frames is not None and self.in8021q_frames._has_data():
                                                    return True

                                                if self.in_bcast_pkt is not None and self.in_bcast_pkt._has_data():
                                                    return True

                                                if self.in_drop_abort is not None and self.in_drop_abort._has_data():
                                                    return True

                                                if self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac._has_data():
                                                    return True

                                                if self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap._has_data():
                                                    return True

                                                if self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan._has_data():
                                                    return True

                                                if self.in_drop_other is not None and self.in_drop_other._has_data():
                                                    return True

                                                if self.in_drop_overrun is not None and self.in_drop_overrun._has_data():
                                                    return True

                                                if self.in_error_collisions is not None and self.in_error_collisions._has_data():
                                                    return True

                                                if self.in_error_fragments is not None and self.in_error_fragments._has_data():
                                                    return True

                                                if self.in_error_giant is not None and self.in_error_giant._has_data():
                                                    return True

                                                if self.in_error_jabbers is not None and self.in_error_jabbers._has_data():
                                                    return True

                                                if self.in_error_other is not None and self.in_error_other._has_data():
                                                    return True

                                                if self.in_error_runt is not None and self.in_error_runt._has_data():
                                                    return True

                                                if self.in_error_symbol is not None and self.in_error_symbol._has_data():
                                                    return True

                                                if self.in_good_bytes is not None and self.in_good_bytes._has_data():
                                                    return True

                                                if self.in_good_pkts is not None and self.in_good_pkts._has_data():
                                                    return True

                                                if self.in_mcast_pkt is not None and self.in_mcast_pkt._has_data():
                                                    return True

                                                if self.in_mib_giant is not None and self.in_mib_giant._has_data():
                                                    return True

                                                if self.in_mib_jabber is not None and self.in_mib_jabber._has_data():
                                                    return True

                                                if self.in_mibcrc is not None and self.in_mibcrc._has_data():
                                                    return True

                                                if self.in_pause_frame is not None and self.in_pause_frame._has_data():
                                                    return True

                                                if self.in_pkt64_octet is not None and self.in_pkt64_octet._has_data():
                                                    return True

                                                if self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets._has_data():
                                                    return True

                                                if self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets._has_data():
                                                    return True

                                                if self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets._has_data():
                                                    return True

                                                if self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets._has_data():
                                                    return True

                                                if self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets._has_data():
                                                    return True

                                                if self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets._has_data():
                                                    return True

                                                if self.in_ucast_pkt is not None and self.in_ucast_pkt._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.jabber_stat is not None and self.jabber_stat._has_data():
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.long_frames_stat is not None and self.long_frames_stat._has_data():
                                                    return True

                                                if self.octet_stat is not None and self.octet_stat._has_data():
                                                    return True

                                                if self.out8021q_frames is not None and self.out8021q_frames._has_data():
                                                    return True

                                                if self.out_bcast_pkt is not None and self.out_bcast_pkt._has_data():
                                                    return True

                                                if self.out_drop_abort is not None and self.out_drop_abort._has_data():
                                                    return True

                                                if self.out_drop_other is not None and self.out_drop_other._has_data():
                                                    return True

                                                if self.out_drop_underrun is not None and self.out_drop_underrun._has_data():
                                                    return True

                                                if self.out_error_other is not None and self.out_error_other._has_data():
                                                    return True

                                                if self.out_good_bytes is not None and self.out_good_bytes._has_data():
                                                    return True

                                                if self.out_good_pkts is not None and self.out_good_pkts._has_data():
                                                    return True

                                                if self.out_mcast_pkt is not None and self.out_mcast_pkt._has_data():
                                                    return True

                                                if self.out_octets is not None and self.out_octets._has_data():
                                                    return True

                                                if self.out_pause_frames is not None and self.out_pause_frames._has_data():
                                                    return True

                                                if self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets._has_data():
                                                    return True

                                                if self.out_pkts128255_octets is not None and self.out_pkts128255_octets._has_data():
                                                    return True

                                                if self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets._has_data():
                                                    return True

                                                if self.out_pkts256511_octets is not None and self.out_pkts256511_octets._has_data():
                                                    return True

                                                if self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets._has_data():
                                                    return True

                                                if self.out_pkts65127_octets is not None and self.out_pkts65127_octets._has_data():
                                                    return True

                                                if self.out_ucast_pkt is not None and self.out_ucast_pkt._has_data():
                                                    return True

                                                if self.outpkt64octet is not None and self.outpkt64octet._has_data():
                                                    return True

                                                if self.oversize_pkt_stat is not None and self.oversize_pkt_stat._has_data():
                                                    return True

                                                if self.rx_pkt is not None and self.rx_pkt._has_data():
                                                    return True

                                                if self.rx_util is not None and self.rx_util._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.stat_pkt is not None and self.stat_pkt._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.tx_bad_fcs is not None and self.tx_bad_fcs._has_data():
                                                    return True

                                                if self.tx_fragments is not None and self.tx_fragments._has_data():
                                                    return True

                                                if self.tx_jabber is not None and self.tx_jabber._has_data():
                                                    return True

                                                if self.tx_oversized_pkt is not None and self.tx_oversized_pkt._has_data():
                                                    return True

                                                if self.tx_pkt is not None and self.tx_pkt._has_data():
                                                    return True

                                                if self.tx_undersized_pkt is not None and self.tx_undersized_pkt._has_data():
                                                    return True

                                                if self.tx_util is not None and self.tx_util._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:minute15-ether-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.minute15_ether_time_line_instance is not None:
                                                for child_ref in self.minute15_ether_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.slot_number is None:
                                            raise YPYModelError('Key property slot_number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:minute15-ether-history[Cisco-IOS-XR-pmengine-oper:slot-number = ' + str(self.slot_number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.slot_number is not None:
                                            return True

                                        if self.minute15_ether_time_line_instances is not None and self.minute15_ether_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:minute15-ether-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.minute15_ether_history is not None:
                                        for child_ref in self.minute15_ether_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ethernet-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.minute15_ether_histories is not None and self.minute15_ether_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:ethernet-history/Cisco-IOS-XR-pmengine-oper:ethernet-port-histories/Cisco-IOS-XR-pmengine-oper:ethernet-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.ethernet_hour24_history is not None and self.ethernet_hour24_history._has_data():
                                return True

                            if self.ethernet_minute15_history is not None and self.ethernet_minute15_history._has_data():
                                return True

                            if self.ethernet_second30_history is not None and self.ethernet_second30_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:ethernet-history/Cisco-IOS-XR-pmengine-oper:ethernet-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ethernet_port_history is not None:
                            for child_ref in self.ethernet_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:ethernet-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ethernet_port_histories is not None and self.ethernet_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.EthernetHistory']['meta_info']


            class DwdmHistory(object):
                """
                DWDM controller History performance data
                
                .. attribute:: dwdm_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`DwdmPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.dwdm_port_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories()
                    self.dwdm_port_histories.parent = self


                class DwdmPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: dwdm_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`DwdmPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.dwdm_port_history = YList()
                        self.dwdm_port_history.parent = self
                        self.dwdm_port_history.name = 'dwdm_port_history'


                    class DwdmPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: dwdm_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History>`
                        
                        .. attribute:: dwdm_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.dwdm_hour24_history = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History()
                            self.dwdm_hour24_history.parent = self
                            self.dwdm_minute15_history = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History()
                            self.dwdm_minute15_history.parent = self


                        class DwdmMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15_optics_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`DwdmMinute15OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories>`
                            
                            .. attribute:: dwdm_minute15fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`DwdmMinute15FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories>`
                            
                            .. attribute:: dwdm_minute15otn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`DwdmMinute15OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dwdm_minute15_optics_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories()
                                self.dwdm_minute15_optics_histories.parent = self
                                self.dwdm_minute15fec_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories()
                                self.dwdm_minute15fec_histories.parent = self
                                self.dwdm_minute15otn_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories()
                                self.dwdm_minute15otn_histories.parent = self


                            class DwdmMinute15OtnHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_minute15otn_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of    :py:class:`DwdmMinute15OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dwdm_minute15otn_history = YList()
                                    self.dwdm_minute15otn_history.parent = self
                                    self.dwdm_minute15otn_history.name = 'dwdm_minute15otn_history'


                                class DwdmMinute15OtnHistory(object):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_minute15otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmMinute15OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.dwdm_minute15otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances()
                                        self.dwdm_minute15otn_time_line_instances.parent = self


                                    class DwdmMinute15OtnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_minute15otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`DwdmMinute15OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dwdm_minute15otn_time_line_instance = YList()
                                            self.dwdm_minute15otn_time_line_instance.parent = self
                                            self.dwdm_minute15otn_time_line_instance.name = 'dwdm_minute15otn_time_line_instance'


                                        class DwdmMinute15OtnTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.sec30_support = None
                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self.timestamp = None
                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.Lbc']['meta_info']


                                            class EsNe(object):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsNe']['meta_info']


                                            class EsrNe(object):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrNe']['meta_info']


                                            class SesNe(object):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesNe']['meta_info']


                                            class SesrNe(object):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrNe']['meta_info']


                                            class UasNe(object):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasNe']['meta_info']


                                            class BbeNe(object):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeNe']['meta_info']


                                            class BberNe(object):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberNe']['meta_info']


                                            class FcNe(object):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcNe']['meta_info']


                                            class EsFe(object):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsFe']['meta_info']


                                            class EsrFe(object):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrFe']['meta_info']


                                            class SesFe(object):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesFe']['meta_info']


                                            class SesrFe(object):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrFe']['meta_info']


                                            class UasFe(object):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasFe']['meta_info']


                                            class BbeFe(object):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeFe']['meta_info']


                                            class BberFe(object):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberFe']['meta_info']


                                            class FcFe(object):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcFe']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15otn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.bbe_fe is not None and self.bbe_fe._has_data():
                                                    return True

                                                if self.bbe_ne is not None and self.bbe_ne._has_data():
                                                    return True

                                                if self.bber_fe is not None and self.bber_fe._has_data():
                                                    return True

                                                if self.bber_ne is not None and self.bber_ne._has_data():
                                                    return True

                                                if self.es_fe is not None and self.es_fe._has_data():
                                                    return True

                                                if self.es_ne is not None and self.es_ne._has_data():
                                                    return True

                                                if self.esr_fe is not None and self.esr_fe._has_data():
                                                    return True

                                                if self.esr_ne is not None and self.esr_ne._has_data():
                                                    return True

                                                if self.fc_fe is not None and self.fc_fe._has_data():
                                                    return True

                                                if self.fc_ne is not None and self.fc_ne._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.ses_fe is not None and self.ses_fe._has_data():
                                                    return True

                                                if self.ses_ne is not None and self.ses_ne._has_data():
                                                    return True

                                                if self.sesr_fe is not None and self.sesr_fe._has_data():
                                                    return True

                                                if self.sesr_ne is not None and self.sesr_ne._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uas_fe is not None and self.uas_fe._has_data():
                                                    return True

                                                if self.uas_ne is not None and self.uas_ne._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15otn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dwdm_minute15otn_time_line_instance is not None:
                                                for child_ref in self.dwdm_minute15otn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15otn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.dwdm_minute15otn_time_line_instances is not None and self.dwdm_minute15otn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15otn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dwdm_minute15otn_history is not None:
                                        for child_ref in self.dwdm_minute15otn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories']['meta_info']


                            class DwdmMinute15FecHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_minute15fec_history
                                
                                	port 15\-minute fec performance data
                                	**type**\: list of    :py:class:`DwdmMinute15FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dwdm_minute15fec_history = YList()
                                    self.dwdm_minute15fec_history.parent = self
                                    self.dwdm_minute15fec_history.name = 'dwdm_minute15fec_history'


                                class DwdmMinute15FecHistory(object):
                                    """
                                    port 15\-minute fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_minute15fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmMinute15FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.dwdm_minute15fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances()
                                        self.dwdm_minute15fec_time_line_instances.parent = self


                                    class DwdmMinute15FecTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_minute15fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data by index
                                        	**type**\: list of    :py:class:`DwdmMinute15FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dwdm_minute15fec_time_line_instance = YList()
                                            self.dwdm_minute15fec_time_line_instance.parent = self
                                            self.dwdm_minute15fec_time_line_instance.name = 'dwdm_minute15fec_time_line_instance'


                                        class DwdmMinute15FecTimeLineInstance(object):
                                            """
                                            port 15\-minute fec performance data by
                                            index
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self.q = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self.valid = None


                                            class EcBits(object):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.EcBits']['meta_info']


                                            class UcWords(object):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.UcWords']['meta_info']


                                            class PreFecBer(object):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PreFecBer']['meta_info']


                                            class PostFecBer(object):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PostFecBer']['meta_info']


                                            class Q(object):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Q']['meta_info']


                                            class Qmargin(object):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Qmargin']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15fec-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ec_bits is not None and self.ec_bits._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                                    return True

                                                if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                                    return True

                                                if self.q is not None and self.q._has_data():
                                                    return True

                                                if self.qmargin is not None and self.qmargin._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uc_words is not None and self.uc_words._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15fec-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dwdm_minute15fec_time_line_instance is not None:
                                                for child_ref in self.dwdm_minute15fec_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15fec-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.dwdm_minute15fec_time_line_instances is not None and self.dwdm_minute15fec_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15fec-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dwdm_minute15fec_history is not None:
                                        for child_ref in self.dwdm_minute15fec_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories']['meta_info']


                            class DwdmMinute15OpticsHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_minute15_optics_history
                                
                                	port 15\-minute optics performance data
                                	**type**\: list of    :py:class:`DwdmMinute15OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dwdm_minute15_optics_history = YList()
                                    self.dwdm_minute15_optics_history.parent = self
                                    self.dwdm_minute15_optics_history.name = 'dwdm_minute15_optics_history'


                                class DwdmMinute15OpticsHistory(object):
                                    """
                                    port 15\-minute optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_minute15_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmMinute15OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.dwdm_minute15_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances()
                                        self.dwdm_minute15_optics_time_line_instances.parent = self


                                    class DwdmMinute15OpticsTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_minute15_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`DwdmMinute15OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dwdm_minute15_optics_time_line_instance = YList()
                                            self.dwdm_minute15_optics_time_line_instance.parent = self
                                            self.dwdm_minute15_optics_time_line_instance.name = 'dwdm_minute15_optics_time_line_instance'


                                        class DwdmMinute15OpticsTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.cd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self.opr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self.opt = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self.pn = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc']['meta_info']


                                            class LbcPc(object):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc']['meta_info']


                                            class Opt(object):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt']['meta_info']


                                            class Opr(object):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr']['meta_info']


                                            class Cd(object):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd']['meta_info']


                                            class Dgd(object):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd']['meta_info']


                                            class Pmd(object):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd']['meta_info']


                                            class Osnr(object):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr']['meta_info']


                                            class CenterWavelength(object):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength']['meta_info']


                                            class Pdl(object):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl']['meta_info']


                                            class Pcr(object):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr']['meta_info']


                                            class Pn(object):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn']['meta_info']


                                            class RxSigPow(object):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow']['meta_info']


                                            class LowSigFreqOff(object):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15-optics-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.cd is not None and self.cd._has_data():
                                                    return True

                                                if self.center_wavelength is not None and self.center_wavelength._has_data():
                                                    return True

                                                if self.dgd is not None and self.dgd._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.lbc_pc is not None and self.lbc_pc._has_data():
                                                    return True

                                                if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                                    return True

                                                if self.opr is not None and self.opr._has_data():
                                                    return True

                                                if self.opt is not None and self.opt._has_data():
                                                    return True

                                                if self.osnr is not None and self.osnr._has_data():
                                                    return True

                                                if self.pcr is not None and self.pcr._has_data():
                                                    return True

                                                if self.pdl is not None and self.pdl._has_data():
                                                    return True

                                                if self.pmd is not None and self.pmd._has_data():
                                                    return True

                                                if self.pn is not None and self.pn._has_data():
                                                    return True

                                                if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15-optics-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dwdm_minute15_optics_time_line_instance is not None:
                                                for child_ref in self.dwdm_minute15_optics_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15-optics-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.dwdm_minute15_optics_time_line_instances is not None and self.dwdm_minute15_optics_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15-optics-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dwdm_minute15_optics_history is not None:
                                        for child_ref in self.dwdm_minute15_optics_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dwdm_minute15_optics_histories is not None and self.dwdm_minute15_optics_histories._has_data():
                                    return True

                                if self.dwdm_minute15fec_histories is not None and self.dwdm_minute15fec_histories._has_data():
                                    return True

                                if self.dwdm_minute15otn_histories is not None and self.dwdm_minute15otn_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History']['meta_info']


                        class DwdmHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_hour24_optics_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`DwdmHour24OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories>`
                            
                            .. attribute:: dwdm_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`DwdmHour24FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories>`
                            
                            .. attribute:: dwdm_hour24otn_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`DwdmHour24OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dwdm_hour24_optics_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories()
                                self.dwdm_hour24_optics_histories.parent = self
                                self.dwdm_hour24fec_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories()
                                self.dwdm_hour24fec_histories.parent = self
                                self.dwdm_hour24otn_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories()
                                self.dwdm_hour24otn_histories.parent = self


                            class DwdmHour24OtnHistories(object):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: dwdm_hour24otn_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of    :py:class:`DwdmHour24OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dwdm_hour24otn_history = YList()
                                    self.dwdm_hour24otn_history.parent = self
                                    self.dwdm_hour24otn_history.name = 'dwdm_hour24otn_history'


                                class DwdmHour24OtnHistory(object):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_hour24otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmHour24OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.dwdm_hour24otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances()
                                        self.dwdm_hour24otn_time_line_instances.parent = self


                                    class DwdmHour24OtnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_hour24otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`DwdmHour24OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dwdm_hour24otn_time_line_instance = YList()
                                            self.dwdm_hour24otn_time_line_instance.parent = self
                                            self.dwdm_hour24otn_time_line_instance.name = 'dwdm_hour24otn_time_line_instance'


                                        class DwdmHour24OtnTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.sec30_support = None
                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self.timestamp = None
                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.Lbc']['meta_info']


                                            class EsNe(object):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsNe']['meta_info']


                                            class EsrNe(object):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrNe']['meta_info']


                                            class SesNe(object):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesNe']['meta_info']


                                            class SesrNe(object):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrNe']['meta_info']


                                            class UasNe(object):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasNe']['meta_info']


                                            class BbeNe(object):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeNe']['meta_info']


                                            class BberNe(object):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberNe']['meta_info']


                                            class FcNe(object):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcNe']['meta_info']


                                            class EsFe(object):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsFe']['meta_info']


                                            class EsrFe(object):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrFe']['meta_info']


                                            class SesFe(object):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesFe']['meta_info']


                                            class SesrFe(object):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrFe']['meta_info']


                                            class UasFe(object):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasFe']['meta_info']


                                            class BbeFe(object):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeFe']['meta_info']


                                            class BberFe(object):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberFe']['meta_info']


                                            class FcFe(object):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcFe']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24otn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.bbe_fe is not None and self.bbe_fe._has_data():
                                                    return True

                                                if self.bbe_ne is not None and self.bbe_ne._has_data():
                                                    return True

                                                if self.bber_fe is not None and self.bber_fe._has_data():
                                                    return True

                                                if self.bber_ne is not None and self.bber_ne._has_data():
                                                    return True

                                                if self.es_fe is not None and self.es_fe._has_data():
                                                    return True

                                                if self.es_ne is not None and self.es_ne._has_data():
                                                    return True

                                                if self.esr_fe is not None and self.esr_fe._has_data():
                                                    return True

                                                if self.esr_ne is not None and self.esr_ne._has_data():
                                                    return True

                                                if self.fc_fe is not None and self.fc_fe._has_data():
                                                    return True

                                                if self.fc_ne is not None and self.fc_ne._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.ses_fe is not None and self.ses_fe._has_data():
                                                    return True

                                                if self.ses_ne is not None and self.ses_ne._has_data():
                                                    return True

                                                if self.sesr_fe is not None and self.sesr_fe._has_data():
                                                    return True

                                                if self.sesr_ne is not None and self.sesr_ne._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uas_fe is not None and self.uas_fe._has_data():
                                                    return True

                                                if self.uas_ne is not None and self.uas_ne._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24otn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dwdm_hour24otn_time_line_instance is not None:
                                                for child_ref in self.dwdm_hour24otn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24otn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.dwdm_hour24otn_time_line_instances is not None and self.dwdm_hour24otn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24otn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dwdm_hour24otn_history is not None:
                                        for child_ref in self.dwdm_hour24otn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories']['meta_info']


                            class DwdmHour24FecHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_hour24fec_history
                                
                                	port 24 hour fec performance data
                                	**type**\: list of    :py:class:`DwdmHour24FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dwdm_hour24fec_history = YList()
                                    self.dwdm_hour24fec_history.parent = self
                                    self.dwdm_hour24fec_history.name = 'dwdm_hour24fec_history'


                                class DwdmHour24FecHistory(object):
                                    """
                                    port 24 hour fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmHour24FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.dwdm_hour24fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances()
                                        self.dwdm_hour24fec_time_line_instances.parent = self


                                    class DwdmHour24FecTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_hour24fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data by index
                                        	**type**\: list of    :py:class:`DwdmHour24FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dwdm_hour24fec_time_line_instance = YList()
                                            self.dwdm_hour24fec_time_line_instance.parent = self
                                            self.dwdm_hour24fec_time_line_instance.name = 'dwdm_hour24fec_time_line_instance'


                                        class DwdmHour24FecTimeLineInstance(object):
                                            """
                                            port 15\-minute fec performance data by
                                            index
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self.q = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self.valid = None


                                            class EcBits(object):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.EcBits']['meta_info']


                                            class UcWords(object):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.UcWords']['meta_info']


                                            class PreFecBer(object):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PreFecBer']['meta_info']


                                            class PostFecBer(object):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PostFecBer']['meta_info']


                                            class Q(object):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Q']['meta_info']


                                            class Qmargin(object):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Qmargin']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24fec-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ec_bits is not None and self.ec_bits._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                                    return True

                                                if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                                    return True

                                                if self.q is not None and self.q._has_data():
                                                    return True

                                                if self.qmargin is not None and self.qmargin._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uc_words is not None and self.uc_words._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24fec-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dwdm_hour24fec_time_line_instance is not None:
                                                for child_ref in self.dwdm_hour24fec_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24fec-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.dwdm_hour24fec_time_line_instances is not None and self.dwdm_hour24fec_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24fec-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dwdm_hour24fec_history is not None:
                                        for child_ref in self.dwdm_hour24fec_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories']['meta_info']


                            class DwdmHour24OpticsHistories(object):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: dwdm_hour24_optics_history
                                
                                	port 24 hour optics performance data
                                	**type**\: list of    :py:class:`DwdmHour24OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dwdm_hour24_optics_history = YList()
                                    self.dwdm_hour24_optics_history.parent = self
                                    self.dwdm_hour24_optics_history.name = 'dwdm_hour24_optics_history'


                                class DwdmHour24OpticsHistory(object):
                                    """
                                    port 24 hour optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_hour24_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmHour24OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.dwdm_hour24_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances()
                                        self.dwdm_hour24_optics_time_line_instances.parent = self


                                    class DwdmHour24OpticsTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_hour24_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`DwdmHour24OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dwdm_hour24_optics_time_line_instance = YList()
                                            self.dwdm_hour24_optics_time_line_instance.parent = self
                                            self.dwdm_hour24_optics_time_line_instance.name = 'dwdm_hour24_optics_time_line_instance'


                                        class DwdmHour24OpticsTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.cd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self.opr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self.opt = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self.pn = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc']['meta_info']


                                            class LbcPc(object):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc']['meta_info']


                                            class Opt(object):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt']['meta_info']


                                            class Opr(object):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr']['meta_info']


                                            class Cd(object):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd']['meta_info']


                                            class Dgd(object):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd']['meta_info']


                                            class Pmd(object):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd']['meta_info']


                                            class Osnr(object):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr']['meta_info']


                                            class CenterWavelength(object):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength']['meta_info']


                                            class Pdl(object):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl']['meta_info']


                                            class Pcr(object):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr']['meta_info']


                                            class Pn(object):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn']['meta_info']


                                            class RxSigPow(object):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow']['meta_info']


                                            class LowSigFreqOff(object):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24-optics-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.cd is not None and self.cd._has_data():
                                                    return True

                                                if self.center_wavelength is not None and self.center_wavelength._has_data():
                                                    return True

                                                if self.dgd is not None and self.dgd._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.lbc_pc is not None and self.lbc_pc._has_data():
                                                    return True

                                                if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                                    return True

                                                if self.opr is not None and self.opr._has_data():
                                                    return True

                                                if self.opt is not None and self.opt._has_data():
                                                    return True

                                                if self.osnr is not None and self.osnr._has_data():
                                                    return True

                                                if self.pcr is not None and self.pcr._has_data():
                                                    return True

                                                if self.pdl is not None and self.pdl._has_data():
                                                    return True

                                                if self.pmd is not None and self.pmd._has_data():
                                                    return True

                                                if self.pn is not None and self.pn._has_data():
                                                    return True

                                                if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24-optics-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dwdm_hour24_optics_time_line_instance is not None:
                                                for child_ref in self.dwdm_hour24_optics_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24-optics-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.dwdm_hour24_optics_time_line_instances is not None and self.dwdm_hour24_optics_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24-optics-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dwdm_hour24_optics_history is not None:
                                        for child_ref in self.dwdm_hour24_optics_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dwdm-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dwdm_hour24_optics_histories is not None and self.dwdm_hour24_optics_histories._has_data():
                                    return True

                                if self.dwdm_hour24fec_histories is not None and self.dwdm_hour24fec_histories._has_data():
                                    return True

                                if self.dwdm_hour24otn_histories is not None and self.dwdm_hour24otn_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:dwdm-history/Cisco-IOS-XR-pmengine-oper:dwdm-port-histories/Cisco-IOS-XR-pmengine-oper:dwdm-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.dwdm_hour24_history is not None and self.dwdm_hour24_history._has_data():
                                return True

                            if self.dwdm_minute15_history is not None and self.dwdm_minute15_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:dwdm-history/Cisco-IOS-XR-pmengine-oper:dwdm-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.dwdm_port_history is not None:
                            for child_ref in self.dwdm_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:dwdm-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.dwdm_port_histories is not None and self.dwdm_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.DwdmHistory']['meta_info']


            class StmHistory(object):
                """
                STM controller History performance data
                
                .. attribute:: stm_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`StmPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.stm_port_histories = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories()
                    self.stm_port_histories.parent = self


                class StmPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: stm_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`StmPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.stm_port_history = YList()
                        self.stm_port_history.parent = self
                        self.stm_port_history.name = 'stm_port_history'


                    class StmPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: stm_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`StmHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History>`
                        
                        .. attribute:: stm_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`StmMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.stm_hour24_history = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History()
                            self.stm_hour24_history.parent = self
                            self.stm_minute15_history = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History()
                            self.stm_minute15_history.parent = self


                        class StmHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: stm_hour24stm_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`StmHour24StmHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.stm_hour24stm_histories = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories()
                                self.stm_hour24stm_histories.parent = self


                            class StmHour24StmHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: stm_hour24stm_history
                                
                                	port 24 hour stm performance data
                                	**type**\: list of    :py:class:`StmHour24StmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.stm_hour24stm_history = YList()
                                    self.stm_hour24stm_history.parent = self
                                    self.stm_hour24stm_history.name = 'stm_hour24stm_history'


                                class StmHour24StmHistory(object):
                                    """
                                    port 24 hour stm performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: stm_hour24stm_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`StmHour24StmTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.stm_hour24stm_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances()
                                        self.stm_hour24stm_time_line_instances.parent = self


                                    class StmHour24StmTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: stm_hour24stm_time_line_instance
                                        
                                        	port 15\-minute stm performance data
                                        	**type**\: list of    :py:class:`StmHour24StmTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.stm_hour24stm_time_line_instance = YList()
                                            self.stm_hour24stm_time_line_instance.parent = self
                                            self.stm_hour24stm_time_line_instance.name = 'stm_hour24stm_time_line_instance'


                                        class StmHour24StmTimeLineInstance(object):
                                            """
                                            port 15\-minute stm performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line()
                                                self.line.parent = self
                                                self.section = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section()
                                                self.section.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Section(object):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbEs>`
                                                
                                                .. attribute:: section_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbeRs>`
                                                
                                                .. attribute:: section_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEBs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEsRs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSesRs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: section_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.section_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbEs()
                                                    self.section_bb_es.parent = self
                                                    self.section_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbeRs()
                                                    self.section_bbe_rs.parent = self
                                                    self.section_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEBs()
                                                    self.section_e_bs.parent = self
                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self.section_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEsRs()
                                                    self.section_es_rs.parent = self
                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self.section_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSesRs()
                                                    self.section_ses_rs.parent = self
                                                    self.section_status = None
                                                    self.section_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionUaSs()
                                                    self.section_ua_ss.parent = self


                                                class SectionESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionESs']['meta_info']


                                                class SectionEsRs(object):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-es-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEsRs']['meta_info']


                                                class SectionBbEs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-bb-es'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbEs']['meta_info']


                                                class SectionBbeRs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-bbe-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbeRs']['meta_info']


                                                class SectionSeSs(object):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSeSs']['meta_info']


                                                class SectionSesRs(object):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-ses-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSesRs']['meta_info']


                                                class SectionUaSs(object):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionUaSs']['meta_info']


                                                class SectionEBs(object):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-bs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEBs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.section_bb_es is not None and self.section_bb_es._has_data():
                                                        return True

                                                    if self.section_bbe_rs is not None and self.section_bbe_rs._has_data():
                                                        return True

                                                    if self.section_e_bs is not None and self.section_e_bs._has_data():
                                                        return True

                                                    if self.section_e_ss is not None and self.section_e_ss._has_data():
                                                        return True

                                                    if self.section_es_rs is not None and self.section_es_rs._has_data():
                                                        return True

                                                    if self.section_se_ss is not None and self.section_se_ss._has_data():
                                                        return True

                                                    if self.section_ses_rs is not None and self.section_ses_rs._has_data():
                                                        return True

                                                    if self.section_status is not None:
                                                        return True

                                                    if self.section_ua_ss is not None and self.section_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section']['meta_info']


                                            class Line(object):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbEs>`
                                                
                                                .. attribute:: line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbeRs>`
                                                
                                                .. attribute:: line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEBs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEsRs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSesRs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.line_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbEs()
                                                    self.line_bb_es.parent = self
                                                    self.line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbeRs()
                                                    self.line_bbe_rs.parent = self
                                                    self.line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEBs()
                                                    self.line_e_bs.parent = self
                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self.line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEsRs()
                                                    self.line_es_rs.parent = self
                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self.line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSesRs()
                                                    self.line_ses_rs.parent = self
                                                    self.line_status = None
                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self


                                                class LineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineESs']['meta_info']


                                                class LineEsRs(object):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-es-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEsRs']['meta_info']


                                                class LineBbEs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-bb-es'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbEs']['meta_info']


                                                class LineBbeRs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-bbe-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbeRs']['meta_info']


                                                class LineSeSs(object):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSeSs']['meta_info']


                                                class LineSesRs(object):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ses-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSesRs']['meta_info']


                                                class LineUaSs(object):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineUaSs']['meta_info']


                                                class LineEBs(object):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-bs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEBs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.line_bb_es is not None and self.line_bb_es._has_data():
                                                        return True

                                                    if self.line_bbe_rs is not None and self.line_bbe_rs._has_data():
                                                        return True

                                                    if self.line_e_bs is not None and self.line_e_bs._has_data():
                                                        return True

                                                    if self.line_e_ss is not None and self.line_e_ss._has_data():
                                                        return True

                                                    if self.line_es_rs is not None and self.line_es_rs._has_data():
                                                        return True

                                                    if self.line_se_ss is not None and self.line_se_ss._has_data():
                                                        return True

                                                    if self.line_ses_rs is not None and self.line_ses_rs._has_data():
                                                        return True

                                                    if self.line_status is not None:
                                                        return True

                                                    if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line']['meta_info']


                                            class FeLine(object):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineBbeRs>`
                                                
                                                .. attribute:: far_end_line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEBs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_ebb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEbbEs>`
                                                
                                                .. attribute:: far_end_line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEsRs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSesRs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineBbeRs()
                                                    self.far_end_line_bbe_rs.parent = self
                                                    self.far_end_line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEBs()
                                                    self.far_end_line_e_bs.parent = self
                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self.far_end_line_ebb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEbbEs()
                                                    self.far_end_line_ebb_es.parent = self
                                                    self.far_end_line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEsRs()
                                                    self.far_end_line_es_rs.parent = self
                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self.far_end_line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSesRs()
                                                    self.far_end_line_ses_rs.parent = self
                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self


                                                class FarEndLineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineESs']['meta_info']


                                                class FarEndLineEsRs(object):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-es-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEsRs']['meta_info']


                                                class FarEndLineEbbEs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ebb-es'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEbbEs']['meta_info']


                                                class FarEndLineBbeRs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-bbe-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineBbeRs']['meta_info']


                                                class FarEndLineSeSs(object):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSeSs']['meta_info']


                                                class FarEndLineSesRs(object):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ses-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSesRs']['meta_info']


                                                class FarEndLineUaSs(object):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineUaSs']['meta_info']


                                                class FarEndLineEBs(object):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-bs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEBs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs._has_data():
                                                        return True

                                                    if self.far_end_line_e_bs is not None and self.far_end_line_e_bs._has_data():
                                                        return True

                                                    if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                                        return True

                                                    if self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es._has_data():
                                                        return True

                                                    if self.far_end_line_es_rs is not None and self.far_end_line_es_rs._has_data():
                                                        return True

                                                    if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                                        return True

                                                    if self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs._has_data():
                                                        return True

                                                    if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-hour24stm-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_line is not None and self.fe_line._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.line is not None and self.line._has_data():
                                                    return True

                                                if self.section is not None and self.section._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-hour24stm-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.stm_hour24stm_time_line_instance is not None:
                                                for child_ref in self.stm_hour24stm_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-hour24stm-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.stm_hour24stm_time_line_instances is not None and self.stm_hour24stm_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-hour24stm-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.stm_hour24stm_history is not None:
                                        for child_ref in self.stm_hour24stm_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.stm_hour24stm_histories is not None and self.stm_hour24stm_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History']['meta_info']


                        class StmMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: stm_minute15stm_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`StmMinute15StmHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.stm_minute15stm_histories = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories()
                                self.stm_minute15stm_histories.parent = self


                            class StmMinute15StmHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: stm_minute15stm_history
                                
                                	port 15\-minute stm performance data
                                	**type**\: list of    :py:class:`StmMinute15StmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.stm_minute15stm_history = YList()
                                    self.stm_minute15stm_history.parent = self
                                    self.stm_minute15stm_history.name = 'stm_minute15stm_history'


                                class StmMinute15StmHistory(object):
                                    """
                                    port 15\-minute stm performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: stm_minute15stm_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`StmMinute15StmTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.stm_minute15stm_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances()
                                        self.stm_minute15stm_time_line_instances.parent = self


                                    class StmMinute15StmTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: stm_minute15stm_time_line_instance
                                        
                                        	port 15\-minute stm performance data
                                        	**type**\: list of    :py:class:`StmMinute15StmTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.stm_minute15stm_time_line_instance = YList()
                                            self.stm_minute15stm_time_line_instance.parent = self
                                            self.stm_minute15stm_time_line_instance.name = 'stm_minute15stm_time_line_instance'


                                        class StmMinute15StmTimeLineInstance(object):
                                            """
                                            port 15\-minute stm performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line()
                                                self.line.parent = self
                                                self.section = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section()
                                                self.section.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Section(object):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbEs>`
                                                
                                                .. attribute:: section_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbeRs>`
                                                
                                                .. attribute:: section_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEBs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEsRs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSesRs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: section_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.section_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbEs()
                                                    self.section_bb_es.parent = self
                                                    self.section_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbeRs()
                                                    self.section_bbe_rs.parent = self
                                                    self.section_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEBs()
                                                    self.section_e_bs.parent = self
                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self.section_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEsRs()
                                                    self.section_es_rs.parent = self
                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self.section_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSesRs()
                                                    self.section_ses_rs.parent = self
                                                    self.section_status = None
                                                    self.section_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionUaSs()
                                                    self.section_ua_ss.parent = self


                                                class SectionESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionESs']['meta_info']


                                                class SectionEsRs(object):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-es-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEsRs']['meta_info']


                                                class SectionBbEs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-bb-es'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbEs']['meta_info']


                                                class SectionBbeRs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-bbe-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbeRs']['meta_info']


                                                class SectionSeSs(object):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSeSs']['meta_info']


                                                class SectionSesRs(object):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-ses-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSesRs']['meta_info']


                                                class SectionUaSs(object):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionUaSs']['meta_info']


                                                class SectionEBs(object):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-bs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEBs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.section_bb_es is not None and self.section_bb_es._has_data():
                                                        return True

                                                    if self.section_bbe_rs is not None and self.section_bbe_rs._has_data():
                                                        return True

                                                    if self.section_e_bs is not None and self.section_e_bs._has_data():
                                                        return True

                                                    if self.section_e_ss is not None and self.section_e_ss._has_data():
                                                        return True

                                                    if self.section_es_rs is not None and self.section_es_rs._has_data():
                                                        return True

                                                    if self.section_se_ss is not None and self.section_se_ss._has_data():
                                                        return True

                                                    if self.section_ses_rs is not None and self.section_ses_rs._has_data():
                                                        return True

                                                    if self.section_status is not None:
                                                        return True

                                                    if self.section_ua_ss is not None and self.section_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section']['meta_info']


                                            class Line(object):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbEs>`
                                                
                                                .. attribute:: line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbeRs>`
                                                
                                                .. attribute:: line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEBs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEsRs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSesRs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.line_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbEs()
                                                    self.line_bb_es.parent = self
                                                    self.line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbeRs()
                                                    self.line_bbe_rs.parent = self
                                                    self.line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEBs()
                                                    self.line_e_bs.parent = self
                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self.line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEsRs()
                                                    self.line_es_rs.parent = self
                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self.line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSesRs()
                                                    self.line_ses_rs.parent = self
                                                    self.line_status = None
                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self


                                                class LineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineESs']['meta_info']


                                                class LineEsRs(object):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-es-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEsRs']['meta_info']


                                                class LineBbEs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-bb-es'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbEs']['meta_info']


                                                class LineBbeRs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-bbe-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbeRs']['meta_info']


                                                class LineSeSs(object):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSeSs']['meta_info']


                                                class LineSesRs(object):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ses-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSesRs']['meta_info']


                                                class LineUaSs(object):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineUaSs']['meta_info']


                                                class LineEBs(object):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-bs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEBs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.line_bb_es is not None and self.line_bb_es._has_data():
                                                        return True

                                                    if self.line_bbe_rs is not None and self.line_bbe_rs._has_data():
                                                        return True

                                                    if self.line_e_bs is not None and self.line_e_bs._has_data():
                                                        return True

                                                    if self.line_e_ss is not None and self.line_e_ss._has_data():
                                                        return True

                                                    if self.line_es_rs is not None and self.line_es_rs._has_data():
                                                        return True

                                                    if self.line_se_ss is not None and self.line_se_ss._has_data():
                                                        return True

                                                    if self.line_ses_rs is not None and self.line_ses_rs._has_data():
                                                        return True

                                                    if self.line_status is not None:
                                                        return True

                                                    if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line']['meta_info']


                                            class FeLine(object):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineBbeRs>`
                                                
                                                .. attribute:: far_end_line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEBs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_ebb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEbbEs>`
                                                
                                                .. attribute:: far_end_line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEsRs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSesRs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineBbeRs()
                                                    self.far_end_line_bbe_rs.parent = self
                                                    self.far_end_line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEBs()
                                                    self.far_end_line_e_bs.parent = self
                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self.far_end_line_ebb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEbbEs()
                                                    self.far_end_line_ebb_es.parent = self
                                                    self.far_end_line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEsRs()
                                                    self.far_end_line_es_rs.parent = self
                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self.far_end_line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSesRs()
                                                    self.far_end_line_ses_rs.parent = self
                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self


                                                class FarEndLineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineESs']['meta_info']


                                                class FarEndLineEsRs(object):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-es-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEsRs']['meta_info']


                                                class FarEndLineEbbEs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ebb-es'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEbbEs']['meta_info']


                                                class FarEndLineBbeRs(object):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-bbe-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineBbeRs']['meta_info']


                                                class FarEndLineSeSs(object):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSeSs']['meta_info']


                                                class FarEndLineSesRs(object):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ses-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSesRs']['meta_info']


                                                class FarEndLineUaSs(object):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineUaSs']['meta_info']


                                                class FarEndLineEBs(object):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-bs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEBs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs._has_data():
                                                        return True

                                                    if self.far_end_line_e_bs is not None and self.far_end_line_e_bs._has_data():
                                                        return True

                                                    if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                                        return True

                                                    if self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es._has_data():
                                                        return True

                                                    if self.far_end_line_es_rs is not None and self.far_end_line_es_rs._has_data():
                                                        return True

                                                    if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                                        return True

                                                    if self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs._has_data():
                                                        return True

                                                    if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-minute15stm-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_line is not None and self.fe_line._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.line is not None and self.line._has_data():
                                                    return True

                                                if self.section is not None and self.section._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-minute15stm-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.stm_minute15stm_time_line_instance is not None:
                                                for child_ref in self.stm_minute15stm_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-minute15stm-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.stm_minute15stm_time_line_instances is not None and self.stm_minute15stm_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-minute15stm-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.stm_minute15stm_history is not None:
                                        for child_ref in self.stm_minute15stm_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:stm-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.stm_minute15stm_histories is not None and self.stm_minute15stm_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:stm-history/Cisco-IOS-XR-pmengine-oper:stm-port-histories/Cisco-IOS-XR-pmengine-oper:stm-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.stm_hour24_history is not None and self.stm_hour24_history._has_data():
                                return True

                            if self.stm_minute15_history is not None and self.stm_minute15_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:stm-history/Cisco-IOS-XR-pmengine-oper:stm-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.stm_port_history is not None:
                            for child_ref in self.stm_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:stm-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.stm_port_histories is not None and self.stm_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.StmHistory']['meta_info']


            class OduHistory(object):
                """
                ODU controller History performance data
                
                .. attribute:: odu_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`OduPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.odu_port_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories()
                    self.odu_port_histories.parent = self


                class OduPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: odu_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`OduPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.odu_port_history = YList()
                        self.odu_port_history.parent = self
                        self.odu_port_history.name = 'odu_port_history'


                    class OduPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: odu_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History>`
                        
                        .. attribute:: odu_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.odu_hour24_history = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History()
                            self.odu_hour24_history.parent = self
                            self.odu_minute15_history = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History()
                            self.odu_minute15_history.parent = self


                        class OduHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: odu_hour24gfp_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OduHour24GfpHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories>`
                            
                            .. attribute:: odu_hour24otn_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OduHour24OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories>`
                            
                            .. attribute:: odu_hour24prbs_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OduHour24PrbsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.odu_hour24gfp_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories()
                                self.odu_hour24gfp_histories.parent = self
                                self.odu_hour24otn_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories()
                                self.odu_hour24otn_histories.parent = self
                                self.odu_hour24prbs_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories()
                                self.odu_hour24prbs_histories.parent = self


                            class OduHour24GfpHistories(object):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: odu_hour24gfp_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of    :py:class:`OduHour24GfpHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.odu_hour24gfp_history = YList()
                                    self.odu_hour24gfp_history.parent = self
                                    self.odu_hour24gfp_history.name = 'odu_hour24gfp_history'


                                class OduHour24GfpHistory(object):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_hour24gfp_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduHour24GfpTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.odu_hour24gfp_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances()
                                        self.odu_hour24gfp_time_line_instances.parent = self


                                    class OduHour24GfpTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_hour24gfp_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OduHour24GfpTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.odu_hour24gfp_time_line_instance = YList()
                                            self.odu_hour24gfp_time_line_instance.parent = self
                                            self.odu_hour24gfp_time_line_instance.name = 'odu_hour24gfp_time_line_instance'


                                        class OduHour24GfpTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: rx_bit_err
                                            
                                            	RX BIT ERR
                                            	**type**\:   :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxBitErr>`
                                            
                                            .. attribute:: rx_crc
                                            
                                            	RX CRC
                                            	**type**\:   :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCrc>`
                                            
                                            .. attribute:: rx_csf
                                            
                                            	RX CSF
                                            	**type**\:   :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCsf>`
                                            
                                            .. attribute:: rx_inv_typ
                                            
                                            	RX INV TYP
                                            	**type**\:   :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxInvTyp>`
                                            
                                            .. attribute:: rx_lfd
                                            
                                            	RX LFD
                                            	**type**\:   :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxLfd>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.rx_bit_err = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxBitErr()
                                                self.rx_bit_err.parent = self
                                                self.rx_crc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCrc()
                                                self.rx_crc.parent = self
                                                self.rx_csf = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCsf()
                                                self.rx_csf.parent = self
                                                self.rx_inv_typ = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxInvTyp()
                                                self.rx_inv_typ.parent = self
                                                self.rx_lfd = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxLfd()
                                                self.rx_lfd.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.valid = None


                                            class RxBitErr(object):
                                                """
                                                RX BIT ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-bit-err'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxBitErr']['meta_info']


                                            class RxInvTyp(object):
                                                """
                                                RX INV TYP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-inv-typ'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxInvTyp']['meta_info']


                                            class RxCrc(object):
                                                """
                                                RX CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-crc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCrc']['meta_info']


                                            class RxLfd(object):
                                                """
                                                RX LFD
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-lfd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxLfd']['meta_info']


                                            class RxCsf(object):
                                                """
                                                RX CSF
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-csf'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCsf']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24gfp-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.rx_bit_err is not None and self.rx_bit_err._has_data():
                                                    return True

                                                if self.rx_crc is not None and self.rx_crc._has_data():
                                                    return True

                                                if self.rx_csf is not None and self.rx_csf._has_data():
                                                    return True

                                                if self.rx_inv_typ is not None and self.rx_inv_typ._has_data():
                                                    return True

                                                if self.rx_lfd is not None and self.rx_lfd._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24gfp-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.odu_hour24gfp_time_line_instance is not None:
                                                for child_ref in self.odu_hour24gfp_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24gfp-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.odu_hour24gfp_time_line_instances is not None and self.odu_hour24gfp_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24gfp-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.odu_hour24gfp_history is not None:
                                        for child_ref in self.odu_hour24gfp_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories']['meta_info']


                            class OduHour24PrbsHistories(object):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: odu_hour24prbs_history
                                
                                	port 24 hour prbs performance data
                                	**type**\: list of    :py:class:`OduHour24PrbsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.odu_hour24prbs_history = YList()
                                    self.odu_hour24prbs_history.parent = self
                                    self.odu_hour24prbs_history.name = 'odu_hour24prbs_history'


                                class OduHour24PrbsHistory(object):
                                    """
                                    port 24 hour prbs performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_hour24prbs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduHour24PrbsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.odu_hour24prbs_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances()
                                        self.odu_hour24prbs_time_line_instances.parent = self


                                    class OduHour24PrbsTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_hour24prbs_time_line_instance
                                        
                                        	port 15\-minute prbs performance data
                                        	**type**\: list of    :py:class:`OduHour24PrbsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.odu_hour24prbs_time_line_instance = YList()
                                            self.odu_hour24prbs_time_line_instance.parent = self
                                            self.odu_hour24prbs_time_line_instance.name = 'odu_hour24prbs_time_line_instance'


                                        class OduHour24PrbsTimeLineInstance(object):
                                            """
                                            port 15\-minute prbs performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: conf_patt
                                            
                                            	CONFIG PTRN
                                            	**type**\:   :py:class:`PmPrbsPatternEtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEtEnum>`
                                            
                                            .. attribute:: ebc
                                            
                                            	EBC
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: found_at_time
                                            
                                            	FOUND AT TS
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: found_count
                                            
                                            	FOUND COUNT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: lost_at_time
                                            
                                            	LOST AT TS
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: lost_count
                                            
                                            	LOST COUNT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcv_patt
                                            
                                            	RCVD PTRN
                                            	**type**\:   :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance.RcvPatt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.conf_patt = None
                                                self.ebc = None
                                                self.found_at_time = None
                                                self.found_count = None
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.lost_at_time = None
                                                self.lost_count = None
                                                self.rcv_patt = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance.RcvPatt()
                                                self.rcv_patt.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class RcvPatt(object):
                                                """
                                                RCVD PTRN
                                                
                                                .. attribute:: rcv_patt
                                                
                                                	RCVD PTRN
                                                	**type**\:   :py:class:`PmPrbsPatternEtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEtEnum>`
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rcv_patt = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rcv-patt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rcv_patt is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance.RcvPatt']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24prbs-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.conf_patt is not None:
                                                    return True

                                                if self.ebc is not None:
                                                    return True

                                                if self.found_at_time is not None:
                                                    return True

                                                if self.found_count is not None:
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lost_at_time is not None:
                                                    return True

                                                if self.lost_count is not None:
                                                    return True

                                                if self.rcv_patt is not None and self.rcv_patt._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24prbs-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.odu_hour24prbs_time_line_instance is not None:
                                                for child_ref in self.odu_hour24prbs_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24prbs-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.odu_hour24prbs_time_line_instances is not None and self.odu_hour24prbs_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24prbs-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.odu_hour24prbs_history is not None:
                                        for child_ref in self.odu_hour24prbs_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories']['meta_info']


                            class OduHour24OtnHistories(object):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: odu_hour24otn_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of    :py:class:`OduHour24OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.odu_hour24otn_history = YList()
                                    self.odu_hour24otn_history.parent = self
                                    self.odu_hour24otn_history.name = 'odu_hour24otn_history'


                                class OduHour24OtnHistory(object):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_hour24otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduHour24OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.odu_hour24otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances()
                                        self.odu_hour24otn_time_line_instances.parent = self


                                    class OduHour24OtnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_hour24otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OduHour24OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.odu_hour24otn_time_line_instance = YList()
                                            self.odu_hour24otn_time_line_instance.parent = self
                                            self.odu_hour24otn_time_line_instance.name = 'odu_hour24otn_time_line_instance'


                                        class OduHour24OtnTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.sec30_support = None
                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self.timestamp = None
                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.Lbc']['meta_info']


                                            class EsNe(object):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsNe']['meta_info']


                                            class EsrNe(object):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrNe']['meta_info']


                                            class SesNe(object):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesNe']['meta_info']


                                            class SesrNe(object):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrNe']['meta_info']


                                            class UasNe(object):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasNe']['meta_info']


                                            class BbeNe(object):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeNe']['meta_info']


                                            class BberNe(object):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberNe']['meta_info']


                                            class FcNe(object):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcNe']['meta_info']


                                            class EsFe(object):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsFe']['meta_info']


                                            class EsrFe(object):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrFe']['meta_info']


                                            class SesFe(object):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesFe']['meta_info']


                                            class SesrFe(object):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrFe']['meta_info']


                                            class UasFe(object):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasFe']['meta_info']


                                            class BbeFe(object):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeFe']['meta_info']


                                            class BberFe(object):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberFe']['meta_info']


                                            class FcFe(object):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcFe']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24otn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.bbe_fe is not None and self.bbe_fe._has_data():
                                                    return True

                                                if self.bbe_ne is not None and self.bbe_ne._has_data():
                                                    return True

                                                if self.bber_fe is not None and self.bber_fe._has_data():
                                                    return True

                                                if self.bber_ne is not None and self.bber_ne._has_data():
                                                    return True

                                                if self.es_fe is not None and self.es_fe._has_data():
                                                    return True

                                                if self.es_ne is not None and self.es_ne._has_data():
                                                    return True

                                                if self.esr_fe is not None and self.esr_fe._has_data():
                                                    return True

                                                if self.esr_ne is not None and self.esr_ne._has_data():
                                                    return True

                                                if self.fc_fe is not None and self.fc_fe._has_data():
                                                    return True

                                                if self.fc_ne is not None and self.fc_ne._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.ses_fe is not None and self.ses_fe._has_data():
                                                    return True

                                                if self.ses_ne is not None and self.ses_ne._has_data():
                                                    return True

                                                if self.sesr_fe is not None and self.sesr_fe._has_data():
                                                    return True

                                                if self.sesr_ne is not None and self.sesr_ne._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uas_fe is not None and self.uas_fe._has_data():
                                                    return True

                                                if self.uas_ne is not None and self.uas_ne._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24otn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.odu_hour24otn_time_line_instance is not None:
                                                for child_ref in self.odu_hour24otn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24otn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.odu_hour24otn_time_line_instances is not None and self.odu_hour24otn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24otn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.odu_hour24otn_history is not None:
                                        for child_ref in self.odu_hour24otn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.odu_hour24gfp_histories is not None and self.odu_hour24gfp_histories._has_data():
                                    return True

                                if self.odu_hour24otn_histories is not None and self.odu_hour24otn_histories._has_data():
                                    return True

                                if self.odu_hour24prbs_histories is not None and self.odu_hour24prbs_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History']['meta_info']


                        class OduMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15gfp_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OduMinute15GfpHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories>`
                            
                            .. attribute:: odu_minute15otn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OduMinute15OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories>`
                            
                            .. attribute:: odu_minute15prbs_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OduMinute15PrbsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.odu_minute15gfp_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories()
                                self.odu_minute15gfp_histories.parent = self
                                self.odu_minute15otn_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories()
                                self.odu_minute15otn_histories.parent = self
                                self.odu_minute15prbs_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories()
                                self.odu_minute15prbs_histories.parent = self


                            class OduMinute15PrbsHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: odu_minute15prbs_history
                                
                                	port 15\-minute prbs performance data
                                	**type**\: list of    :py:class:`OduMinute15PrbsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.odu_minute15prbs_history = YList()
                                    self.odu_minute15prbs_history.parent = self
                                    self.odu_minute15prbs_history.name = 'odu_minute15prbs_history'


                                class OduMinute15PrbsHistory(object):
                                    """
                                    port 15\-minute prbs performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_minute15prbs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduMinute15PrbsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.odu_minute15prbs_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances()
                                        self.odu_minute15prbs_time_line_instances.parent = self


                                    class OduMinute15PrbsTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_minute15prbs_time_line_instance
                                        
                                        	port 15\-minute prbs performance data
                                        	**type**\: list of    :py:class:`OduMinute15PrbsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.odu_minute15prbs_time_line_instance = YList()
                                            self.odu_minute15prbs_time_line_instance.parent = self
                                            self.odu_minute15prbs_time_line_instance.name = 'odu_minute15prbs_time_line_instance'


                                        class OduMinute15PrbsTimeLineInstance(object):
                                            """
                                            port 15\-minute prbs performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: conf_patt
                                            
                                            	CONFIG PTRN
                                            	**type**\:   :py:class:`PmPrbsPatternEtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEtEnum>`
                                            
                                            .. attribute:: ebc
                                            
                                            	EBC
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: found_at_time
                                            
                                            	FOUND AT TS
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: found_count
                                            
                                            	FOUND COUNT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: lost_at_time
                                            
                                            	LOST AT TS
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: lost_count
                                            
                                            	LOST COUNT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcv_patt
                                            
                                            	RCVD PTRN
                                            	**type**\:   :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance.RcvPatt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.conf_patt = None
                                                self.ebc = None
                                                self.found_at_time = None
                                                self.found_count = None
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.lost_at_time = None
                                                self.lost_count = None
                                                self.rcv_patt = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance.RcvPatt()
                                                self.rcv_patt.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class RcvPatt(object):
                                                """
                                                RCVD PTRN
                                                
                                                .. attribute:: rcv_patt
                                                
                                                	RCVD PTRN
                                                	**type**\:   :py:class:`PmPrbsPatternEtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEtEnum>`
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rcv_patt = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rcv-patt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rcv_patt is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance.RcvPatt']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15prbs-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.conf_patt is not None:
                                                    return True

                                                if self.ebc is not None:
                                                    return True

                                                if self.found_at_time is not None:
                                                    return True

                                                if self.found_count is not None:
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lost_at_time is not None:
                                                    return True

                                                if self.lost_count is not None:
                                                    return True

                                                if self.rcv_patt is not None and self.rcv_patt._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15prbs-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.odu_minute15prbs_time_line_instance is not None:
                                                for child_ref in self.odu_minute15prbs_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15prbs-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.odu_minute15prbs_time_line_instances is not None and self.odu_minute15prbs_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15prbs-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.odu_minute15prbs_history is not None:
                                        for child_ref in self.odu_minute15prbs_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories']['meta_info']


                            class OduMinute15GfpHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: odu_minute15gfp_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of    :py:class:`OduMinute15GfpHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.odu_minute15gfp_history = YList()
                                    self.odu_minute15gfp_history.parent = self
                                    self.odu_minute15gfp_history.name = 'odu_minute15gfp_history'


                                class OduMinute15GfpHistory(object):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_minute15gfp_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduMinute15GfpTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.odu_minute15gfp_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances()
                                        self.odu_minute15gfp_time_line_instances.parent = self


                                    class OduMinute15GfpTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_minute15gfp_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OduMinute15GfpTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.odu_minute15gfp_time_line_instance = YList()
                                            self.odu_minute15gfp_time_line_instance.parent = self
                                            self.odu_minute15gfp_time_line_instance.name = 'odu_minute15gfp_time_line_instance'


                                        class OduMinute15GfpTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: rx_bit_err
                                            
                                            	RX BIT ERR
                                            	**type**\:   :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxBitErr>`
                                            
                                            .. attribute:: rx_crc
                                            
                                            	RX CRC
                                            	**type**\:   :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCrc>`
                                            
                                            .. attribute:: rx_csf
                                            
                                            	RX CSF
                                            	**type**\:   :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCsf>`
                                            
                                            .. attribute:: rx_inv_typ
                                            
                                            	RX INV TYP
                                            	**type**\:   :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxInvTyp>`
                                            
                                            .. attribute:: rx_lfd
                                            
                                            	RX LFD
                                            	**type**\:   :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxLfd>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.rx_bit_err = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxBitErr()
                                                self.rx_bit_err.parent = self
                                                self.rx_crc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCrc()
                                                self.rx_crc.parent = self
                                                self.rx_csf = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCsf()
                                                self.rx_csf.parent = self
                                                self.rx_inv_typ = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxInvTyp()
                                                self.rx_inv_typ.parent = self
                                                self.rx_lfd = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxLfd()
                                                self.rx_lfd.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.valid = None


                                            class RxBitErr(object):
                                                """
                                                RX BIT ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-bit-err'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxBitErr']['meta_info']


                                            class RxInvTyp(object):
                                                """
                                                RX INV TYP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-inv-typ'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxInvTyp']['meta_info']


                                            class RxCrc(object):
                                                """
                                                RX CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-crc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCrc']['meta_info']


                                            class RxLfd(object):
                                                """
                                                RX LFD
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-lfd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxLfd']['meta_info']


                                            class RxCsf(object):
                                                """
                                                RX CSF
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-csf'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCsf']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15gfp-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.rx_bit_err is not None and self.rx_bit_err._has_data():
                                                    return True

                                                if self.rx_crc is not None and self.rx_crc._has_data():
                                                    return True

                                                if self.rx_csf is not None and self.rx_csf._has_data():
                                                    return True

                                                if self.rx_inv_typ is not None and self.rx_inv_typ._has_data():
                                                    return True

                                                if self.rx_lfd is not None and self.rx_lfd._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15gfp-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.odu_minute15gfp_time_line_instance is not None:
                                                for child_ref in self.odu_minute15gfp_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15gfp-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.odu_minute15gfp_time_line_instances is not None and self.odu_minute15gfp_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15gfp-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.odu_minute15gfp_history is not None:
                                        for child_ref in self.odu_minute15gfp_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories']['meta_info']


                            class OduMinute15OtnHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: odu_minute15otn_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of    :py:class:`OduMinute15OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.odu_minute15otn_history = YList()
                                    self.odu_minute15otn_history.parent = self
                                    self.odu_minute15otn_history.name = 'odu_minute15otn_history'


                                class OduMinute15OtnHistory(object):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_minute15otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduMinute15OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.odu_minute15otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances()
                                        self.odu_minute15otn_time_line_instances.parent = self


                                    class OduMinute15OtnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_minute15otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OduMinute15OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.odu_minute15otn_time_line_instance = YList()
                                            self.odu_minute15otn_time_line_instance.parent = self
                                            self.odu_minute15otn_time_line_instance.name = 'odu_minute15otn_time_line_instance'


                                        class OduMinute15OtnTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.sec30_support = None
                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self.timestamp = None
                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.Lbc']['meta_info']


                                            class EsNe(object):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsNe']['meta_info']


                                            class EsrNe(object):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrNe']['meta_info']


                                            class SesNe(object):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesNe']['meta_info']


                                            class SesrNe(object):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrNe']['meta_info']


                                            class UasNe(object):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasNe']['meta_info']


                                            class BbeNe(object):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeNe']['meta_info']


                                            class BberNe(object):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberNe']['meta_info']


                                            class FcNe(object):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcNe']['meta_info']


                                            class EsFe(object):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsFe']['meta_info']


                                            class EsrFe(object):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrFe']['meta_info']


                                            class SesFe(object):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesFe']['meta_info']


                                            class SesrFe(object):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrFe']['meta_info']


                                            class UasFe(object):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasFe']['meta_info']


                                            class BbeFe(object):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeFe']['meta_info']


                                            class BberFe(object):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberFe']['meta_info']


                                            class FcFe(object):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcFe']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15otn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.bbe_fe is not None and self.bbe_fe._has_data():
                                                    return True

                                                if self.bbe_ne is not None and self.bbe_ne._has_data():
                                                    return True

                                                if self.bber_fe is not None and self.bber_fe._has_data():
                                                    return True

                                                if self.bber_ne is not None and self.bber_ne._has_data():
                                                    return True

                                                if self.es_fe is not None and self.es_fe._has_data():
                                                    return True

                                                if self.es_ne is not None and self.es_ne._has_data():
                                                    return True

                                                if self.esr_fe is not None and self.esr_fe._has_data():
                                                    return True

                                                if self.esr_ne is not None and self.esr_ne._has_data():
                                                    return True

                                                if self.fc_fe is not None and self.fc_fe._has_data():
                                                    return True

                                                if self.fc_ne is not None and self.fc_ne._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.ses_fe is not None and self.ses_fe._has_data():
                                                    return True

                                                if self.ses_ne is not None and self.ses_ne._has_data():
                                                    return True

                                                if self.sesr_fe is not None and self.sesr_fe._has_data():
                                                    return True

                                                if self.sesr_ne is not None and self.sesr_ne._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uas_fe is not None and self.uas_fe._has_data():
                                                    return True

                                                if self.uas_ne is not None and self.uas_ne._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15otn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.odu_minute15otn_time_line_instance is not None:
                                                for child_ref in self.odu_minute15otn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15otn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.odu_minute15otn_time_line_instances is not None and self.odu_minute15otn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15otn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.odu_minute15otn_history is not None:
                                        for child_ref in self.odu_minute15otn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:odu-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.odu_minute15gfp_histories is not None and self.odu_minute15gfp_histories._has_data():
                                    return True

                                if self.odu_minute15otn_histories is not None and self.odu_minute15otn_histories._has_data():
                                    return True

                                if self.odu_minute15prbs_histories is not None and self.odu_minute15prbs_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:odu-history/Cisco-IOS-XR-pmengine-oper:odu-port-histories/Cisco-IOS-XR-pmengine-oper:odu-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.odu_hour24_history is not None and self.odu_hour24_history._has_data():
                                return True

                            if self.odu_minute15_history is not None and self.odu_minute15_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:odu-history/Cisco-IOS-XR-pmengine-oper:odu-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.odu_port_history is not None:
                            for child_ref in self.odu_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:odu-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.odu_port_histories is not None and self.odu_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OduHistory']['meta_info']


            class OtuHistory(object):
                """
                OTU controller History performance data
                
                .. attribute:: otu_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`OtuPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.otu_port_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories()
                    self.otu_port_histories.parent = self


                class OtuPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: otu_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`OtuPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.otu_port_history = YList()
                        self.otu_port_history.parent = self
                        self.otu_port_history.name = 'otu_port_history'


                    class OtuPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: otu_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History>`
                        
                        .. attribute:: otu_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History>`
                        
                        .. attribute:: otu_second30_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.otu_hour24_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History()
                            self.otu_hour24_history.parent = self
                            self.otu_minute15_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History()
                            self.otu_minute15_history.parent = self
                            self.otu_second30_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History()
                            self.otu_second30_history.parent = self


                        class OtuSecond30History(object):
                            """
                            port current performance data
                            
                            .. attribute:: otu_second30fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuSecond30FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories>`
                            
                            .. attribute:: otu_second30otn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuSecond30OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.otu_second30fec_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories()
                                self.otu_second30fec_histories.parent = self
                                self.otu_second30otn_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories()
                                self.otu_second30otn_histories.parent = self


                            class OtuSecond30FecHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: otu_second30fec_history
                                
                                	port 30\-second fec performance data
                                	**type**\: list of    :py:class:`OtuSecond30FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.otu_second30fec_history = YList()
                                    self.otu_second30fec_history.parent = self
                                    self.otu_second30fec_history.name = 'otu_second30fec_history'


                                class OtuSecond30FecHistory(object):
                                    """
                                    port 30\-second fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_second30fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuSecond30FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.otu_second30fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances()
                                        self.otu_second30fec_time_line_instances.parent = self


                                    class OtuSecond30FecTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_second30fec_time_line_instance
                                        
                                        	port 30\-second fec performance data
                                        	**type**\: list of    :py:class:`OtuSecond30FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.otu_second30fec_time_line_instance = YList()
                                            self.otu_second30fec_time_line_instance.parent = self
                                            self.otu_second30fec_time_line_instance.name = 'otu_second30fec_time_line_instance'


                                        class OtuSecond30FecTimeLineInstance(object):
                                            """
                                            port 30\-second fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self.q = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self.valid = None


                                            class EcBits(object):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.EcBits']['meta_info']


                                            class UcWords(object):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.UcWords']['meta_info']


                                            class PreFecBer(object):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PreFecBer']['meta_info']


                                            class PostFecBer(object):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PostFecBer']['meta_info']


                                            class Q(object):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Q']['meta_info']


                                            class Qmargin(object):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Qmargin']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30fec-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ec_bits is not None and self.ec_bits._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                                    return True

                                                if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                                    return True

                                                if self.q is not None and self.q._has_data():
                                                    return True

                                                if self.qmargin is not None and self.qmargin._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uc_words is not None and self.uc_words._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30fec-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.otu_second30fec_time_line_instance is not None:
                                                for child_ref in self.otu_second30fec_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30fec-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.otu_second30fec_time_line_instances is not None and self.otu_second30fec_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30fec-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.otu_second30fec_history is not None:
                                        for child_ref in self.otu_second30fec_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories']['meta_info']


                            class OtuSecond30OtnHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: otu_second30otn_history
                                
                                	port 30\-second otn performance data
                                	**type**\: list of    :py:class:`OtuSecond30OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.otu_second30otn_history = YList()
                                    self.otu_second30otn_history.parent = self
                                    self.otu_second30otn_history.name = 'otu_second30otn_history'


                                class OtuSecond30OtnHistory(object):
                                    """
                                    port 30\-second otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_second30otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuSecond30OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.otu_second30otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances()
                                        self.otu_second30otn_time_line_instances.parent = self


                                    class OtuSecond30OtnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_second30otn_time_line_instance
                                        
                                        	port 30\-second otn performance data
                                        	**type**\: list of    :py:class:`OtuSecond30OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.otu_second30otn_time_line_instance = YList()
                                            self.otu_second30otn_time_line_instance.parent = self
                                            self.otu_second30otn_time_line_instance.name = 'otu_second30otn_time_line_instance'


                                        class OtuSecond30OtnTimeLineInstance(object):
                                            """
                                            port 30\-second otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.sec30_support = None
                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self.timestamp = None
                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.Lbc']['meta_info']


                                            class EsNe(object):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsNe']['meta_info']


                                            class EsrNe(object):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrNe']['meta_info']


                                            class SesNe(object):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesNe']['meta_info']


                                            class SesrNe(object):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrNe']['meta_info']


                                            class UasNe(object):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasNe']['meta_info']


                                            class BbeNe(object):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeNe']['meta_info']


                                            class BberNe(object):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberNe']['meta_info']


                                            class FcNe(object):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcNe']['meta_info']


                                            class EsFe(object):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsFe']['meta_info']


                                            class EsrFe(object):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrFe']['meta_info']


                                            class SesFe(object):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesFe']['meta_info']


                                            class SesrFe(object):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrFe']['meta_info']


                                            class UasFe(object):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasFe']['meta_info']


                                            class BbeFe(object):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeFe']['meta_info']


                                            class BberFe(object):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberFe']['meta_info']


                                            class FcFe(object):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcFe']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30otn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.bbe_fe is not None and self.bbe_fe._has_data():
                                                    return True

                                                if self.bbe_ne is not None and self.bbe_ne._has_data():
                                                    return True

                                                if self.bber_fe is not None and self.bber_fe._has_data():
                                                    return True

                                                if self.bber_ne is not None and self.bber_ne._has_data():
                                                    return True

                                                if self.es_fe is not None and self.es_fe._has_data():
                                                    return True

                                                if self.es_ne is not None and self.es_ne._has_data():
                                                    return True

                                                if self.esr_fe is not None and self.esr_fe._has_data():
                                                    return True

                                                if self.esr_ne is not None and self.esr_ne._has_data():
                                                    return True

                                                if self.fc_fe is not None and self.fc_fe._has_data():
                                                    return True

                                                if self.fc_ne is not None and self.fc_ne._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.ses_fe is not None and self.ses_fe._has_data():
                                                    return True

                                                if self.ses_ne is not None and self.ses_ne._has_data():
                                                    return True

                                                if self.sesr_fe is not None and self.sesr_fe._has_data():
                                                    return True

                                                if self.sesr_ne is not None and self.sesr_ne._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uas_fe is not None and self.uas_fe._has_data():
                                                    return True

                                                if self.uas_ne is not None and self.uas_ne._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30otn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.otu_second30otn_time_line_instance is not None:
                                                for child_ref in self.otu_second30otn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30otn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.otu_second30otn_time_line_instances is not None and self.otu_second30otn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30otn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.otu_second30otn_history is not None:
                                        for child_ref in self.otu_second30otn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-second30-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.otu_second30fec_histories is not None and self.otu_second30fec_histories._has_data():
                                    return True

                                if self.otu_second30otn_histories is not None and self.otu_second30otn_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History']['meta_info']


                        class OtuMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuMinute15FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories>`
                            
                            .. attribute:: otu_minute15otn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuMinute15OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.otu_minute15fec_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories()
                                self.otu_minute15fec_histories.parent = self
                                self.otu_minute15otn_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories()
                                self.otu_minute15otn_histories.parent = self


                            class OtuMinute15FecHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: otu_minute15fec_history
                                
                                	port 15\-minute fec performance data
                                	**type**\: list of    :py:class:`OtuMinute15FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.otu_minute15fec_history = YList()
                                    self.otu_minute15fec_history.parent = self
                                    self.otu_minute15fec_history.name = 'otu_minute15fec_history'


                                class OtuMinute15FecHistory(object):
                                    """
                                    port 15\-minute fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_minute15fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuMinute15FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.otu_minute15fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances()
                                        self.otu_minute15fec_time_line_instances.parent = self


                                    class OtuMinute15FecTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_minute15fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of    :py:class:`OtuMinute15FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.otu_minute15fec_time_line_instance = YList()
                                            self.otu_minute15fec_time_line_instance.parent = self
                                            self.otu_minute15fec_time_line_instance.name = 'otu_minute15fec_time_line_instance'


                                        class OtuMinute15FecTimeLineInstance(object):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self.q = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self.valid = None


                                            class EcBits(object):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.EcBits']['meta_info']


                                            class UcWords(object):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.UcWords']['meta_info']


                                            class PreFecBer(object):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PreFecBer']['meta_info']


                                            class PostFecBer(object):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PostFecBer']['meta_info']


                                            class Q(object):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Q']['meta_info']


                                            class Qmargin(object):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Qmargin']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15fec-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ec_bits is not None and self.ec_bits._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                                    return True

                                                if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                                    return True

                                                if self.q is not None and self.q._has_data():
                                                    return True

                                                if self.qmargin is not None and self.qmargin._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uc_words is not None and self.uc_words._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15fec-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.otu_minute15fec_time_line_instance is not None:
                                                for child_ref in self.otu_minute15fec_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15fec-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.otu_minute15fec_time_line_instances is not None and self.otu_minute15fec_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15fec-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.otu_minute15fec_history is not None:
                                        for child_ref in self.otu_minute15fec_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories']['meta_info']


                            class OtuMinute15OtnHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: otu_minute15otn_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of    :py:class:`OtuMinute15OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.otu_minute15otn_history = YList()
                                    self.otu_minute15otn_history.parent = self
                                    self.otu_minute15otn_history.name = 'otu_minute15otn_history'


                                class OtuMinute15OtnHistory(object):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_minute15otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuMinute15OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.otu_minute15otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances()
                                        self.otu_minute15otn_time_line_instances.parent = self


                                    class OtuMinute15OtnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_minute15otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OtuMinute15OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.otu_minute15otn_time_line_instance = YList()
                                            self.otu_minute15otn_time_line_instance.parent = self
                                            self.otu_minute15otn_time_line_instance.name = 'otu_minute15otn_time_line_instance'


                                        class OtuMinute15OtnTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.sec30_support = None
                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self.timestamp = None
                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.Lbc']['meta_info']


                                            class EsNe(object):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsNe']['meta_info']


                                            class EsrNe(object):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrNe']['meta_info']


                                            class SesNe(object):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesNe']['meta_info']


                                            class SesrNe(object):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrNe']['meta_info']


                                            class UasNe(object):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasNe']['meta_info']


                                            class BbeNe(object):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeNe']['meta_info']


                                            class BberNe(object):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberNe']['meta_info']


                                            class FcNe(object):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcNe']['meta_info']


                                            class EsFe(object):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsFe']['meta_info']


                                            class EsrFe(object):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrFe']['meta_info']


                                            class SesFe(object):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesFe']['meta_info']


                                            class SesrFe(object):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrFe']['meta_info']


                                            class UasFe(object):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasFe']['meta_info']


                                            class BbeFe(object):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeFe']['meta_info']


                                            class BberFe(object):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberFe']['meta_info']


                                            class FcFe(object):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcFe']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15otn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.bbe_fe is not None and self.bbe_fe._has_data():
                                                    return True

                                                if self.bbe_ne is not None and self.bbe_ne._has_data():
                                                    return True

                                                if self.bber_fe is not None and self.bber_fe._has_data():
                                                    return True

                                                if self.bber_ne is not None and self.bber_ne._has_data():
                                                    return True

                                                if self.es_fe is not None and self.es_fe._has_data():
                                                    return True

                                                if self.es_ne is not None and self.es_ne._has_data():
                                                    return True

                                                if self.esr_fe is not None and self.esr_fe._has_data():
                                                    return True

                                                if self.esr_ne is not None and self.esr_ne._has_data():
                                                    return True

                                                if self.fc_fe is not None and self.fc_fe._has_data():
                                                    return True

                                                if self.fc_ne is not None and self.fc_ne._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.ses_fe is not None and self.ses_fe._has_data():
                                                    return True

                                                if self.ses_ne is not None and self.ses_ne._has_data():
                                                    return True

                                                if self.sesr_fe is not None and self.sesr_fe._has_data():
                                                    return True

                                                if self.sesr_ne is not None and self.sesr_ne._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uas_fe is not None and self.uas_fe._has_data():
                                                    return True

                                                if self.uas_ne is not None and self.uas_ne._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15otn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.otu_minute15otn_time_line_instance is not None:
                                                for child_ref in self.otu_minute15otn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15otn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.otu_minute15otn_time_line_instances is not None and self.otu_minute15otn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15otn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.otu_minute15otn_history is not None:
                                        for child_ref in self.otu_minute15otn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.otu_minute15fec_histories is not None and self.otu_minute15fec_histories._has_data():
                                    return True

                                if self.otu_minute15otn_histories is not None and self.otu_minute15otn_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History']['meta_info']


                        class OtuHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: otu_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuHour24FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories>`
                            
                            .. attribute:: otu_hour24otn_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OtuHour24OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.otu_hour24fec_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories()
                                self.otu_hour24fec_histories.parent = self
                                self.otu_hour24otn_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories()
                                self.otu_hour24otn_histories.parent = self


                            class OtuHour24OtnHistories(object):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: otu_hour24otn_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of    :py:class:`OtuHour24OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.otu_hour24otn_history = YList()
                                    self.otu_hour24otn_history.parent = self
                                    self.otu_hour24otn_history.name = 'otu_hour24otn_history'


                                class OtuHour24OtnHistory(object):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_hour24otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuHour24OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.otu_hour24otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances()
                                        self.otu_hour24otn_time_line_instances.parent = self


                                    class OtuHour24OtnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_hour24otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OtuHour24OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.otu_hour24otn_time_line_instance = YList()
                                            self.otu_hour24otn_time_line_instance.parent = self
                                            self.otu_hour24otn_time_line_instance.name = 'otu_hour24otn_time_line_instance'


                                        class OtuHour24OtnTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.sec30_support = None
                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self.timestamp = None
                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.Lbc']['meta_info']


                                            class EsNe(object):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsNe']['meta_info']


                                            class EsrNe(object):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrNe']['meta_info']


                                            class SesNe(object):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesNe']['meta_info']


                                            class SesrNe(object):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrNe']['meta_info']


                                            class UasNe(object):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasNe']['meta_info']


                                            class BbeNe(object):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeNe']['meta_info']


                                            class BberNe(object):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberNe']['meta_info']


                                            class FcNe(object):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-ne'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcNe']['meta_info']


                                            class EsFe(object):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:es-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsFe']['meta_info']


                                            class EsrFe(object):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:esr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrFe']['meta_info']


                                            class SesFe(object):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ses-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesFe']['meta_info']


                                            class SesrFe(object):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:sesr-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrFe']['meta_info']


                                            class UasFe(object):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uas-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasFe']['meta_info']


                                            class BbeFe(object):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bbe-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeFe']['meta_info']


                                            class BberFe(object):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:bber-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberFe']['meta_info']


                                            class FcFe(object):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fc-fe'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcFe']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24otn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.bbe_fe is not None and self.bbe_fe._has_data():
                                                    return True

                                                if self.bbe_ne is not None and self.bbe_ne._has_data():
                                                    return True

                                                if self.bber_fe is not None and self.bber_fe._has_data():
                                                    return True

                                                if self.bber_ne is not None and self.bber_ne._has_data():
                                                    return True

                                                if self.es_fe is not None and self.es_fe._has_data():
                                                    return True

                                                if self.es_ne is not None and self.es_ne._has_data():
                                                    return True

                                                if self.esr_fe is not None and self.esr_fe._has_data():
                                                    return True

                                                if self.esr_ne is not None and self.esr_ne._has_data():
                                                    return True

                                                if self.fc_fe is not None and self.fc_fe._has_data():
                                                    return True

                                                if self.fc_ne is not None and self.fc_ne._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.ses_fe is not None and self.ses_fe._has_data():
                                                    return True

                                                if self.ses_ne is not None and self.ses_ne._has_data():
                                                    return True

                                                if self.sesr_fe is not None and self.sesr_fe._has_data():
                                                    return True

                                                if self.sesr_ne is not None and self.sesr_ne._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uas_fe is not None and self.uas_fe._has_data():
                                                    return True

                                                if self.uas_ne is not None and self.uas_ne._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24otn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.otu_hour24otn_time_line_instance is not None:
                                                for child_ref in self.otu_hour24otn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24otn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.otu_hour24otn_time_line_instances is not None and self.otu_hour24otn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24otn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.otu_hour24otn_history is not None:
                                        for child_ref in self.otu_hour24otn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories']['meta_info']


                            class OtuHour24FecHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: otu_hour24fec_history
                                
                                	port 24 hour fec performance data
                                	**type**\: list of    :py:class:`OtuHour24FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.otu_hour24fec_history = YList()
                                    self.otu_hour24fec_history.parent = self
                                    self.otu_hour24fec_history.name = 'otu_hour24fec_history'


                                class OtuHour24FecHistory(object):
                                    """
                                    port 24 hour fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuHour24FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.otu_hour24fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances()
                                        self.otu_hour24fec_time_line_instances.parent = self


                                    class OtuHour24FecTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_hour24fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of    :py:class:`OtuHour24FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.otu_hour24fec_time_line_instance = YList()
                                            self.otu_hour24fec_time_line_instance.parent = self
                                            self.otu_hour24fec_time_line_instance.name = 'otu_hour24fec_time_line_instance'


                                        class OtuHour24FecTimeLineInstance(object):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self.q = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self.valid = None


                                            class EcBits(object):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.EcBits']['meta_info']


                                            class UcWords(object):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.UcWords']['meta_info']


                                            class PreFecBer(object):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PreFecBer']['meta_info']


                                            class PostFecBer(object):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PostFecBer']['meta_info']


                                            class Q(object):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Q']['meta_info']


                                            class Qmargin(object):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Qmargin']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24fec-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ec_bits is not None and self.ec_bits._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                                    return True

                                                if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                                    return True

                                                if self.q is not None and self.q._has_data():
                                                    return True

                                                if self.qmargin is not None and self.qmargin._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uc_words is not None and self.uc_words._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24fec-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.otu_hour24fec_time_line_instance is not None:
                                                for child_ref in self.otu_hour24fec_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24fec-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.otu_hour24fec_time_line_instances is not None and self.otu_hour24fec_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24fec-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.otu_hour24fec_history is not None:
                                        for child_ref in self.otu_hour24fec_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:otu-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.otu_hour24fec_histories is not None and self.otu_hour24fec_histories._has_data():
                                    return True

                                if self.otu_hour24otn_histories is not None and self.otu_hour24otn_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:otu-history/Cisco-IOS-XR-pmengine-oper:otu-port-histories/Cisco-IOS-XR-pmengine-oper:otu-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.otu_hour24_history is not None and self.otu_hour24_history._has_data():
                                return True

                            if self.otu_minute15_history is not None and self.otu_minute15_history._has_data():
                                return True

                            if self.otu_second30_history is not None and self.otu_second30_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:otu-history/Cisco-IOS-XR-pmengine-oper:otu-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.otu_port_history is not None:
                            for child_ref in self.otu_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:otu-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.otu_port_histories is not None and self.otu_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OtuHistory']['meta_info']


            class HoVcHistory(object):
                """
                HO\_VC controller History performance data
                
                .. attribute:: ho_vc_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`HoVcPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ho_vc_port_histories = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories()
                    self.ho_vc_port_histories.parent = self


                class HoVcPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: ho_vc_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`HoVcPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ho_vc_port_history = YList()
                        self.ho_vc_port_history.parent = self
                        self.ho_vc_port_history.name = 'ho_vc_port_history'


                    class HoVcPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: ho_vc_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`HoVcHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History>`
                        
                        .. attribute:: ho_vc_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`HoVcMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.ho_vc_hour24_history = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History()
                            self.ho_vc_hour24_history.parent = self
                            self.ho_vc_minute15_history = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History()
                            self.ho_vc_minute15_history.parent = self


                        class HoVcMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_minute15_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`HoVcMinute15PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ho_vc_minute15_path_histories = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories()
                                self.ho_vc_minute15_path_histories.parent = self


                            class HoVcMinute15PathHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: ho_vc_minute15_path_history
                                
                                	port 15\-minute Path performance data
                                	**type**\: list of    :py:class:`HoVcMinute15PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ho_vc_minute15_path_history = YList()
                                    self.ho_vc_minute15_path_history.parent = self
                                    self.ho_vc_minute15_path_history.name = 'ho_vc_minute15_path_history'


                                class HoVcMinute15PathHistory(object):
                                    """
                                    port 15\-minute Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ho_vc_minute15_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`HoVcMinute15PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.ho_vc_minute15_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances()
                                        self.ho_vc_minute15_path_time_line_instances.parent = self


                                    class HoVcMinute15PathTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ho_vc_minute15_path_time_line_instance
                                        
                                        	port 15\-minute ho\_vc performance data
                                        	**type**\: list of    :py:class:`HoVcMinute15PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ho_vc_minute15_path_time_line_instance = YList()
                                            self.ho_vc_minute15_path_time_line_instance.parent = self
                                            self.ho_vc_minute15_path_time_line_instance.name = 'ho_vc_minute15_path_time_line_instance'


                                        class HoVcMinute15PathTimeLineInstance(object):
                                            """
                                            port 15\-minute ho\_vc performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Path(object):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_bb_es
                                                
                                                	The number of background block errors
                                                	**type**\:   :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs>`
                                                
                                                .. attribute:: path_bbe_rs
                                                
                                                	The number of background block errors
                                                	**type**\:   :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs>`
                                                
                                                .. attribute:: path_e_bs
                                                
                                                	The number of Errored blocks
                                                	**type**\:   :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_es_rs
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_ses_rs
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.path_bb_es = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs()
                                                    self.path_bb_es.parent = self
                                                    self.path_bbe_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs()
                                                    self.path_bbe_rs.parent = self
                                                    self.path_e_bs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs()
                                                    self.path_e_bs.parent = self
                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self.path_es_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs()
                                                    self.path_es_rs.parent = self
                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self.path_ses_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs()
                                                    self.path_ses_rs.parent = self
                                                    self.path_status = None
                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self


                                                class PathESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs']['meta_info']


                                                class PathEsRs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-es-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs']['meta_info']


                                                class PathSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs']['meta_info']


                                                class PathSesRs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ses-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs']['meta_info']


                                                class PathEBs(object):
                                                    """
                                                    The number of Errored blocks
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-bs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs']['meta_info']


                                                class PathUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs']['meta_info']


                                                class PathBbEs(object):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-bb-es'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs']['meta_info']


                                                class PathBbeRs(object):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-bbe-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.path_bb_es is not None and self.path_bb_es._has_data():
                                                        return True

                                                    if self.path_bbe_rs is not None and self.path_bbe_rs._has_data():
                                                        return True

                                                    if self.path_e_bs is not None and self.path_e_bs._has_data():
                                                        return True

                                                    if self.path_e_ss is not None and self.path_e_ss._has_data():
                                                        return True

                                                    if self.path_es_rs is not None and self.path_es_rs._has_data():
                                                        return True

                                                    if self.path_se_ss is not None and self.path_se_ss._has_data():
                                                        return True

                                                    if self.path_ses_rs is not None and self.path_ses_rs._has_data():
                                                        return True

                                                    if self.path_status is not None:
                                                        return True

                                                    if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path']['meta_info']


                                            class FePath(object):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_ua_ss = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_path_c_vs is not None:
                                                        return True

                                                    if self.far_end_path_e_ss is not None:
                                                        return True

                                                    if self.far_end_path_se_ss is not None:
                                                        return True

                                                    if self.far_end_path_ua_ss is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-minute15-path-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_path is not None and self.fe_path._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.path is not None and self.path._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-minute15-path-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ho_vc_minute15_path_time_line_instance is not None:
                                                for child_ref in self.ho_vc_minute15_path_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-minute15-path-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.ho_vc_minute15_path_time_line_instances is not None and self.ho_vc_minute15_path_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-minute15-path-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ho_vc_minute15_path_history is not None:
                                        for child_ref in self.ho_vc_minute15_path_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ho_vc_minute15_path_histories is not None and self.ho_vc_minute15_path_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History']['meta_info']


                        class HoVcHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_hour24_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`HoVcHour24PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ho_vc_hour24_path_histories = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories()
                                self.ho_vc_hour24_path_histories.parent = self


                            class HoVcHour24PathHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: ho_vc_hour24_path_history
                                
                                	port 24 hour Path performance data
                                	**type**\: list of    :py:class:`HoVcHour24PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ho_vc_hour24_path_history = YList()
                                    self.ho_vc_hour24_path_history.parent = self
                                    self.ho_vc_hour24_path_history.name = 'ho_vc_hour24_path_history'


                                class HoVcHour24PathHistory(object):
                                    """
                                    port 24 hour Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ho_vc_hour24_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`HoVcHour24PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.ho_vc_hour24_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances()
                                        self.ho_vc_hour24_path_time_line_instances.parent = self


                                    class HoVcHour24PathTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ho_vc_hour24_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`HoVcHour24PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ho_vc_hour24_path_time_line_instance = YList()
                                            self.ho_vc_hour24_path_time_line_instance.parent = self
                                            self.ho_vc_hour24_path_time_line_instance.name = 'ho_vc_hour24_path_time_line_instance'


                                        class HoVcHour24PathTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Path(object):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_bb_es
                                                
                                                	The number of background block errors
                                                	**type**\:   :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs>`
                                                
                                                .. attribute:: path_bbe_rs
                                                
                                                	The number of background block errors
                                                	**type**\:   :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs>`
                                                
                                                .. attribute:: path_e_bs
                                                
                                                	The number of Errored blocks
                                                	**type**\:   :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_es_rs
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_ses_rs
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.path_bb_es = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs()
                                                    self.path_bb_es.parent = self
                                                    self.path_bbe_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs()
                                                    self.path_bbe_rs.parent = self
                                                    self.path_e_bs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs()
                                                    self.path_e_bs.parent = self
                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self.path_es_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs()
                                                    self.path_es_rs.parent = self
                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self.path_ses_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs()
                                                    self.path_ses_rs.parent = self
                                                    self.path_status = None
                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self


                                                class PathESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs']['meta_info']


                                                class PathEsRs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-es-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs']['meta_info']


                                                class PathSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs']['meta_info']


                                                class PathSesRs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ses-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs']['meta_info']


                                                class PathEBs(object):
                                                    """
                                                    The number of Errored blocks
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-e-bs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs']['meta_info']


                                                class PathUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs']['meta_info']


                                                class PathBbEs(object):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-bb-es'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs']['meta_info']


                                                class PathBbeRs(object):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path-bbe-rs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.path_bb_es is not None and self.path_bb_es._has_data():
                                                        return True

                                                    if self.path_bbe_rs is not None and self.path_bbe_rs._has_data():
                                                        return True

                                                    if self.path_e_bs is not None and self.path_e_bs._has_data():
                                                        return True

                                                    if self.path_e_ss is not None and self.path_e_ss._has_data():
                                                        return True

                                                    if self.path_es_rs is not None and self.path_es_rs._has_data():
                                                        return True

                                                    if self.path_se_ss is not None and self.path_se_ss._has_data():
                                                        return True

                                                    if self.path_ses_rs is not None and self.path_ses_rs._has_data():
                                                        return True

                                                    if self.path_status is not None:
                                                        return True

                                                    if self.path_ua_ss is not None and self.path_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path']['meta_info']


                                            class FePath(object):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_path_c_vs = None
                                                    self.far_end_path_e_ss = None
                                                    self.far_end_path_se_ss = None
                                                    self.far_end_path_ua_ss = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_path_c_vs is not None:
                                                        return True

                                                    if self.far_end_path_e_ss is not None:
                                                        return True

                                                    if self.far_end_path_se_ss is not None:
                                                        return True

                                                    if self.far_end_path_ua_ss is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-hour24-path-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_path is not None and self.fe_path._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.path is not None and self.path._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-hour24-path-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ho_vc_hour24_path_time_line_instance is not None:
                                                for child_ref in self.ho_vc_hour24_path_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-hour24-path-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.ho_vc_hour24_path_time_line_instances is not None and self.ho_vc_hour24_path_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-hour24-path-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ho_vc_hour24_path_history is not None:
                                        for child_ref in self.ho_vc_hour24_path_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ho-vc-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ho_vc_hour24_path_histories is not None and self.ho_vc_hour24_path_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:ho-vc-history/Cisco-IOS-XR-pmengine-oper:ho-vc-port-histories/Cisco-IOS-XR-pmengine-oper:ho-vc-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.ho_vc_hour24_history is not None and self.ho_vc_hour24_history._has_data():
                                return True

                            if self.ho_vc_minute15_history is not None and self.ho_vc_minute15_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:ho-vc-history/Cisco-IOS-XR-pmengine-oper:ho-vc-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ho_vc_port_history is not None:
                            for child_ref in self.ho_vc_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:ho-vc-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ho_vc_port_histories is not None and self.ho_vc_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.HoVcHistory']['meta_info']


            class OpticsHistory(object):
                """
                OPTICS controller History performance data
                
                .. attribute:: optics_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`OpticsPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.optics_port_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories()
                    self.optics_port_histories.parent = self


                class OpticsPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: optics_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`OpticsPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.optics_port_history = YList()
                        self.optics_port_history.parent = self
                        self.optics_port_history.name = 'optics_port_history'


                    class OpticsPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: optics_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History>`
                        
                        .. attribute:: optics_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History>`
                        
                        .. attribute:: optics_second30_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.optics_hour24_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History()
                            self.optics_hour24_history.parent = self
                            self.optics_minute15_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History()
                            self.optics_minute15_history.parent = self
                            self.optics_second30_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History()
                            self.optics_second30_history.parent = self


                        class OpticsHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: optics_hour24_optics_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OpticsHour24OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories>`
                            
                            .. attribute:: optics_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsHour24FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.optics_hour24_optics_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories()
                                self.optics_hour24_optics_histories.parent = self
                                self.optics_hour24fec_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories()
                                self.optics_hour24fec_histories.parent = self


                            class OpticsHour24OpticsHistories(object):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: optics_hour24_optics_history
                                
                                	port 24 hour optics performance data
                                	**type**\: list of    :py:class:`OpticsHour24OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.optics_hour24_optics_history = YList()
                                    self.optics_hour24_optics_history.parent = self
                                    self.optics_hour24_optics_history.name = 'optics_hour24_optics_history'


                                class OpticsHour24OpticsHistory(object):
                                    """
                                    port 24 hour optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_hour24_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsHour24OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.optics_hour24_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances()
                                        self.optics_hour24_optics_time_line_instances.parent = self


                                    class OpticsHour24OpticsTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_hour24_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OpticsHour24OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.optics_hour24_optics_time_line_instance = YList()
                                            self.optics_hour24_optics_time_line_instance.parent = self
                                            self.optics_hour24_optics_time_line_instance.name = 'optics_hour24_optics_time_line_instance'


                                        class OpticsHour24OpticsTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.cd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self.opr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self.opt = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self.pn = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc']['meta_info']


                                            class LbcPc(object):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc']['meta_info']


                                            class Opt(object):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt']['meta_info']


                                            class Opr(object):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr']['meta_info']


                                            class Cd(object):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd']['meta_info']


                                            class Dgd(object):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd']['meta_info']


                                            class Pmd(object):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd']['meta_info']


                                            class Osnr(object):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr']['meta_info']


                                            class CenterWavelength(object):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength']['meta_info']


                                            class Pdl(object):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl']['meta_info']


                                            class Pcr(object):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr']['meta_info']


                                            class Pn(object):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn']['meta_info']


                                            class RxSigPow(object):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow']['meta_info']


                                            class LowSigFreqOff(object):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24-optics-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.cd is not None and self.cd._has_data():
                                                    return True

                                                if self.center_wavelength is not None and self.center_wavelength._has_data():
                                                    return True

                                                if self.dgd is not None and self.dgd._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.lbc_pc is not None and self.lbc_pc._has_data():
                                                    return True

                                                if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                                    return True

                                                if self.opr is not None and self.opr._has_data():
                                                    return True

                                                if self.opt is not None and self.opt._has_data():
                                                    return True

                                                if self.osnr is not None and self.osnr._has_data():
                                                    return True

                                                if self.pcr is not None and self.pcr._has_data():
                                                    return True

                                                if self.pdl is not None and self.pdl._has_data():
                                                    return True

                                                if self.pmd is not None and self.pmd._has_data():
                                                    return True

                                                if self.pn is not None and self.pn._has_data():
                                                    return True

                                                if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24-optics-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.optics_hour24_optics_time_line_instance is not None:
                                                for child_ref in self.optics_hour24_optics_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24-optics-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.optics_hour24_optics_time_line_instances is not None and self.optics_hour24_optics_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24-optics-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.optics_hour24_optics_history is not None:
                                        for child_ref in self.optics_hour24_optics_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories']['meta_info']


                            class OpticsHour24FecHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: optics_hour24fec_history
                                
                                	port 24 hour fec performance data
                                	**type**\: list of    :py:class:`OpticsHour24FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.optics_hour24fec_history = YList()
                                    self.optics_hour24fec_history.parent = self
                                    self.optics_hour24fec_history.name = 'optics_hour24fec_history'


                                class OpticsHour24FecHistory(object):
                                    """
                                    port 24 hour fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsHour24FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.optics_hour24fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances()
                                        self.optics_hour24fec_time_line_instances.parent = self


                                    class OpticsHour24FecTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_hour24fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of    :py:class:`OpticsHour24FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.optics_hour24fec_time_line_instance = YList()
                                            self.optics_hour24fec_time_line_instance.parent = self
                                            self.optics_hour24fec_time_line_instance.name = 'optics_hour24fec_time_line_instance'


                                        class OpticsHour24FecTimeLineInstance(object):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self.q = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self.valid = None


                                            class EcBits(object):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.EcBits']['meta_info']


                                            class UcWords(object):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.UcWords']['meta_info']


                                            class PreFecBer(object):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PreFecBer']['meta_info']


                                            class PostFecBer(object):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PostFecBer']['meta_info']


                                            class Q(object):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Q']['meta_info']


                                            class Qmargin(object):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Qmargin']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24fec-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ec_bits is not None and self.ec_bits._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                                    return True

                                                if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                                    return True

                                                if self.q is not None and self.q._has_data():
                                                    return True

                                                if self.qmargin is not None and self.qmargin._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uc_words is not None and self.uc_words._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24fec-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.optics_hour24fec_time_line_instance is not None:
                                                for child_ref in self.optics_hour24fec_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24fec-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.optics_hour24fec_time_line_instances is not None and self.optics_hour24fec_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24fec-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.optics_hour24fec_history is not None:
                                        for child_ref in self.optics_hour24fec_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.optics_hour24_optics_histories is not None and self.optics_hour24_optics_histories._has_data():
                                    return True

                                if self.optics_hour24fec_histories is not None and self.optics_hour24fec_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History']['meta_info']


                        class OpticsSecond30History(object):
                            """
                            port current performance data
                            
                            .. attribute:: optics_second30_optics_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsSecond30OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories>`
                            
                            .. attribute:: optics_second30fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsSecond30FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.optics_second30_optics_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories()
                                self.optics_second30_optics_histories.parent = self
                                self.optics_second30fec_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories()
                                self.optics_second30fec_histories.parent = self


                            class OpticsSecond30OpticsHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: optics_second30_optics_history
                                
                                	port 30\-second optics performance data
                                	**type**\: list of    :py:class:`OpticsSecond30OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.optics_second30_optics_history = YList()
                                    self.optics_second30_optics_history.parent = self
                                    self.optics_second30_optics_history.name = 'optics_second30_optics_history'


                                class OpticsSecond30OpticsHistory(object):
                                    """
                                    port 30\-second optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_second30_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsSecond30OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.optics_second30_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances()
                                        self.optics_second30_optics_time_line_instances.parent = self


                                    class OpticsSecond30OpticsTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_second30_optics_time_line_instance
                                        
                                        	port 30 second otn performance data
                                        	**type**\: list of    :py:class:`OpticsSecond30OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.optics_second30_optics_time_line_instance = YList()
                                            self.optics_second30_optics_time_line_instance.parent = self
                                            self.optics_second30_optics_time_line_instance.name = 'optics_second30_optics_time_line_instance'


                                        class OpticsSecond30OpticsTimeLineInstance(object):
                                            """
                                            port 30 second otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.cd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self.opr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self.opt = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self.pn = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc']['meta_info']


                                            class LbcPc(object):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc']['meta_info']


                                            class Opt(object):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt']['meta_info']


                                            class Opr(object):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr']['meta_info']


                                            class Cd(object):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd']['meta_info']


                                            class Dgd(object):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd']['meta_info']


                                            class Pmd(object):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd']['meta_info']


                                            class Osnr(object):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr']['meta_info']


                                            class CenterWavelength(object):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength']['meta_info']


                                            class Pdl(object):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl']['meta_info']


                                            class Pcr(object):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr']['meta_info']


                                            class Pn(object):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn']['meta_info']


                                            class RxSigPow(object):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow']['meta_info']


                                            class LowSigFreqOff(object):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30-optics-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.cd is not None and self.cd._has_data():
                                                    return True

                                                if self.center_wavelength is not None and self.center_wavelength._has_data():
                                                    return True

                                                if self.dgd is not None and self.dgd._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.lbc_pc is not None and self.lbc_pc._has_data():
                                                    return True

                                                if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                                    return True

                                                if self.opr is not None and self.opr._has_data():
                                                    return True

                                                if self.opt is not None and self.opt._has_data():
                                                    return True

                                                if self.osnr is not None and self.osnr._has_data():
                                                    return True

                                                if self.pcr is not None and self.pcr._has_data():
                                                    return True

                                                if self.pdl is not None and self.pdl._has_data():
                                                    return True

                                                if self.pmd is not None and self.pmd._has_data():
                                                    return True

                                                if self.pn is not None and self.pn._has_data():
                                                    return True

                                                if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30-optics-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.optics_second30_optics_time_line_instance is not None:
                                                for child_ref in self.optics_second30_optics_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30-optics-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.optics_second30_optics_time_line_instances is not None and self.optics_second30_optics_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30-optics-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.optics_second30_optics_history is not None:
                                        for child_ref in self.optics_second30_optics_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories']['meta_info']


                            class OpticsSecond30FecHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: optics_second30fec_history
                                
                                	port 30\-second fec performance data
                                	**type**\: list of    :py:class:`OpticsSecond30FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.optics_second30fec_history = YList()
                                    self.optics_second30fec_history.parent = self
                                    self.optics_second30fec_history.name = 'optics_second30fec_history'


                                class OpticsSecond30FecHistory(object):
                                    """
                                    port 30\-second fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_second30fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsSecond30FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.optics_second30fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances()
                                        self.optics_second30fec_time_line_instances.parent = self


                                    class OpticsSecond30FecTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_second30fec_time_line_instance
                                        
                                        	port sec\-30 fec performance data
                                        	**type**\: list of    :py:class:`OpticsSecond30FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.optics_second30fec_time_line_instance = YList()
                                            self.optics_second30fec_time_line_instance.parent = self
                                            self.optics_second30fec_time_line_instance.name = 'optics_second30fec_time_line_instance'


                                        class OpticsSecond30FecTimeLineInstance(object):
                                            """
                                            port sec\-30 fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self.q = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self.valid = None


                                            class EcBits(object):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.EcBits']['meta_info']


                                            class UcWords(object):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.UcWords']['meta_info']


                                            class PreFecBer(object):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PreFecBer']['meta_info']


                                            class PostFecBer(object):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PostFecBer']['meta_info']


                                            class Q(object):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Q']['meta_info']


                                            class Qmargin(object):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Qmargin']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30fec-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ec_bits is not None and self.ec_bits._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                                    return True

                                                if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                                    return True

                                                if self.q is not None and self.q._has_data():
                                                    return True

                                                if self.qmargin is not None and self.qmargin._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uc_words is not None and self.uc_words._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30fec-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.optics_second30fec_time_line_instance is not None:
                                                for child_ref in self.optics_second30fec_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30fec-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.optics_second30fec_time_line_instances is not None and self.optics_second30fec_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30fec-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.optics_second30fec_history is not None:
                                        for child_ref in self.optics_second30fec_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-second30-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.optics_second30_optics_histories is not None and self.optics_second30_optics_histories._has_data():
                                    return True

                                if self.optics_second30fec_histories is not None and self.optics_second30fec_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History']['meta_info']


                        class OpticsMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: optics_minute15_optics_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsMinute15OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories>`
                            
                            .. attribute:: optics_minute15fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsMinute15FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.optics_minute15_optics_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories()
                                self.optics_minute15_optics_histories.parent = self
                                self.optics_minute15fec_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories()
                                self.optics_minute15fec_histories.parent = self


                            class OpticsMinute15OpticsHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: optics_minute15_optics_history
                                
                                	port 15\-minute optics performance data
                                	**type**\: list of    :py:class:`OpticsMinute15OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.optics_minute15_optics_history = YList()
                                    self.optics_minute15_optics_history.parent = self
                                    self.optics_minute15_optics_history.name = 'optics_minute15_optics_history'


                                class OpticsMinute15OpticsHistory(object):
                                    """
                                    port 15\-minute optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_minute15_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsMinute15OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.optics_minute15_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances()
                                        self.optics_minute15_optics_time_line_instances.parent = self


                                    class OpticsMinute15OpticsTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_minute15_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OpticsMinute15OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.optics_minute15_optics_time_line_instance = YList()
                                            self.optics_minute15_optics_time_line_instance.parent = self
                                            self.optics_minute15_optics_time_line_instance.name = 'optics_minute15_optics_time_line_instance'


                                        class OpticsMinute15OpticsTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.cd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self.opr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self.opt = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self.pn = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.valid = None


                                            class Lbc(object):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc']['meta_info']


                                            class LbcPc(object):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:lbc-pc'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc']['meta_info']


                                            class Opt(object):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opt'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt']['meta_info']


                                            class Opr(object):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:opr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr']['meta_info']


                                            class Cd(object):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:cd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd']['meta_info']


                                            class Dgd(object):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:dgd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd']['meta_info']


                                            class Pmd(object):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pmd'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd']['meta_info']


                                            class Osnr(object):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:osnr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr']['meta_info']


                                            class CenterWavelength(object):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:center-wavelength'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength']['meta_info']


                                            class Pdl(object):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pdl'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl']['meta_info']


                                            class Pcr(object):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pcr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr']['meta_info']


                                            class Pn(object):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pn'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn']['meta_info']


                                            class RxSigPow(object):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:rx-sig-pow'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow']['meta_info']


                                            class LowSigFreqOff(object):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:low-sig-freq-off'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15-optics-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.cd is not None and self.cd._has_data():
                                                    return True

                                                if self.center_wavelength is not None and self.center_wavelength._has_data():
                                                    return True

                                                if self.dgd is not None and self.dgd._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.lbc is not None and self.lbc._has_data():
                                                    return True

                                                if self.lbc_pc is not None and self.lbc_pc._has_data():
                                                    return True

                                                if self.low_sig_freq_off is not None and self.low_sig_freq_off._has_data():
                                                    return True

                                                if self.opr is not None and self.opr._has_data():
                                                    return True

                                                if self.opt is not None and self.opt._has_data():
                                                    return True

                                                if self.osnr is not None and self.osnr._has_data():
                                                    return True

                                                if self.pcr is not None and self.pcr._has_data():
                                                    return True

                                                if self.pdl is not None and self.pdl._has_data():
                                                    return True

                                                if self.pmd is not None and self.pmd._has_data():
                                                    return True

                                                if self.pn is not None and self.pn._has_data():
                                                    return True

                                                if self.rx_sig_pow is not None and self.rx_sig_pow._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15-optics-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.optics_minute15_optics_time_line_instance is not None:
                                                for child_ref in self.optics_minute15_optics_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15-optics-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.optics_minute15_optics_time_line_instances is not None and self.optics_minute15_optics_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15-optics-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.optics_minute15_optics_history is not None:
                                        for child_ref in self.optics_minute15_optics_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories']['meta_info']


                            class OpticsMinute15FecHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: optics_minute15fec_history
                                
                                	port 15\-minute fec performance data
                                	**type**\: list of    :py:class:`OpticsMinute15FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.optics_minute15fec_history = YList()
                                    self.optics_minute15fec_history.parent = self
                                    self.optics_minute15fec_history.name = 'optics_minute15fec_history'


                                class OpticsMinute15FecHistory(object):
                                    """
                                    port 15\-minute fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_minute15fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsMinute15FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.optics_minute15fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances()
                                        self.optics_minute15fec_time_line_instances.parent = self


                                    class OpticsMinute15FecTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_minute15fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of    :py:class:`OpticsMinute15FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.optics_minute15fec_time_line_instance = YList()
                                            self.optics_minute15fec_time_line_instance.parent = self
                                            self.optics_minute15fec_time_line_instance.name = 'optics_minute15fec_time_line_instance'


                                        class OpticsMinute15FecTimeLineInstance(object):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear30_sec_time = None
                                                self.last_clear_time = None
                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self.q = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self.sec30_support = None
                                                self.timestamp = None
                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self.valid = None


                                            class EcBits(object):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:ec-bits'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.EcBits']['meta_info']


                                            class UcWords(object):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.data = None
                                                    self.tca_report = None
                                                    self.threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:uc-words'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.data is not None:
                                                        return True

                                                    if self.tca_report is not None:
                                                        return True

                                                    if self.threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.UcWords']['meta_info']


                                            class PreFecBer(object):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:pre-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PreFecBer']['meta_info']


                                            class PostFecBer(object):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:post-fec-ber'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PostFecBer']['meta_info']


                                            class Q(object):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:q'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Q']['meta_info']


                                            class Qmargin(object):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.average = None
                                                    self.maximum = None
                                                    self.maximum_tca_report = None
                                                    self.maximum_threshold = None
                                                    self.minimum = None
                                                    self.minimum_tca_report = None
                                                    self.minimum_threshold = None
                                                    self.valid = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:qmargin'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.average is not None:
                                                        return True

                                                    if self.maximum is not None:
                                                        return True

                                                    if self.maximum_tca_report is not None:
                                                        return True

                                                    if self.maximum_threshold is not None:
                                                        return True

                                                    if self.minimum is not None:
                                                        return True

                                                    if self.minimum_tca_report is not None:
                                                        return True

                                                    if self.minimum_threshold is not None:
                                                        return True

                                                    if self.valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Qmargin']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15fec-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.ec_bits is not None and self.ec_bits._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear30_sec_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.post_fec_ber is not None and self.post_fec_ber._has_data():
                                                    return True

                                                if self.pre_fec_ber is not None and self.pre_fec_ber._has_data():
                                                    return True

                                                if self.q is not None and self.q._has_data():
                                                    return True

                                                if self.qmargin is not None and self.qmargin._has_data():
                                                    return True

                                                if self.sec30_support is not None:
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.uc_words is not None and self.uc_words._has_data():
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15fec-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.optics_minute15fec_time_line_instance is not None:
                                                for child_ref in self.optics_minute15fec_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15fec-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.optics_minute15fec_time_line_instances is not None and self.optics_minute15fec_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15fec-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.optics_minute15fec_history is not None:
                                        for child_ref in self.optics_minute15fec_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:optics-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.optics_minute15_optics_histories is not None and self.optics_minute15_optics_histories._has_data():
                                    return True

                                if self.optics_minute15fec_histories is not None and self.optics_minute15fec_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:optics-history/Cisco-IOS-XR-pmengine-oper:optics-port-histories/Cisco-IOS-XR-pmengine-oper:optics-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.optics_hour24_history is not None and self.optics_hour24_history._has_data():
                                return True

                            if self.optics_minute15_history is not None and self.optics_minute15_history._has_data():
                                return True

                            if self.optics_second30_history is not None and self.optics_second30_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:optics-history/Cisco-IOS-XR-pmengine-oper:optics-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.optics_port_history is not None:
                            for child_ref in self.optics_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:optics-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.optics_port_histories is not None and self.optics_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OpticsHistory']['meta_info']


            class OcHistory(object):
                """
                OC controller History performance data
                
                .. attribute:: oc_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`OcPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.oc_port_histories = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories()
                    self.oc_port_histories.parent = self


                class OcPortHistories(object):
                    """
                    Port performance data
                    
                    .. attribute:: oc_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`OcPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.oc_port_history = YList()
                        self.oc_port_history.parent = self
                        self.oc_port_history.name = 'oc_port_history'


                    class OcPortHistory(object):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: oc_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OcHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History>`
                        
                        .. attribute:: oc_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OcMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.oc_hour24_history = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History()
                            self.oc_hour24_history.parent = self
                            self.oc_minute15_history = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History()
                            self.oc_minute15_history.parent = self


                        class OcHour24History(object):
                            """
                            port current performance data
                            
                            .. attribute:: oc_hour24ocn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OcHour24OcnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.oc_hour24ocn_histories = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories()
                                self.oc_hour24ocn_histories.parent = self


                            class OcHour24OcnHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: oc_hour24ocn_history
                                
                                	port 24 hour ocn performance data
                                	**type**\: list of    :py:class:`OcHour24OcnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.oc_hour24ocn_history = YList()
                                    self.oc_hour24ocn_history.parent = self
                                    self.oc_hour24ocn_history.name = 'oc_hour24ocn_history'


                                class OcHour24OcnHistory(object):
                                    """
                                    port 24 hour ocn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: oc_hour24ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OcHour24OcnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.oc_hour24ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances()
                                        self.oc_hour24ocn_time_line_instances.parent = self


                                    class OcHour24OcnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: oc_hour24ocn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OcHour24OcnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.oc_hour24ocn_time_line_instance = YList()
                                            self.oc_hour24ocn_time_line_instance.parent = self
                                            self.oc_hour24ocn_time_line_instance.name = 'oc_hour24ocn_time_line_instance'


                                        class OcHour24OcnTimeLineInstance(object):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self.section = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Section(object):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self.section_status = None


                                                class SectionESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionESs']['meta_info']


                                                class SectionSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSeSs']['meta_info']


                                                class SectionSefSs(object):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-sef-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSefSs']['meta_info']


                                                class SectionCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionCVs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.section_c_vs is not None and self.section_c_vs._has_data():
                                                        return True

                                                    if self.section_e_ss is not None and self.section_e_ss._has_data():
                                                        return True

                                                    if self.section_se_ss is not None and self.section_se_ss._has_data():
                                                        return True

                                                    if self.section_sef_ss is not None and self.section_sef_ss._has_data():
                                                        return True

                                                    if self.section_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section']['meta_info']


                                            class Line(object):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self.line_status = None
                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self


                                                class LineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineESs']['meta_info']


                                                class LineSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineSeSs']['meta_info']


                                                class LineCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineCVs']['meta_info']


                                                class LineUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineUaSs']['meta_info']


                                                class LineFcLs(object):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-fc-ls'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineFcLs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.line_c_vs is not None and self.line_c_vs._has_data():
                                                        return True

                                                    if self.line_e_ss is not None and self.line_e_ss._has_data():
                                                        return True

                                                    if self.line_fc_ls is not None and self.line_fc_ls._has_data():
                                                        return True

                                                    if self.line_se_ss is not None and self.line_se_ss._has_data():
                                                        return True

                                                    if self.line_status is not None:
                                                        return True

                                                    if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line']['meta_info']


                                            class FeLine(object):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self


                                                class FarEndLineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineESs']['meta_info']


                                                class FarEndLineSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs']['meta_info']


                                                class FarEndLineCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineCVs']['meta_info']


                                                class FarEndLineUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs']['meta_info']


                                                class FarEndLineFcLs(object):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-fc-ls'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_line_c_vs is not None and self.far_end_line_c_vs._has_data():
                                                        return True

                                                    if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                                        return True

                                                    if self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls._has_data():
                                                        return True

                                                    if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                                        return True

                                                    if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-hour24ocn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_line is not None and self.fe_line._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.line is not None and self.line._has_data():
                                                    return True

                                                if self.section is not None and self.section._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-hour24ocn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.oc_hour24ocn_time_line_instance is not None:
                                                for child_ref in self.oc_hour24ocn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-hour24ocn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.oc_hour24ocn_time_line_instances is not None and self.oc_hour24ocn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-hour24ocn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.oc_hour24ocn_history is not None:
                                        for child_ref in self.oc_hour24ocn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-hour24-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.oc_hour24ocn_histories is not None and self.oc_hour24ocn_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History']['meta_info']


                        class OcMinute15History(object):
                            """
                            port current performance data
                            
                            .. attribute:: oc_minute15ocn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OcMinute15OcnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.oc_minute15ocn_histories = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories()
                                self.oc_minute15ocn_histories.parent = self


                            class OcMinute15OcnHistories(object):
                                """
                                port current performance data
                                
                                .. attribute:: oc_minute15ocn_history
                                
                                	port 15\-minute ocn performance data
                                	**type**\: list of    :py:class:`OcMinute15OcnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.oc_minute15ocn_history = YList()
                                    self.oc_minute15ocn_history.parent = self
                                    self.oc_minute15ocn_history.name = 'oc_minute15ocn_history'


                                class OcMinute15OcnHistory(object):
                                    """
                                    port 15\-minute ocn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: oc_minute15ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OcMinute15OcnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.number = None
                                        self.oc_minute15ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances()
                                        self.oc_minute15ocn_time_line_instances.parent = self


                                    class OcMinute15OcnTimeLineInstances(object):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: oc_minute15ocn_time_line_instance
                                        
                                        	port 15\-minute ocn performance data
                                        	**type**\: list of    :py:class:`OcMinute15OcnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.oc_minute15ocn_time_line_instance = YList()
                                            self.oc_minute15ocn_time_line_instance.parent = self
                                            self.oc_minute15ocn_time_line_instance.name = 'oc_minute15ocn_time_line_instance'


                                        class OcMinute15OcnTimeLineInstance(object):
                                            """
                                            port 15\-minute ocn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.number = None
                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self.index = None
                                                self.last_clear15_min_time = None
                                                self.last_clear24_hr_time = None
                                                self.last_clear_time = None
                                                self.line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self.section = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self.timestamp = None
                                                self.valid = None


                                            class Section(object):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self.section_status = None


                                                class SectionESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionESs']['meta_info']


                                                class SectionSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSeSs']['meta_info']


                                                class SectionSefSs(object):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-sef-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSefSs']['meta_info']


                                                class SectionCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionCVs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:section'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.section_c_vs is not None and self.section_c_vs._has_data():
                                                        return True

                                                    if self.section_e_ss is not None and self.section_e_ss._has_data():
                                                        return True

                                                    if self.section_se_ss is not None and self.section_se_ss._has_data():
                                                        return True

                                                    if self.section_sef_ss is not None and self.section_sef_ss._has_data():
                                                        return True

                                                    if self.section_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section']['meta_info']


                                            class Line(object):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self.line_status = None
                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self


                                                class LineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineESs']['meta_info']


                                                class LineSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineSeSs']['meta_info']


                                                class LineCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineCVs']['meta_info']


                                                class LineUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineUaSs']['meta_info']


                                                class LineFcLs(object):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line-fc-ls'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineFcLs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.line_c_vs is not None and self.line_c_vs._has_data():
                                                        return True

                                                    if self.line_e_ss is not None and self.line_e_ss._has_data():
                                                        return True

                                                    if self.line_fc_ls is not None and self.line_fc_ls._has_data():
                                                        return True

                                                    if self.line_se_ss is not None and self.line_se_ss._has_data():
                                                        return True

                                                    if self.line_status is not None:
                                                        return True

                                                    if self.line_ua_ss is not None and self.line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line']['meta_info']


                                            class FeLine(object):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self


                                                class FarEndLineESs(object):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-e-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineESs']['meta_info']


                                                class FarEndLineSeSs(object):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-se-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs']['meta_info']


                                                class FarEndLineCVs(object):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-c-vs'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs']['meta_info']


                                                class FarEndLineUaSs(object):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-ua-ss'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs']['meta_info']


                                                class FarEndLineFcLs(object):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.data = None
                                                        self.tca_report = None
                                                        self.threshold = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:far-end-line-fc-ls'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.data is not None:
                                                            return True

                                                        if self.tca_report is not None:
                                                            return True

                                                        if self.threshold is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:fe-line'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.far_end_line_c_vs is not None and self.far_end_line_c_vs._has_data():
                                                        return True

                                                    if self.far_end_line_e_ss is not None and self.far_end_line_e_ss._has_data():
                                                        return True

                                                    if self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls._has_data():
                                                        return True

                                                    if self.far_end_line_se_ss is not None and self.far_end_line_se_ss._has_data():
                                                        return True

                                                    if self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.number is None:
                                                    raise YPYModelError('Key property number is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-minute15ocn-time-line-instance[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.number is not None:
                                                    return True

                                                if self.fe_line is not None and self.fe_line._has_data():
                                                    return True

                                                if self.index is not None:
                                                    return True

                                                if self.last_clear15_min_time is not None:
                                                    return True

                                                if self.last_clear24_hr_time is not None:
                                                    return True

                                                if self.last_clear_time is not None:
                                                    return True

                                                if self.line is not None and self.line._has_data():
                                                    return True

                                                if self.section is not None and self.section._has_data():
                                                    return True

                                                if self.timestamp is not None:
                                                    return True

                                                if self.valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-minute15ocn-time-line-instances'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.oc_minute15ocn_time_line_instance is not None:
                                                for child_ref in self.oc_minute15ocn_time_line_instance:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.number is None:
                                            raise YPYModelError('Key property number is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-minute15ocn-history[Cisco-IOS-XR-pmengine-oper:number = ' + str(self.number) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.number is not None:
                                            return True

                                        if self.oc_minute15ocn_time_line_instances is not None and self.oc_minute15ocn_time_line_instances._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-minute15ocn-histories'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.oc_minute15ocn_history is not None:
                                        for child_ref in self.oc_minute15ocn_history:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-pmengine-oper:oc-minute15-history'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.oc_minute15ocn_histories is not None and self.oc_minute15ocn_histories._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History']['meta_info']

                        @property
                        def _common_path(self):
                            if self.name is None:
                                raise YPYModelError('Key property name is None')

                            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:oc-history/Cisco-IOS-XR-pmengine-oper:oc-port-histories/Cisco-IOS-XR-pmengine-oper:oc-port-history[Cisco-IOS-XR-pmengine-oper:name = ' + str(self.name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.oc_hour24_history is not None and self.oc_hour24_history._has_data():
                                return True

                            if self.oc_minute15_history is not None and self.oc_minute15_history._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                            return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:oc-history/Cisco-IOS-XR-pmengine-oper:oc-port-histories'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.oc_port_history is not None:
                            for child_ref in self.oc_port_history:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                        return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic/Cisco-IOS-XR-pmengine-oper:oc-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.oc_port_histories is not None and self.oc_port_histories._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                    return meta._meta_table['PerformanceManagementHistory.Global_.Periodic.OcHistory']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global/Cisco-IOS-XR-pmengine-oper:periodic'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.dwdm_history is not None and self.dwdm_history._has_data():
                    return True

                if self.ethernet_history is not None and self.ethernet_history._has_data():
                    return True

                if self.ho_vc_history is not None and self.ho_vc_history._has_data():
                    return True

                if self.oc_history is not None and self.oc_history._has_data():
                    return True

                if self.odu_history is not None and self.odu_history._has_data():
                    return True

                if self.optics_history is not None and self.optics_history._has_data():
                    return True

                if self.otu_history is not None and self.otu_history._has_data():
                    return True

                if self.sonet_history is not None and self.sonet_history._has_data():
                    return True

                if self.stm_history is not None and self.stm_history._has_data():
                    return True

                if self.sts_history is not None and self.sts_history._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
                return meta._meta_table['PerformanceManagementHistory.Global_.Periodic']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-pmengine-oper:performance-management-history/Cisco-IOS-XR-pmengine-oper:global'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.periodic is not None and self.periodic._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
            return meta._meta_table['PerformanceManagementHistory.Global_']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-pmengine-oper:performance-management-history'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.global_ is not None and self.global_._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_pmengine_oper as meta
        return meta._meta_table['PerformanceManagementHistory']['meta_info']


